@@ -36,6 +36,7 @@ vtkStandardNewMacro(vtkLookupTableManager);
 #include "lut/HotIron.h"
 #include "lut/HotGreen.h"
 #include "lut/GEColor.h"
+#include "lut/PERFUSION.h"
 #include "lut/Flow.h"
 #include "lut/LONI.h"
 #include "lut/LONI2.h"
@@ -45,17 +46,14 @@ vtkStandardNewMacro(vtkLookupTableManager);
 
 #include <time.h>
 
-
 vtkLookupTableManager::vtkLookupTableManager() {}
 
-
 vtkLookupTableManager::~vtkLookupTableManager() {}
 
-
 std::list<std::string> vtkLookupTableManager::GetAvailableLookupTables() {
-    std::string lutNames[]={_Std("B/W"),_Std("B/W Inverse"),_Std("Barten"), _Std("Black Body"), _Std("Cardiac"), _Std("VR Bones"), _Std("VR Muscles & Bones"), _Std("VR Red Vessels"), _Std("Gray Rainbow"), _Std("Stern"), _Std("Spectrum"), _Std("Hot Metal"), _Std("Hot Iron"), _Std("Hot Green"), _Std("GE Color"), _Std("Flow"), _Std("LONI"), _Std("LONI2"), _Std("Asymmetry"), _Std("P-Value"), _Std("ROI")};
+    std::string lutNames[]={_Std("B/W"),_Std("B/W Inverse"),_Std("Barten"), _Std("Black Body"), _Std("Cardiac"), _Std("VR Bones"), _Std("VR Muscles & Bones"), _Std("VR Red Vessels"), _Std("Gray Rainbow"), _Std("Stern"), _Std("Spectrum"), _Std("Hot Metal"), _Std("Hot Iron"), _Std("Hot Green"), _Std("GE Color"), _Std("PERFusion"), _Std("PET"), _Std("Flow"), _Std("LONI"), _Std("LONI2"), _Std("Asymmetry"), _Std("P-Value"), _Std("ROI")};
     std::list<std::string> v_lutNames;
-    for ( int i=0; i<21; i++) {
+    for ( int i=0; i<22; i++) {
         v_lutNames.push_back(lutNames[i]);
     }
 
@@ -125,6 +123,14 @@ vtkLookupTable* vtkLookupTableManager::GetLookupTable(const int& n) {
 			lut = vtkLookupTableManager::GetGEColorLookupTable();
 			break;
 
+		case LUT_PERFUSION:
+			lut = vtkLookupTableManager::GetPERFusionLookupTable();
+			break;
+
+		case LUT_PET:
+			lut = vtkLookupTableManager::GetPETLookupTable();
+			break;
+
 		case LUT_FLOW:
 			lut = vtkLookupTableManager::GetFlowLookupTable();
 			break;
@@ -448,6 +454,44 @@ vtkLookupTable* vtkLookupTableManager::GetHotGreenLookupTable(void) {
     return lut;
 }
 
+vtkLookupTable* vtkLookupTableManager::GetPETLookupTable(void) {
+    vtkLookupTable* lut = vtkLookupTable::New();
+    lut->SetNumberOfTableValues(256);
+    
+	lut->Build();
+
+	for ( int i = 0; i < 256; i++) {
+		if (i < 128) {
+			lut->SetTableValue(i, (double)(i << 1) / 255.0, 0.0, 0.0, /*(double)(i)/255.0*/ log (1.0+(double)(i)/255.0*9.0)/log (10.0) );
+		}
+		else if (i < 192) {
+			lut->SetTableValue(i, 1.0, (double) ( (i-128) << 2 ) / 255.0, 0.0, /*(double)(i)/255.0*/ log (1.0+(double)(i)/255.0*9.0)/log (10.0) );
+		}
+		else {
+			lut->SetTableValue(i, 1.0, 1.0, (double) ( (i-192) << 2 ) / 255.0, /*(double)(i)/255.0*/ log (1.0+(double)(i)/255.0*9.0)/log (10.0) );
+		}        
+    }
+
+    return lut;
+}
+
+vtkLookupTable* vtkLookupTableManager::GetPERFusionLookupTable(void) {
+    vtkLookupTable* lut = vtkLookupTable::New();
+    lut->SetNumberOfTableValues(256);
+    
+	lut->Build();
+
+	const int* R = PERFUSION;
+	const int* G = R + 256;
+	const int* B = G + 256;
+
+    for ( int i = 0; i < 256; i++) {
+        lut->SetTableValue(i, (double)R[i]/255.0, (double)G[i]/255.0, (double)B[i]/255.0, /*(double)(i)/255.0*/ log (1.0+(double)(i)/255.0*9.0)/log (10.0) );
+    }
+
+    return lut;
+}
+
 vtkLookupTable* vtkLookupTableManager::GetROILookupTable() {
     vtkLookupTable* lut = vtkLookupTable::New();
     lut->SetNumberOfTableValues (256);
