@@ -3,7 +3,7 @@
  *  $Id: icontroladorcarga.h $
  *  Ginkgo CADx Project
  *
- *  Copyright 2008-12 MetaEmotion S.L. All rights reserved.
+ *  Copyright 2008-14 MetaEmotion S.L. All rights reserved.
  *  http://ginkgo-cadx.com
  *
  *  This file is licensed under LGPL v3 license.
@@ -41,12 +41,9 @@ namespace GNC {
 
 		class ControladorCargaException : public GNC::GCS::IException {
 		public:
-			ControladorCargaException(const std::string& msg, const std::string& componente="Modelo", bool fatal = true) : GNC::GCS::IException(msg, componente, fatal)
-			{
-			}
-			~ControladorCargaException() throw()
-			{
-			}
+			ControladorCargaException(const std::string& msg, const std::string& componente="Modelo", bool fatal = true);
+			
+			~ControladorCargaException() throw();
 		protected:
 		};
 
@@ -67,40 +64,28 @@ namespace GNC {
 			//endregion
 
 		protected:
-			IControladorCarga() {}
-			~IControladorCarga() {}
+			IControladorCarga();
+			~IControladorCarga();
 		};
 
 		
-		class IStreamingLoader : public IPipelineProperties, public GNC::GCS::ILockable {
+		class EXTAPI IStreamingLoader : public IPipelineProperties, public GNC::GCS::ILockable {
 		public:
 			//region Constructor
-			IStreamingLoader() {}
+			IStreamingLoader();
 
-			virtual ~IStreamingLoader() {}
+			virtual ~IStreamingLoader();
 
 			virtual bool IsSignalFile() = 0;
 
 			/** Fija un fichero de entrada y reestablece el pipeline interno de carga si es necesario **/
 			virtual void SetInput(const std::string& fichero) = 0;
 
-			/** Actualiza la imagen completa del puerto de salida **/
-			virtual void Update() = 0;
-
 			/** Devuelve el puerto de salida **/
 			virtual vtkSmartPointer<vtkAlgorithmOutput> GetOutputPort() = 0;
 
 			/** Devuelve por parametro una copia de la imagen **/
 			virtual void GetOutputCopy(vtkSmartPointer<vtkImageData>& output) = 0;
-			
-			/** Obtiene las dimensiones de la imagen de entrada **/
-			virtual void GetDimensions(int dimensions[3]) = 0;
-			
-			/** Obtiene el origen de la imagen de entrada **/
-			virtual void GetOrigin(double origin[3]) = 0;
-			
-			/** Obtiene el spacing de la imagen de entrada **/
-			virtual void GetSpacing(double spacing[3]) = 0;
 
 			/** establece el spacing **/
 			virtual void SetOutputSpacing(double spacing[3]) = 0;
