@@ -86,8 +86,15 @@ namespace GNC {
 
 				template <class T> T ObtenerValor() const {
 					T v;
-					std::istringstream is(m_Valor);
-					is >> v;
+					if (!m_Activo) {
+						std::istringstream is(m_ValorPorDefecto);
+						is >> v;
+					}
+					else {
+						std::istringstream is(m_Valor);
+						is >> v;
+					}
+					
 					return v;
 				}
 
