@@ -41,9 +41,9 @@ namespace GIL {
 
 			std::string tagName;
 
-			DicomDataset() {}
+			DicomDataset() ;
 
-			~DicomDataset() {}
+			~DicomDataset() ;
 
 			//aade referencias a las imagenes a las que hace referencia
 			void AddReference(const std::string& sopClassUID, const std::string& sopInstanceUID);
@@ -51,6 +51,8 @@ namespace GIL {
 			//aade referencias a las imagenes originales
 			void AddReferenceSource(const std::string& sopClassUID, const std::string& sopInstanceUID);
 
+			void clear();
+
 			DicomDataset* buscar_secuencia(const char* tag);
 
 			DicomDataset* buscar_secuencia(const std::string & tag);
