@@ -115,6 +115,8 @@
 #include <main/controllers/historytoolscontroller.h>
 #include <main/controllers/hangingprotocolcontroller.h>
 #include <main/controllers/autocleaningcontroller.h>
+#include <main/controllers/modalitysettingscontroller.h>
+#include <main/controllers/anonusagestats.h>
 
 #include <main/gui/mainwindow/ventanaprincipal.h>
 
@@ -379,6 +381,28 @@ bool Ginkgo::OnInit()
 	}
 	#endif
 
+	wxPNGHandler* handlerPng=new wxPNGHandler();
+	wxImage::AddHandler(handlerPng);
+#if defined(_GINKGO_ENABLE_SPLASH)	
+	m_pVentanaLogo = NULL;
+	wxBitmap bitmap = GinkgoResourcesManager::Logos::GetLogoSplash();
+	wxSplashScreen splash(bitmap, wxSPLASH_CENTRE_ON_SCREEN | wxSPLASH_NO_TIMEOUT,
+		-1, NULL, -1, wxDefaultPosition, wxDefaultSize,
+		wxSTAY_ON_TOP|wxNO_BORDER);
+	wxIcon icono;
+	icono.CopyFromBitmap(GinkgoResourcesManager::Logos::GetLogoGinkgo32x32());
+	splash.SetIcon(icono);
+	splash.Connect(wxEVT_CLOSE_WINDOW, wxCloseEventHandler(Ginkgo::OnSplashClose));
+	// Copia del bitmap original de la ventana splash para pintar sobre ella
+	if (m_pBitmapOriginal.Create(bitmap.GetWidth(), bitmap.GetHeight(), bitmap.GetDepth())) {
+		m_pVentanaLogo = &splash;
+		wxMemoryDC srcDC(bitmap);
+		wxMemoryDC dstDC(m_pBitmapOriginal);
+		dstDC.Blit(wxPoint(0, 0), srcDC.GetSize(), &srcDC, wxPoint(0, 0), wxCOPY, false, wxPoint(0, 0));
+	}
+#endif
+	DoProgress(wxString(_("Initializing environment ...")));		
+
 	//inicializamos la intrnacionalizacion del core
 	{
 		GNC::GCS::ControladorInternacionalizacion::Instance()->AddCatalog("cadxcore");
@@ -413,6 +437,8 @@ bool Ginkgo::OnInit()
 	GNC::GCS::IControladorPermisos::Instance()->AddDefinicionPermiso("core.pacs.limits", _Std("PACS Limits"), "patient_scope", _Std("Restrict search over selected patient"), false, "", false);
 	GNC::GCS::IControladorPermisos::Instance()->AddDefinicionPermiso("core.pacs.limits", _Std("PACS Limits"), "study_size", _Std("Restrict study retrieval by maximum size (KB)"), false, "16384", false);
 	GNC::GCS::IControladorPermisos::Instance()->AddDefinicionPermiso("core.pacs.limits", _Std("PACS Limits"), "force_lossless", _Std("Force lossless when upload"), false, "", false);
+	GNC::GCS::IControladorPermisos::Instance()->AddDefinicionPermiso("core.importacion", _Std("Import"), "storage_sop_class", _Std("Specify this Storage SOP Class in dicomization"), false, "1.2.840.10008.5.1.4.1.1.77.1.4", false);
+	GNC::GCS::IControladorPermisos::Instance()->AddDefinicionPermiso("core.importacion", _Std("Import"), "input_accno", _Std("Show accession number input"), false, "", false);
 	GNC::GCS::IControladorPermisos::Instance()->AddDefinicionPermiso("core.importacion", _Std("Import"), "quality", _Std("Set compression, 0 implies no compression (0..14)"), false, "1", true);
 	GNC::GCS::IControladorPermisos::Instance()->AddDefinicionPermiso("core.importacion", _Std("Import"), "codec", _Std("Recompression codec (0=JPEG Baseline(default), 1=JPEG Progressive, 2=JPEG Lossless)"), false, "0", true);
 	GNC::GCS::IControladorPermisos::Instance()->AddDefinicionPermiso("core.importacion", _Std("Import"), "mantener", _Std("Don't change image codec (if possible)"), false, "", true);
@@ -467,127 +493,101 @@ bool Ginkgo::OnInit()
 
 	wxThread::SetConcurrency(wxThread::GetCPUCount());
 
-	m_pVentanaLogo = NULL;
-
+	//codecs...
 	wxJPEGHandler* handler=new wxJPEGHandler();
 	wxImage::AddHandler(handler);
 
-	wxPNGHandler* handlerPng=new wxPNGHandler();
-	wxImage::AddHandler(handlerPng);
-
 	wxGIFHandler* handlerGif=new wxGIFHandler();
 	wxImage::AddHandler(handlerGif);
 
 	wxTIFFHandler* handleTiff = new wxTIFFHandler();
 	wxImage::AddHandler(handleTiff);
 
-#if defined(_GINKGO_ENABLE_SPLASH)
+	GNC::Entorno::Instance()->SetApp(this);
 
 	{
-		wxBitmap bitmap = GinkgoResourcesManager::Logos::GetLogoSplash();
-		wxSplashScreen splash(bitmap, wxSPLASH_CENTRE_ON_SCREEN | wxSPLASH_NO_TIMEOUT,
-			-1, NULL, -1, wxDefaultPosition, wxDefaultSize,
-			wxSTAY_ON_TOP|wxNO_BORDER);
-		wxIcon icono;
-		icono.CopyFromBitmap(GinkgoResourcesManager::Logos::GetLogoGinkgo32x32());
-		splash.SetIcon(icono);
-		splash.Connect(wxEVT_CLOSE_WINDOW, wxCloseEventHandler(Ginkgo::OnSplashClose));
-		// Copia del bitmap original de la ventana splash para pintar sobre ella
-		if (m_pBitmapOriginal.Create(bitmap.GetWidth(), bitmap.GetHeight(), bitmap.GetDepth())) {
-			m_pVentanaLogo = &splash;
-			wxMemoryDC srcDC(bitmap);
-			wxMemoryDC dstDC(m_pBitmapOriginal);
-			dstDC.Blit(wxPoint(0, 0), srcDC.GetSize(), &srcDC, wxPoint(0, 0), wxCOPY, false, wxPoint(0, 0));
-		}
-#endif
+		wxWindowDisabler dis;
+		m_pVentanaPrincipal = new VentanaPrincipal(NULL, wxString::FromUTF8(GNC::Entorno::Instance()->GetApplicationName().c_str()));
+		m_pVentanaPrincipal->Hide();
+		SetTopWindow(m_pVentanaPrincipal);
+	}
 
-		DoProgress(wxString(_("Initializing environment ...")));
+	DoProgress(wxString(_("Tools loading base ...")));
 
-		GNC::Entorno::Instance()->SetApp(this);
-
-		{
-			wxWindowDisabler dis;
-			m_pVentanaPrincipal = new VentanaPrincipal(NULL, wxString::FromUTF8(GNC::Entorno::Instance()->GetApplicationName().c_str()));
-			m_pVentanaPrincipal->Hide();
-			SetTopWindow(m_pVentanaPrincipal);
-		}
-
-		DoProgress(wxString(_("Tools loading base ...")));
-
-		DoProgress(wxString(_("Starting tools...")));
+	DoProgress(wxString(_("Starting tools...")));
 		
-		GNC::RegisterCoreTools();
+	GNC::RegisterCoreTools();
 
-		DoProgress(wxString(_("Loading plugins ...")));
+	DoProgress(wxString(_("Loading plugins ...")));
 
-		try {
-			LoadPlugins();
-		}
-		catch (GNC::GCS::IRequestingException& ex) {
-			m_pVentanaLogo->Hide();
-			if (ex.shouldExit()) {
-				exit(-1);
-			}
-		}
-		catch (GNC::GCS::IException& ex) {
-			m_pVentanaLogo->Hide();
-			LOG_ERROR("Init", "Error loading: " << ex.GetCause());		
-			wxMessageBox(_("Unable to start GinkgoCADx:\n") + wxString::FromUTF8(ex.GetCause().c_str()),_("error"),wxICON_INFORMATION);
+	try {
+		LoadPlugins();
+	}
+	catch (GNC::GCS::IRequestingException& ex) {
+		m_pVentanaLogo->Hide();
+		if (ex.shouldExit()) {
 			exit(-1);
 		}
+	}
+	catch (GNC::GCS::IException& ex) {
+		m_pVentanaLogo->Hide();
+		LOG_ERROR("Init", "Error loading: " << ex.GetCause());		
+		wxMessageBox(_("Unable to start GinkgoCADx:\n") + wxString::FromUTF8(ex.GetCause().c_str()),_("error"),wxICON_INFORMATION);
+		exit(-1);
+	}
 
-		DoProgress(wxString(_("Loading resources ...")));
-		GIL::DICOM::Conformance::Load();
+	DoProgress(wxString(_("Loading resources ...")));
+	GIL::DICOM::Conformance::Load();
 
-		DoProgress(wxString(_("Starting services...")));
-		try {
-			GIL::DICOM::PACSController::Instance()->StartServer();
-		}
-		catch(GNC::GCS::IException& ex) {
-			LOG_ERROR("Init", "Error starting PACS Service: " << ex.GetCause());
-		}
+	DoProgress(wxString(_("Starting services...")));
+	try {
+		GIL::DICOM::PACSController::Instance()->StartServer();
+	}
+	catch(GNC::GCS::IException& ex) {
+		LOG_ERROR("Init", "Error starting PACS Service: " << ex.GetCause());
+	}
 
-		DoProgress(wxString(_("Configuring environment ...")));
+	DoProgress(wxString(_("Configuring environment ...")));
 
-		try{
-			GNC::GCS::ConfigurationController::TListGroups profiles;
-			GNC::GCS::ConfigurationController::Instance()->readGroupGeneral("/GinkgoCore/Profiles", profiles);
+	try{
+		GNC::GCS::ConfigurationController::TListGroups profiles;
+		GNC::GCS::ConfigurationController::Instance()->readGroupGeneral("/GinkgoCore/Profiles", profiles);
 
-			for (GNC::GCS::ConfigurationController::TListGroups::iterator it = profiles.begin(); it != profiles.end(); ++it) {
-				bool value;
-				(*it).readBoolValue("Apply",value, false);
-				if (value) {
-					std::string xml;
-					if ((*it).readStringValue("XML", xml)) {
-						GNC::GCS::IControladorPermisos::Instance()->CargarXMLPermisos(xml, false);
-						break;
-					}
+		for (GNC::GCS::ConfigurationController::TListGroups::iterator it = profiles.begin(); it != profiles.end(); ++it) {
+			bool value;
+			(*it).readBoolValue("Apply",value, false);
+			if (value) {
+				std::string xml;
+				if ((*it).readStringValue("XML", xml)) {
+					GNC::GCS::IControladorPermisos::Instance()->CargarXMLPermisos(xml, false);
+					break;
 				}
 			}
 		}
-		catch(GNC::GCS::ControladorPermisosException& ex) {
-			m_pVentanaLogo->Hide();
-			wxMessageBox(_("Failed to set permissions:\n") + wxString::FromUTF8(ex.GetCause().c_str()),_("error"),wxICON_INFORMATION);
-		}
-
-		//es necesario porque hay permisos que afectan a menus
-		m_pVentanaPrincipal->RefrescarMenus();
-
-		//se registran vistas y modos
-		const GNC::ControladorExtensiones::ListaModulos& listaModulos = GNC::ControladorExtensiones::Instance()->Modulos();
-		for(GNC::ControladorExtensiones::ListaModulos::const_iterator it = listaModulos.begin(); it != listaModulos.end(); ++it)
-		{
-			(*it).second->RegistrarVistas();
-		}
-
-		DoProgress(wxString(_("Updating ...")));
-
-		m_pVentanaPrincipal->CargarHistorial();	
-
-		DoProgress(wxString(_("Interpreting parameters ...")));
-
-
 	}
+	catch(GNC::GCS::ControladorPermisosException& ex) {
+		m_pVentanaLogo->Hide();
+		wxMessageBox(_("Failed to set permissions:\n") + wxString::FromUTF8(ex.GetCause().c_str()),_("error"),wxICON_INFORMATION);
+	}
+
+	//es necesario porque hay permisos que afectan a menus
+	m_pVentanaPrincipal->RefrescarMenus();
+
+	//se registran vistas y modos
+	const GNC::ControladorExtensiones::ListaModulos& listaModulos = GNC::ControladorExtensiones::Instance()->Modulos();
+	for(GNC::ControladorExtensiones::ListaModulos::const_iterator it = listaModulos.begin(); it != listaModulos.end(); ++it)
+	{
+		(*it).second->RegistrarVistas();
+	}
+
+	DoProgress(wxString(_("Updating ...")));
+
+	m_pVentanaPrincipal->CargarHistorial();	
+
+	DoProgress(wxString(_("Interpreting parameters ...")));
+
+
+	
 	//parseo
 	wxCommandEvent ce(wxEVT_COMMAND_MENU_SELECTED, ID_Inicio_Aplicacion);
 	m_pVentanaPrincipal->GetEventHandler()->AddPendingEvent(ce);
@@ -604,6 +604,8 @@ bool Ginkgo::OnInit()
 	//launch auto cleaning controller...
 	GNC::GCS::AutoCleaningController::Instance();
 
+	LOG_STAT(ANON_STAT_RUN_GINKGO)
+
 	return TRUE;
 }
 
@@ -637,7 +639,9 @@ int Ginkgo::OnExit()
 	}
 
 	GNC::GCS::AutoCleaningController::FreeInstance();
+	GNC::GCS::AnonUsageStats::FreeInstance();
 	GNC::GCS::ThumbnailController::FreeInstance();
+	GNC::GCS::ModalitySettingsController::FreeInstance();
 	GNC::GCS::HangingProtocolController::FreeInstance();
 	GNC::GCS::ControladorVistas::FreeInstance();
 	GIL::IntegrationController::FreeInstance();
