@@ -4,7 +4,7 @@
  *  $Id: istudycontext.h $
  *  Ginkgo CADx Project
  *
- *  Copyright 2008-12 MetaEmotion S.L. All rights reserved.
+ *  Copyright 2008-14 MetaEmotion S.L. All rights reserved.
  *  http://ginkgo-cadx.com
  *
  *  This file is licensed under LGPL v3 license.
@@ -38,6 +38,7 @@ namespace GNC {
 		class IReferredStudyContext;
 		class IModuleController;
 		class Layout;
+		class HangingProtocol;
 	}
 }
 
@@ -73,7 +74,7 @@ namespace GNC {
 			typedef std::vector<GNC::GCS::Ptr<TStudyFile> >     TStudyFileVector;
 
 			GNC::GCS::IVista*                                 View;
-			GNC::GCS::IModuleController*                     Module;
+			GNC::GCS::IModuleController*                      Module;
 			vtkSmartPointer<vtkGinkgoImageViewer>             Viewer;
 			wxWindow*                                         ParentWindow; // La ventana WX de la que es padre la vista (Notebook/Grid..)
 			wxWindow*                                         Window;      // La ventana WX propia de la vista
@@ -82,6 +83,7 @@ namespace GNC {
 
 			vtkSmartPointer<vtkAlgorithmOutput>               renderConnection; // Conexion hacia renderer
 			GNC::GCS::Ptr<GNC::GCS::Layout>					  hangingLayout;
+			GNC::GCS::Ptr<GNC::GCS::HangingProtocol>          hangingProtocol;
 
 			int                                               ActiveFileIndex;
 			std::vector<long>											  OpenedSeries;
