@@ -12,6 +12,7 @@
  */
 #pragma once
 #include <api/api.h>
+#include <api/autoptr.h>
 #include <api/math/geometry.h>
 #include <api/ievento.h>
 #include <api/iwidgetsproperties.h>
@@ -23,7 +24,7 @@ namespace GNC {
 		class IEventsController;
 		class IWidgetsRenderer;
 		class IContexto;
-		class IAnotador;
+		class IAnnotator;
 		class IImpresorOverlay;
 
 		namespace Widgets {
@@ -53,17 +54,11 @@ namespace GNC {
 
 			virtual ~IWidgetsManager();
 			
-			inline GNC::GCS::IVista* GetVista(){
-				return m_pView;
-			}
+			GNC::GCS::IVista* GetVista();
 
-			inline void MarcarModificado(bool modificado) {
-				m_Modified = modificado;
-			}
+			void MarcarModificado(bool modificado);
 
-			inline bool EstaModificado() {
-				return m_Modified;
-			}
+			bool EstaModificado();
 
 		//----------------------------------------------------------------------------------------------------
 		//region "Interfaz de registro de IWidgetBuilder's"
@@ -72,20 +67,9 @@ namespace GNC {
 			ListaBuilders m_pBuilders;
 
 		public:
-			inline void RegisterBuilder(GNC::GCS::Widgets::IWidgetBuilder* pBuilder)
-			{
-				m_pBuilders.push_back(pBuilder);
-			}
+			void RegisterBuilder(GNC::GCS::Widgets::IWidgetBuilder* pBuilder);
 
-			inline void UnRegisterBuilder(GNC::GCS::Widgets::IWidgetBuilder* pBuilder)
-			{
-				for (ListaBuilders::iterator it = m_pBuilders.begin(); it != m_pBuilders.end(); ++it) {
-					if ( (*it) == pBuilder) {
-						m_pBuilders.erase(it);
-						break;
-					}
-				}
-			}
+			void UnRegisterBuilder(GNC::GCS::Widgets::IWidgetBuilder* pBuilder);
 
 		//endregion
 
@@ -185,10 +169,10 @@ namespace GNC {
 
 		//----------------------------------------------------------------------------------------------------
 		//region "Interfaz general"
-			virtual void CrearWidgetAnotador(GNC::GCS::IAnotador* pAnotador) = 0;
-			virtual void EnableAnotacionDinamica(bool enable) = 0;
-			virtual void MostrarOcultarAnotador() = 0;
-			virtual bool IsVisibleAnotador() = 0;
+			virtual void SetAnnotator(const GNC::GCS::Ptr<GNC::GCS::IAnnotator>& pAnnotador) = 0;
+			virtual const GNC::GCS::Ptr<GNC::GCS::IAnnotator>& GetAnnotator() = 0;
+			virtual void ShowAnnotations(bool show) = 0;
+			virtual bool IsShownAnnotations() = 0;
 		//endregion
 
 		//----------------------------------------------------------------------------------------------------
