@@ -4,7 +4,7 @@
  *  $Id: geometry.h $
  *  Ginkgo CADx Project
  *
- *  Copyright 2008-12 MetaEmotion S.L. All rights reserved.
+ *  Copyright 2008-14 MetaEmotion S.L. All rights reserved.
  *  http://ginkgo-cadx.com
  *
  *  This file is licensed under LGPL v3 license.
@@ -44,8 +44,12 @@ namespace GNC {
 			typedef PRECISION_COMPONENTE_POR_DEFECTO TComp;
 			typedef PRECISION_REALES_POR_DEFECTO     TReal;
 
-			TComp x;           // Coordenada mundo X
-			TComp y;           // Coordenada mundo Y			
+			TComp& x;           // Coordenada mundo X
+			TComp& y;           // Coordenada mundo Y 
+			TComp& z;           // Coordenada mundo Z (Allways zero)
+			TComp& w;           // Coordenada mundo W
+
+			TComp v[4];
 
 		public:
 
@@ -73,30 +77,38 @@ namespace GNC {
 			//-- Constructores y destructores
 			//----------------------------------------------
 
-			inline Vector()
+			inline Vector() : x(v[0]), y(v[1]), z(v[2]), w(v[3])
 			{
 				x = (TComp)0.0;
 				y = (TComp)0.0;
+				z = (TComp)0.0;
+				w = (TComp)1.0;
 			}
 
 			/* Constructor copia transparente */
-			inline Vector(const Vector& b)
+			inline Vector(const Vector& b) : x(v[0]), y(v[1]), z(v[2]), w(v[3])
 			{
 				x = b.x;
 				y = b.y;
+				z = (TComp)0.0;
+				w = (TComp)1.0;
 			}
 
-			template <class TipoComp1, class TipoComp2>
-			inline Vector(const TipoComp1& valX, const TipoComp2& valY)
+			template <class TipoComp1, class TipoComp2> 
+			inline Vector(const TipoComp1& valX, const TipoComp2& valY)  : x(v[0]), y(v[1]), z(v[2]), w(v[3])
 			{
 				x = (TComp) valX;
 				y = (TComp) valY;
+				z = (TComp)0.0;
+				w = (TComp)1.0;
 			}
 
-			template <class TipoComp> inline Vector(const TipoComp* const valor)
+			template <class TipoComp> inline Vector(const TipoComp* const valor)  : x(v[0]), y(v[1]), z(v[2]), w(v[3])
 			{
 				x = valor[0];
 				y = valor[1];
+				z = (TComp)0.0;
+				w = (TComp)1.0;
 			}
 
 			inline ~Vector()
@@ -1311,6 +1323,11 @@ namespace GNC {
 				return Vector(*this) -= valor;
 			}
 
+			/** Unary minus **/
+			inline Vector operator-() const {
+				return Vector(-x, -y);
+			}
+
 			inline Vector& operator-=(const TComp& valor) {
 				x -= valor;
 				y -= valor;
@@ -1337,6 +1354,22 @@ namespace GNC {
 				return *this;
 			}
 
+			inline operator TComp *() {
+				return v;
+			}
+
+			inline operator const TComp *() const {
+				return v;
+			}
+
+			//----------------------------------------------
+			//-- Accesores
+			//----------------------------------------------
+
+			inline TComp& operator [] (int i) {
+				return v[i];
+			}
+
 			inline friend std::ostream& operator<<(std::ostream& out, const Vector& c) {
 				out << "[ x = " << c.x << ", y = " << c.y << " ]";
 				return out;
@@ -1353,6 +1386,54 @@ namespace GNC {
 			}
 		};
 
+		inline GNC::GCS::Vector operator+(int val, const Vector& o) {
+			return GNC::GCS::Vector( (GNC::GCS::Vector::TComp)val + o.x, (GNC::GCS::Vector::TComp)val + o.y );
+		}
+
+		inline GNC::GCS::Vector operator+(float val, const Vector& o) {
+			return GNC::GCS::Vector( (GNC::GCS::Vector::TComp)val + o.x, (GNC::GCS::Vector::TComp)val + o.y );
+		}
+
+		inline GNC::GCS::Vector operator+(double val, const Vector& o) {
+			return GNC::GCS::Vector( (GNC::GCS::Vector::TComp)val + o.x, (GNC::GCS::Vector::TComp)val + o.y );
+		}
+
+		inline GNC::GCS::Vector operator-(int val, const Vector& o) {
+			return GNC::GCS::Vector( (GNC::GCS::Vector::TComp)val - o.x, (GNC::GCS::Vector::TComp)val - o.y );
+		}
+
+		inline GNC::GCS::Vector operator-(float val, const Vector& o) {
+			return GNC::GCS::Vector( (GNC::GCS::Vector::TComp)val - o.x, (GNC::GCS::Vector::TComp)val - o.y );
+		}
+
+		inline GNC::GCS::Vector operator-(double val, const Vector& o) {
+			return GNC::GCS::Vector( (GNC::GCS::Vector::TComp)val - o.x, (GNC::GCS::Vector::TComp)val - o.y );
+		}
+
+		inline GNC::GCS::Vector operator*(int val, const Vector& o) {
+			return GNC::GCS::Vector( (GNC::GCS::Vector::TComp)val * o.x, (GNC::GCS::Vector::TComp)val * o.y );
+		}
+
+		inline GNC::GCS::Vector operator*(float val, const Vector& o) {
+			return GNC::GCS::Vector( (GNC::GCS::Vector::TComp)val * o.x, (GNC::GCS::Vector::TComp)val * o.y );
+		}
+
+		inline GNC::GCS::Vector operator*(double val, const Vector& o) {
+			return GNC::GCS::Vector( (GNC::GCS::Vector::TComp)val * o.x, (GNC::GCS::Vector::TComp)val * o.y );
+		}
+
+		inline GNC::GCS::Vector operator/(int val, const Vector& o) {
+			return GNC::GCS::Vector( (GNC::GCS::Vector::TComp)val / o.x, (GNC::GCS::Vector::TComp)val / o.y );
+		}
+
+		inline GNC::GCS::Vector operator/(float val, const Vector& o) {
+			return GNC::GCS::Vector( (GNC::GCS::Vector::TComp)val / o.x, (GNC::GCS::Vector::TComp)val / o.y );
+		}
+
+		inline GNC::GCS::Vector operator/(double val, const Vector& o) {
+			return GNC::GCS::Vector( (GNC::GCS::Vector::TComp)val / o.x, (GNC::GCS::Vector::TComp)val / o.y );
+		}
+
 		class  Matriz {
 
 		public:
