@@ -3,7 +3,7 @@
 *  $Id: itool.cpp $
 *  Ginkgo CADx Project
 *
-*  Copyright 2008-12 MetaEmotion S.L. All rights reserved.
+*  Copyright 2008-14 MetaEmotion S.L. All rights reserved.
 *  http://ginkgo-cadx.com
 *
 *  This file is licensed under LGPL v3 license.
@@ -54,7 +54,6 @@ GNC::GCS::ITool::ITool(const ITool::UID& uid, const ITool::TToolFamily& uidFamil
 {
 }
 
-
 GNC::GCS::ITool::~ITool()
 {
 }
@@ -62,8 +61,14 @@ GNC::GCS::ITool::~ITool()
 void GNC::GCS::ITool::AppendToolIn(wxAuiToolBar* pParent)
 {
 	if (AppendsInToolBar()) {
-		pParent->AddTool(this->ID, wxString::FromUTF8(Name.c_str()), Icon, wxString::FromUTF8(Name.c_str()));
-		pParent->SetToolDropDown(this->ID, HasDropDownMenu());
+		if ( HasDropDownMenu()) {
+			pParent->AddTool(this->ID, wxString::FromUTF8(Name.c_str()), Icon, wxString::FromUTF8(Name.c_str()), wxITEM_NORMAL);
+			pParent->SetToolDropDown(this->ID, true);
+		}
+		else {
+			pParent->AddTool(this->ID, wxString::FromUTF8(Name.c_str()), Icon, wxString::FromUTF8(Name.c_str()), wxITEM_CHECK);
+			pParent->SetToolDropDown(this->ID, false);
+		}
 		pParent->EnableTool(this->ID, IsEnabled());
 	}
 }
