@@ -4,7 +4,7 @@
  *  $Id: itool.h $
  *  Ginkgo CADx Project
  *
- *  Copyright 2008-12 MetaEmotion S.L. All rights reserved.
+ *  Copyright 2008-14 MetaEmotion S.L. All rights reserved.
  *  http://ginkgo-cadx.com
  *
  *  This file is licensed under LGPL v3 license.
@@ -61,7 +61,8 @@ namespace GNC {
 				TMenuHerramientas,
 				TMenuHelp,
 				TMenuExport,
-				TMenuPACSAcquisition
+				TMenuPACSAcquisition,
+				TViewOptions
 			} TToolFamily;
 
 			typedef unsigned int UID;
