@@ -3,7 +3,7 @@
 *  $Id: thumbnailscommand.cpp $
 *  Ginkgo CADx Project
 *
-*  Copyright 2008-12 MetaEmotion S.L. All rights reserved.
+*  Copyright 2008-14 MetaEmotion S.L. All rights reserved.
 *  http://ginkgo-cadx.com
 *
 *  This file is licensed under LGPL v3 license.
@@ -191,8 +191,8 @@ namespace GADAPI {
 
 			{
 				//esto es una nyapa para recuperarnos de errores, antes de leer guardamos en bbdd una imagen negra, si finalmente
-				//el thumbnail se genera bien pues se mete, si no pues se quedara negro
-				wxImage img(SIZE_THUMBNAILS,SIZE_THUMBNAILS);
+				//el thumbnail se genera bien pues se mete, si no pues se quedara con unknown
+				wxImage img = GinkgoResourcesManager::History::GetIcoUnknownFile().ConvertToImage();
 				m_pThumbParams->m_wxImg = &img;
 				GuardarImagen();
 				m_pThumbParams->m_wxImg = NULL;
@@ -334,7 +334,7 @@ namespace GADAPI {
 
 					}
 					else {
-						vtkSmartPointer<vtkImageMapToWindowLevelColors> pImageMap = vtkSmartPointer<vtkImageMapToWindowLevelColors>::New();
+						vtkSmartPointer<vtkImageMapToColors> pImageMap = vtkSmartPointer<vtkImageMapToColors>::New();
 
 						pImageMap->SetInputConnection(pReslice->GetOutputPort());
 
@@ -349,8 +349,9 @@ namespace GADAPI {
 						if (timg->GetScalarType() != VTK_UNSIGNED_CHAR) {
 							double window, level;
 							if (loader.GetDefaultWindowLevel(window,level) && window != 0.0) {
-								pImageMap->SetWindow(window);
-								pImageMap->SetLevel(level);
+								double v_min = (level) - 0.5 * window;
+								double v_max = level + 0.5 * window;	
+								pImageMap->GetLookupTable()->SetRange(v_min, v_max);
 							} else {
 								timg->Update();
 								double range[2];
@@ -362,15 +363,15 @@ namespace GADAPI {
 								level = 0.5*(range[1]+range[0]);
 
 								if (diff > std::numeric_limits<double>::epsilon()) {
-									pImageMap->SetWindow(window);
-									pImageMap->SetLevel(level);
+									double v_min = (level) - 0.5 * window;
+									double v_max = level + 0.5 * window;	
+									pImageMap->GetLookupTable()->SetRange(v_min, v_max);
 								}
 							}
 						}
 
 
 						VTK2ITKfiltro->SetInput( pImageMap->GetOutput());
-
 					}
 					NotificarProgreso(0.6f,_Std("Creating Thumbnail..."));
 
@@ -448,6 +449,9 @@ namespace GADAPI {
 			else {
 				m_pThumbParams->m_pNotificadorThumbnail->SetImage(m_pThumbParams->m_file_pk, m_pThumbParams->m_wxImg);
 			}
+		} else {
+			wxImage img =  GinkgoResourcesManager::History::GetIcoUnknownFile().ConvertToImage();
+			m_pThumbParams->m_pNotificadorThumbnail->SetImage(m_pThumbParams->m_file_pk, &img);
 		}
 	}
 
