@@ -923,16 +923,6 @@ void Endpoint::setup_raw(std::string argv0)
 void Endpoint::Initialize()
 {
 
-#ifdef _WIN32
-	WSADATA wsaData;
-    // Need WinSock2 at least for raw sockets
-    if (WSAStartup(MAKEWORD(2, 1), &wsaData) != 0)
-    {
-#ifdef _EP_DEBUG
-        std::cout << "couldn't start!" << std::endl;
-#endif
-    }
-#endif
 }
 
 bool Endpoint::Close()
@@ -1039,10 +1029,6 @@ Endpoint::~Endpoint()
 {
   Close();
   CloseServer();
-#ifdef _WIN32
-  WSACleanup();
-  //g_initialized = false;
-#endif
 }
 
 int Endpoint::SetLastError()
