@@ -3,7 +3,7 @@
 *  $Id: modificacionimagen.h $
 *  Ginkgo CADx Project
 *
-*  Copyright 2008-12 MetaEmotion S.L. All rights reserved.
+*  Copyright 2008-14 MetaEmotion S.L. All rights reserved.
 *  http://ginkgo-cadx.com
 *
 *  This file is licensed under LGPL v3 license.
@@ -43,7 +43,7 @@ namespace GNC {
 				} TipoModificacion;
 
 				// El parametro render indica si en el preprocesado de este evento, se debería apilar o no un render
-				EventoModificacionImagen(GNC::GCS::IVista* pVista = NULL, TipoModificacion tipo = ImagenCargada, int sliceAfectado = -1, bool apilarRender = true) : GNC::GCS::Events::IEvent(ginkgoEVT_Core_ModificacionImagen,0,100,pVista)
+				EventoModificacionImagen(GNC::GCS::IVista* pVista = NULL, TipoModificacion tipo = ImagenCargada, int sliceAfectado = -1, bool apilarRender = true) : GNC::GCS::Events::IEvent(ginkgoEVT_Core_ModificacionImagen, 0, 100, pVista)
 				{
 					m_Nombre = "ModificacionImagen";
 					m_SliceAfectado = sliceAfectado;
@@ -56,6 +56,7 @@ namespace GNC {
 					m_newWindow = 0.0f;
 					m_newLevel = 0.0f;
 					m_resetWL = false;
+					m_resetBC = false;
 					m_resetCurrentPoint = false;
 					m_resetZoom = false;
 					m_resetZoomMode = ZM_CenteredBestFit;
@@ -250,6 +251,11 @@ namespace GNC {
 					return m_resetZoom;
 				}
 
+				inline bool ResetBrightnessContrast()
+				{
+					return m_resetBC;
+				}
+
 				inline ResetZoomMode GetResetZoomMode()
 				{
 					return m_resetZoomMode;
@@ -265,6 +271,11 @@ namespace GNC {
 					m_resetWL = true;
 				}
 
+				inline void EnableResetBrightnessContrast()
+				{
+					m_resetBC = true;
+				}
+
 				inline void EnableAutoCalculeWindowLevel()
 				{
 					m_autoCalculeWL = true;
@@ -300,12 +311,13 @@ namespace GNC {
 				int              m_SliceAfectado;
 				bool             m_ApilarRender;
 				TipoModificacion m_Tipo;
-				double			m_newWindow;
-				double			m_newLevel;
-				bool				m_resetWL;
-				bool				m_resetCurrentPoint;
-				bool				m_resetZoom;
-				bool				m_autoCalculeWL;
+				double			 m_newWindow;
+				double			 m_newLevel;
+				bool             m_resetWL;
+				bool             m_resetBC;
+				bool             m_resetCurrentPoint;
+				bool             m_resetZoom;
+				bool             m_autoCalculeWL;
 				ResetZoomMode    m_resetZoomMode;
 			};
 		}
