@@ -30,6 +30,7 @@ namespace GNC {
 
 namespace GNC {
 	namespace GCS {
+		class Contexto3D;
 
 		class EXTAPI IWidgetsContract : public IContract {
 		public:
@@ -46,6 +47,13 @@ namespace GNC {
 
 			bool Inicializado();
 
+			//Anotation section
+			//this method processes special keys like: ${VOLUME.IDX} ${SLICE.WIDTH}...
+			virtual std::string GetAnnotationValue(GNC::GCS::Contexto3D* c, const std::string& key);
+
+			//return dicom tag value from key
+			virtual std::string GetTagValue(GNC::GCS::Contexto3D* c, const std::string& key);
+
 			virtual vtkGinkgoImageViewer* GetViewerActivo() = 0;
 		};
 	}
