@@ -14,7 +14,7 @@
 #include <api/dicom/dicomdataset.h>
 #include <api/internationalization/internationalization.h>
 #include <vtk/vtkginkgoimageviewer.h>
-#include <main/controllers/hangingprotocolcontroller.h>
+#include <main/controllers/modalitysettingscontroller.h>
 #include <api/iwidgetsmanager.h>
 #include <api/ivista.h>
 #include <api/istudycontext.h>
@@ -199,11 +199,8 @@ void GNC::GCS::IWindowLevelContract::Setup(const GIL::DICOM::DicomDataset& base)
 			}
 		}
 	}
-	GNC::GCS::Ptr<HangingProtocol> tmpHanging = GetManager()->GetVista()->GetEstudio()->hangingProtocol;
-	if (!tmpHanging.IsValid()) {
-		tmpHanging = new GNC::GCS::HangingProtocol();
-	}
-	GNC::GCS::Ptr<DefaultModalitySettings> ptr = tmpHanging->getModalitySettings(modality);
+
+	GNC::GCS::Ptr<DefaultModalitySettings> ptr = GNC::GCS::ModalitySettingsController::Instance()->getModalitySettings(modality);
 	if (ptr.IsValid()) {
 		for (GNC::GCS::DefaultModalitySettings::TListOfWLSettings::const_iterator it  = ptr->getWLSettings().begin(); it != ptr->getWLSettings().end(); ++it)
 		{
