@@ -3,7 +3,7 @@
 *  $Id: ipixelsbluringtool.cpp $
 *  Ginkgo CADx Project
 *
-*  Copyright 2008-12 MetaEmotion S.L. All rights reserved.
+*  Copyright 2008-14 MetaEmotion S.L. All rights reserved.
 *  http://ginkgo-cadx.com
 *
 *  This file is licensed under LGPL v3 license.
@@ -17,6 +17,6 @@
 
 GNC::GCS::ITool::UID GNC::GCS::IPixelsBluringTool::ID = HCore_PixelsBluring;
 
-GNC::GCS::IPixelsBluringTool::IPixelsBluringTool() : ITool(ID, TSeriesMenu,  _Std("Pixels bluring"), GinkgoResourcesManager::ToolIcons::GetIcoDesencajar(),2)
+GNC::GCS::IPixelsBluringTool::IPixelsBluringTool() : ITool(ID, TSeriesMenu,  _Std("Pixels blurring"), GinkgoResourcesManager::ToolIcons::GetIcoDesencajar(),2)
 {
 }
