@@ -4,7 +4,7 @@
 *  $Id: ipixelsbluringtool.h $
 *  Ginkgo CADx Project
 *
-*  Copyright 2008-12 MetaEmotion S.L. All rights reserved.
+*  Copyright 2008-14 MetaEmotion S.L. All rights reserved.
 *  http://ginkgo-cadx.com
 *
 *  This file is licensed under LGPL v3 license.
@@ -13,13 +13,13 @@
 */
 #ifndef IINTERPOLATETOOL_H
 #define IINTERPOLATETOOL_H
-#include <export/contracts/iwidgetscontractable.h>
+#include <export/contracts/ipixelsbluringcontractable.h>
 #include <api/toolsystem/itool.h>
 #include "iherramientascore.h"
 
 namespace GNC {
 	namespace GCS {
-		class EXTAPI IPixelsBluringTool:  public ITool, public IWidgetsContractable
+		class EXTAPI IPixelsBluringTool:  public ITool, public IPixelsBluringContractable
 		{
 		public:
 			static GNC::GCS::ITool::UID ID;
