@@ -3,7 +3,7 @@
 *  $Id: iresettool.cpp $
 *  Ginkgo CADx Project
 *
-*  Copyright 2008-12 MetaEmotion S.L. All rights reserved.
+*  Copyright 2008-14 MetaEmotion S.L. All rights reserved.
 *  http://ginkgo-cadx.com
 *
 *  This file is licensed under LGPL v3 license.
@@ -16,6 +16,6 @@
 
 GNC::GCS::ITool::UID GNC::GCS::IResetTool::ID = HCore_Reset;
 
-GNC::GCS::IResetTool::IResetTool() : ITool(ID, TSeriesMenu,  _Std("Reset window level and zoom"), GinkgoResourcesManager::MenuIcons::GetIcoReset(),2)
+GNC::GCS::IResetTool::IResetTool() : ITool(ID, TSeriesMenu,  _Std("Reset"), GinkgoResourcesManager::MenuIcons::GetIcoReset(),2)
 {
 }
