@@ -16,6 +16,6 @@
 
 GNC::GCS::ITool::UID GNC::GCS::IShowTagsTool::ID = HCore_ShowDicomTags;
 
-GNC::GCS::IShowTagsTool::IShowTagsTool() : ITool(ID, TMenuHerramientas,  _Std("Show / Hide DICOM tags panel"), GinkgoResourcesManager::ToolIcons::GetIcoMostrarOcultarTags())
+GNC::GCS::IShowTagsTool::IShowTagsTool() : ITool(ID, TMenuHerramientas,  _Std("DICOM inspector"), GinkgoResourcesManager::ToolIcons::GetIcoMostrarOcultarTags())
 {
 }
