@@ -3,7 +3,7 @@
 *  $Id: istartdicomizationtool.cpp $
 *  Ginkgo CADx Project
 *
-*  Copyright 2008-12 MetaEmotion S.L. All rights reserved.
+*  Copyright 2008-14 MetaEmotion S.L. All rights reserved.
 *  http://ginkgo-cadx.com
 *
 *  This file is licensed under LGPL v3 license.
@@ -16,6 +16,6 @@
 
 GNC::GCS::ITool::UID GNC::GCS::IStartDicomizationTool::ID = HCore_DicomizeFromView;
 
-GNC::GCS::IStartDicomizationTool::IStartDicomizationTool() : ITool(ID, TMenuArchivo,  _Std("Dicomize images..."), GinkgoResourcesManager::MenuIcons::GetIcoImportar(), 2)
+GNC::GCS::IStartDicomizationTool::IStartDicomizationTool() : ITool(ID, TMenuArchivo,  _Std("Dicomize..."), GinkgoResourcesManager::MenuIcons::GetIcoImportar(), 2)
 {
 }
