@@ -22,6 +22,10 @@
 #include <wx/fileconf.h>
 #include <wx/stdpaths.h>
 #include <wx/file.h>
+#ifdef __WINDOWS__
+#include <wx/msw/private.h>     // includes <windows.h>
+#endif
+
 
 
 namespace GNC {
@@ -67,7 +71,7 @@ namespace GNC {
 			return writeString(TC_General, scope, key, value);
 		}
 
-      bool ConfigurationController::readStringGeneral(const std::string& scope, const std::string& key, std::string& value, const std::string& defaultValue)
+		bool ConfigurationController::readStringGeneral(const std::string& scope, const std::string& key, std::string& value, const std::string& defaultValue)
 		{
 			return readString(TC_General, scope, key, value, defaultValue);
 		}
@@ -116,7 +120,7 @@ namespace GNC {
 		{
 			return deleteEntry(TC_User, scope, key);
 		}
-		
+
 		bool ConfigurationController::writeStringUser(const std::string& scope, const std::string& key, const std::string& value)
 		{
 			return writeString(TC_User, scope, key, value);
@@ -236,15 +240,15 @@ namespace GNC {
 			wxCriticalSectionLocker locker(m_criticalSection);
 			wxConfigBase * config;
 			switch (type) {
-				case TC_User:
-					config = m_pUserConfig;
-					break;
-				case TC_Machine: 
-					config = m_pMachineConfig;
-					break;
-				case TC_General:
-				default:
-					config = m_pGeneralConfig;
+			case TC_User:
+				config = m_pUserConfig;
+				break;
+			case TC_Machine: 
+				config = m_pMachineConfig;
+				break;
+			case TC_General:
+			default:
+				config = m_pGeneralConfig;
 			}
 			if (config == NULL) {
 				return false;
@@ -261,15 +265,15 @@ namespace GNC {
 			wxCriticalSectionLocker locker(m_criticalSection);
 			wxConfigBase * config;
 			switch (type) {
-				case TC_User:
-					config = m_pUserConfig;
-					break;
-				case TC_Machine: 
-					config = m_pMachineConfig;
-					break;
-				case TC_General:
-				default:
-					config = m_pGeneralConfig;
+			case TC_User:
+				config = m_pUserConfig;
+				break;
+			case TC_Machine: 
+				config = m_pMachineConfig;
+				break;
+			case TC_General:
+			default:
+				config = m_pGeneralConfig;
 			}
 			if (config == NULL) {
 				return false;
@@ -286,15 +290,15 @@ namespace GNC {
 			wxCriticalSectionLocker locker(m_criticalSection);
 			wxConfigBase * config;
 			switch (type) {
-				case TC_User:
-					config = m_pUserConfig;
-					break;
-				case TC_Machine: 
-					config = m_pMachineConfig;
-					break;
-				case TC_General:
-				default:
-					config = m_pGeneralConfig;
+			case TC_User:
+				config = m_pUserConfig;
+				break;
+			case TC_Machine: 
+				config = m_pMachineConfig;
+				break;
+			case TC_General:
+			default:
+				config = m_pGeneralConfig;
 			}
 			if (config == NULL) {
 				return false;
@@ -311,23 +315,23 @@ namespace GNC {
 			wxCriticalSectionLocker locker(m_criticalSection);
 			wxConfigBase * config;
 			switch (type) {
-				case TC_User:
-					config = m_pUserConfig;
-					break;
-				case TC_Machine: 
-					config = m_pMachineConfig;
-					break;
-				case TC_General:
-				default:
-					config = m_pGeneralConfig;
+			case TC_User:
+				config = m_pUserConfig;
+				break;
+			case TC_Machine: 
+				config = m_pMachineConfig;
+				break;
+			case TC_General:
+			default:
+				config = m_pGeneralConfig;
 			}
 			if (config == NULL) {
 				return false;
 			}
 			config->SetPath(wxString::FromUTF8(scope.c_str()));
-			
+
 			bool result = config->Read(wxString::FromUTF8(key.c_str()),&value,defaultValue);
-			
+
 			return result;
 		}
 
@@ -336,23 +340,23 @@ namespace GNC {
 			wxCriticalSectionLocker locker(m_criticalSection);
 			wxConfigBase * config;
 			switch (type) {
-				case TC_User:
-					config = m_pUserConfig;
-					break;
-				case TC_Machine: 
-					config = m_pMachineConfig;
-					break;
-				case TC_General:
-				default:
-					config = m_pGeneralConfig;
+			case TC_User:
+				config = m_pUserConfig;
+				break;
+			case TC_Machine: 
+				config = m_pMachineConfig;
+				break;
+			case TC_General:
+			default:
+				config = m_pGeneralConfig;
 			}
 			if (config == NULL) {
 				return false;
 			}
 			config->SetPath(wxString::FromUTF8(scope.c_str()));
-			
+
 			bool result = config->Read(wxString::FromUTF8(key.c_str()),&value,defaultValue);
-			
+
 			return result;
 		}
 
@@ -361,15 +365,15 @@ namespace GNC {
 			wxCriticalSectionLocker locker(m_criticalSection);
 			wxConfigBase * config;
 			switch (type) {
-				case TC_User:
-					config = m_pUserConfig;
-					break;
-				case TC_Machine: 
-					config = m_pMachineConfig;
-					break;
-				case TC_General:
-				default:
-					config = m_pGeneralConfig;
+			case TC_User:
+				config = m_pUserConfig;
+				break;
+			case TC_Machine: 
+				config = m_pMachineConfig;
+				break;
+			case TC_General:
+			default:
+				config = m_pGeneralConfig;
 			}
 			if (config == NULL) {
 				return false;
@@ -386,23 +390,23 @@ namespace GNC {
 			wxCriticalSectionLocker locker(m_criticalSection);
 			wxConfigBase * config;
 			switch (type) {
-				case TC_User:
-					config = m_pUserConfig;
-					break;
-				case TC_Machine: 
-					config = m_pMachineConfig;
-					break;
-				case TC_General:
-				default:
-					config = m_pGeneralConfig;
+			case TC_User:
+				config = m_pUserConfig;
+				break;
+			case TC_Machine: 
+				config = m_pMachineConfig;
+				break;
+			case TC_General:
+			default:
+				config = m_pGeneralConfig;
 			}
 			if (config == NULL) {
 				return false;
 			}
 			config->SetPath(wxString::FromUTF8(scope.c_str()));
-			
+
 			bool result = config->Read(wxString::FromUTF8(key.c_str()),&value,defaultValue);
-			
+
 			return result;
 		}
 
@@ -411,15 +415,15 @@ namespace GNC {
 			wxCriticalSectionLocker locker(m_criticalSection);
 			wxConfigBase * config;
 			switch (type) {
-				case TC_User:
-					config = m_pUserConfig;
-					break;
-				case TC_Machine: 
-					config = m_pMachineConfig;
-					break;
-				case TC_General:
-				default:
-					config = m_pGeneralConfig;
+			case TC_User:
+				config = m_pUserConfig;
+				break;
+			case TC_Machine: 
+				config = m_pMachineConfig;
+				break;
+			case TC_General:
+			default:
+				config = m_pGeneralConfig;
 			}
 			if (config == NULL) {
 				return false;
@@ -436,15 +440,15 @@ namespace GNC {
 			wxCriticalSectionLocker locker(m_criticalSection);
 			wxConfigBase * config;
 			switch (type) {
-				case TC_User:
-					config = m_pUserConfig;
-					break;
-				case TC_Machine: 
-					config = m_pMachineConfig;
-					break;
-				case TC_General:
-				default:
-					config = m_pGeneralConfig;
+			case TC_User:
+				config = m_pUserConfig;
+				break;
+			case TC_Machine: 
+				config = m_pMachineConfig;
+				break;
+			case TC_General:
+			default:
+				config = m_pGeneralConfig;
 			}
 			if (config == NULL) {
 				return false;
@@ -469,15 +473,15 @@ namespace GNC {
 			wxCriticalSectionLocker locker(m_criticalSection);
 			wxConfigBase * config;
 			switch (type) {
-				case TC_User:
-					config = m_pUserConfig;
-					break;
-				case TC_Machine: 
-					config = m_pMachineConfig;
-					break;
-				case TC_General:
-				default:
-					config = m_pGeneralConfig;
+			case TC_User:
+				config = m_pUserConfig;
+				break;
+			case TC_Machine: 
+				config = m_pMachineConfig;
+				break;
+			case TC_General:
+			default:
+				config = m_pGeneralConfig;
 			}
 			if (config == NULL) {
 				return false;
@@ -505,9 +509,207 @@ namespace GNC {
 			return !listOfGroups.empty();
 		}
 
+
+		/**Overwrite wxWidgets home user searching*/
+		wxString GetOverwrittedHomeDir(wxString *pstr)
+		{
+			wxString& strDir = *pstr;
+
+			// first branch is for Cygwin
+#if defined(__UNIX__) && !defined(__WINE__)
+			const wxChar *szHome = wxGetenv(wxT("HOME"));
+			if ( szHome == NULL ) {
+				// we're homeless...
+				//wxLogWarning(_("can't find user's HOME, using current directory."));
+				strDir = wxT(".");
+			}
+			else
+				strDir = szHome;
+
+			// add a trailing slash if needed
+			if ( strDir.Last() != wxT('/') )
+				strDir << wxT('/');
+
+#ifdef __CYGWIN__
+			// Cygwin returns unix type path but that does not work well
+			static wxChar windowsPath[MAX_PATH];
+			cygwin_conv_to_full_win32_path(strDir, windowsPath);
+			strDir = windowsPath;
+#endif
+#elif defined(__WXWINCE__)
+			strDir = wxT("\\");
+#elif defined(__WXWINDOWS__)
+			strDir.clear();
+
+			const wxChar *szHome = wxGetenv(wxT("HOMEDRIVE"));
+			if ( szHome != NULL )
+				strDir << szHome;
+			szHome = wxGetenv(wxT("HOMEPATH"));
+
+			if ( szHome != NULL )
+			{
+				strDir << szHome;
+
+				// the idea is that under NT these variables have default values
+				// of "%systemdrive%:" and "\\". As we don't want to create our
+				// config files in the root directory of the system drive, we will
+				// create it in our program's dir. However, if the user took care
+				// to set HOMEPATH to something other than "\\", we suppose that he
+				// knows what he is doing and use the supplied value.
+				if ( wxStrcmp(szHome, wxT("\\")) == 0 )
+					strDir.clear();
+			} else {
+				if ( strDir.empty() )
+				{
+					// If we have a valid USERPROFILE directory, as is the case in
+					// Windows NT, 2000 and XP, we should use that as our home directory.
+					szHome = wxGetenv(wxT("USERPROFILE"));
+
+					if ( szHome != NULL ) {
+						strDir = szHome;
+					} else {
+						// If we have a valid HOME directory, as is used on many machines that
+						// have unix utilities on them, we should use that.
+						szHome = wxGetenv(wxT("HOME"));
+						if ( szHome != NULL )
+						{
+
+							strDir = szHome;
+						} 
+					}
+				}
+			}				
+
+			if ( !strDir.empty() )
+			{
+				// sometimes the value of HOME may be "%USERPROFILE%", so reexpand the
+				// value once again, it shouldn't hurt anyhow
+				strDir = wxExpandEnvVars(strDir);
+			}
+			else // fall back to the program directory
+			{
+				// extract the directory component of the program file name
+				wxSplitPath(wxGetFullModuleName(), &strDir, NULL, NULL);
+			}
+#else 
+			strDir.clear();
+
+			// If we have a valid HOME directory, as is used on many machines that
+			// have unix utilities on them, we should use that.
+			const wxChar *szHome = wxGetenv(wxT("HOME"));
+
+			if ( szHome != NULL )
+			{
+				strDir = szHome;
+			}
+			else // no HOME, try HOMEDRIVE/PATH
+			{
+				szHome = wxGetenv(wxT("HOMEDRIVE"));
+				if ( szHome != NULL )
+					strDir << szHome;
+				szHome = wxGetenv(wxT("HOMEPATH"));
+
+				if ( szHome != NULL )
+				{
+					strDir << szHome;
+
+					// the idea is that under NT these variables have default values
+					// of "%systemdrive%:" and "\\". As we don't want to create our
+					// config files in the root directory of the system drive, we will
+					// create it in our program's dir. However, if the user took care
+					// to set HOMEPATH to something other than "\\", we suppose that he
+					// knows what he is doing and use the supplied value.
+					if ( wxStrcmp(szHome, wxT("\\")) == 0 )
+						strDir.clear();
+				}
+			}
+
+			if ( strDir.empty() )
+			{
+				// If we have a valid USERPROFILE directory, as is the case in
+				// Windows NT, 2000 and XP, we should use that as our home directory.
+				szHome = wxGetenv(wxT("USERPROFILE"));
+
+				if ( szHome != NULL )
+					strDir = szHome;
+			}
+
+			if ( !strDir.empty() )
+			{
+				// sometimes the value of HOME may be "%USERPROFILE%", so reexpand the
+				// value once again, it shouldn't hurt anyhow
+				strDir = wxExpandEnvVars(strDir);
+			}
+			else // fall back to the program directory
+			{
+				// extract the directory component of the program file name
+				wxSplitPath(wxGetFullModuleName(), &strDir, NULL, NULL);
+			}
+#endif  // UNIX
+
+			return strDir.c_str();
+		}
+
+		wxString GetOverwrittedLocalDir()
+		{
+			wxString strDir;
+
+#if defined(__WXMAC__) || defined(__DOS__)
+			// no local dir concept on Mac OS 9 or MS-DOS
+			strDir << GetGlobalDir() ;
+#else
+			GetOverwrittedHomeDir(&strDir);
+
+#ifdef  __UNIX__
+			if (
+				(strDir.Last() != wxT('/'))
+#ifdef __VMS
+				&& (strDir.Last() != wxT(']'))
+#endif
+				)
+				strDir << wxT('/');
+#else
+			if (strDir.Last() != wxT('\\'))
+				strDir << wxT('\\');
+#endif
+#endif
+
+			return strDir;
+		}
+		wxString GetLocalFileName(const wxString& appName)
+		{
+#ifdef __VMS__
+			// On VMS I saw the problem that the home directory was appended
+			// twice for the configuration file. Does that also happen for
+			// other platforms?
+			wxString str = wxT( '.' );
+#else
+			wxString str = GetOverwrittedLocalDir();
+#endif
+
+#if defined( __UNIX__ ) && !defined( __VMS ) && !defined( __WXMAC__ )
+			str << wxT('.');
+#endif
+
+			str << appName;
+
+#if defined(__WINDOWS__) || defined(__DOS__)
+			if ( wxStrchr(appName, wxT('.')) == NULL )
+				str << wxT(".ini");
+#endif
+
+#ifdef __WXMAC__
+			str << wxT(" Preferences") ;
+#endif
+
+			return str;
+		}
+
+
 		ConfigurationController::ConfigurationController() 
 		{			
-			m_pUserConfig = new wxFileConfig(wxT("GinkgoUser"), wxT("Metaemotion"),wxEmptyString,wxEmptyString,wxCONFIG_USE_LOCAL_FILE );
+			wxString localFileconfig = GetLocalFileName(wxT("GinkgoUser"));
+			m_pUserConfig = new wxFileConfig(wxT("GinkgoUser"), wxT("Metaemotion"), localFileconfig,wxEmptyString,wxCONFIG_USE_LOCAL_FILE );
 			m_pathUserConfig = m_pGeneralConfig->GetLocalFileName(wxT("GinkgoUser"));
 
 			wxString pathEjecutable = wxStandardPaths::Get().GetExecutablePath();
@@ -528,8 +730,8 @@ namespace GNC {
 						m_pGeneralConfig = new wxFileConfig(wxEmptyString,wxEmptyString,m_pathGlobalConfig,wxEmptyString,wxCONFIG_USE_LOCAL_FILE);
 					} else {
 						//se inicializa el fichero de propiedades
-						m_pGeneralConfig = new wxFileConfig(wxT("Ginkgo"), wxT("Metaemotion"),wxEmptyString,wxEmptyString,wxCONFIG_USE_LOCAL_FILE );
-						m_pathGlobalConfig = m_pGeneralConfig->GetLocalFileName(wxT("Ginkgo"));
+						m_pathGlobalConfig = GetLocalFileName(wxT("Ginkgo"));
+						m_pGeneralConfig = new wxFileConfig(wxT("Ginkgo"), wxT("Metaemotion"),m_pathGlobalConfig,wxEmptyString,wxCONFIG_USE_LOCAL_FILE );
 					}
 				}
 			}
