@@ -83,7 +83,7 @@ GIL::HL7::ControladorBBDDHl7::ControladorBBDDHl7()
 				//se escribe en tmp...
 				LOG_WARN("Core/BBDD", "No tiene permisos para escribir en el directorio del usuario, se corre el riesgo de no enviar todos los mensajes Hl7")
 				std::ostringstream ostr2;
-				ostr2 << GNC::Entorno::Instance()->GetGinkgoTempDir() << (char)wxFileName::GetPathSeparator(wxPATH_NATIVE) << "ginkgodatabasehl7.db"<<std::ends;
+				ostr2 << GNC::Entorno::Instance()->GetGinkgoTempDir() << (char)wxFileName::GetPathSeparator(wxPATH_NATIVE) << "ginkgodatabasehl7.db";
 				pathFicheroDB = ostr2.str();
 			}
 		}
