@@ -3,7 +3,7 @@
 *  $Id: controladorextensiones.cpp 4943 2012-06-20 12:51:12Z carlos $
 *  Ginkgo CADx Project
 *
-*  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
+*  Copyright 2008-13 MetaEmotion S.L. All rights reserved.
 *  http://ginkgo-cadx.com
 *
 *  This file is licensed under LGPL v3 license.
@@ -51,7 +51,7 @@ PrivateExtension* init_VisualizatorExtension();
 /*
 PrivateExtension* init_LightVisualizatorExtension(); TODO*/ 
 PrivateExtension* init_OfthalmologicExtension();
-PrivateExtension* init_MPRExtension();
+PrivateExtension* init_RadiologicalExtension();
 PrivateExtension* init_DermatologyExtension();
 #endif
 
@@ -464,7 +464,7 @@ void GADVAPI::PrivateExtensionManager::Scan()
 		base[pExt->getSid()] = pExt;
 
 		pExt = new PrivateExtensionWrapper();
-		pExt->Load(init_MPRExtension());
+		pExt->Load(init_RadiologicalExtension());
 		base[pExt->getSid()] = pExt;
 
 		pExt = new PrivateExtensionWrapper();
