@@ -59,22 +59,6 @@
 #define LO_ATT_WIDTH wxT("width")
 #define LO_ATT_HEIGHT wxT("height")
 
-#define ML_ROOT wxT("modality-list")
-#define DMS_ROOT wxT("def-mod-settings")
-#define DMS_ATT_MODALITY wxT("modality")
-#define DMS_ATT_INITIAL_WL wxT("initial-wl")
-#define DMS_ATT_INTERPOLATION wxT("interpolation-mode")
-#define DMS_ATT_INT_NEAREST wxT("nearest-neighbour")
-#define DMS_ATT_LINEAR wxT("linear")
-#define DMS_ATT_CUBIC wxT("cubic")
-
-#define WLS_ROOT wxT("window-levels")
-#define WL_ROOT wxT("window-level")
-#define WL_ATT_WINDOW wxT("window")
-#define WL_ATT_LEVEL wxT("level")
-#define WL_ATT_LABEL wxT("label")
-
-
 #define MC_ROOT wxT("matcher")
 #define MC_ATT_CRITERIA wxT("criteria")
 
@@ -599,231 +583,11 @@ void GNC::GCS::Layout::applyWindowProperties(GNC::GCS::IVista* pView)
 		}
 	}
 }
-/////////////////////////////////////////////////////////////
-GNC::GCS::WindowLevelSetting::WindowLevelSetting(): window(0), level(127), label(_Std("Default"))
-{
-}
-
-GNC::GCS::WindowLevelSetting::WindowLevelSetting(double window, double level, const std::string& label)
-{
-	this->window = window;
-	this->level = level;
-	this->label = label;
-}
-
-GNC::GCS::WindowLevelSetting::WindowLevelSetting(wxXmlNode* wlNode)
-{
-	wlNode->GetAttribute(WL_ATT_WINDOW, wxEmptyString).ToDouble(&this->window);
-	wlNode->GetAttribute(WL_ATT_LEVEL, wxEmptyString).ToDouble(&this->level);
-	this->label = wlNode->GetAttribute(WL_ATT_LABEL, wxEmptyString).ToUTF8();
-}
-
-GNC::GCS::WindowLevelSetting::WindowLevelSetting(const WindowLevelSetting& other)
-{
-	window = other.window;
-	level = other.level;
-	label = other.label;
-}
-
-GNC::GCS::WindowLevelSetting::~WindowLevelSetting()
-{
-}
-
-wxXmlNode* GNC::GCS::WindowLevelSetting::serialize()
-{
-	wxXmlNode* wlNode = new wxXmlNode(NULL, wxXML_ELEMENT_NODE, WL_ROOT);
-	wlNode->AddAttribute(WL_ATT_WINDOW, wxString::Format(wxT("%lf"),this->window));
-	wlNode->AddAttribute(WL_ATT_LEVEL, wxString::Format(wxT("%lf"),this->level));
-	wlNode->AddAttribute(WL_ATT_LABEL, wxString::FromUTF8(this->label.c_str()));	
-
-	return wlNode;
-}
-
-double GNC::GCS::WindowLevelSetting::getWindow() const
-{
-	return window;
-}
-
-double GNC::GCS::WindowLevelSetting::getLevel() const
-{
-	return level;
-}
-
-const std::string& GNC::GCS::WindowLevelSetting::getLabel() const
-{
-	return label;
-}
-
-std::string GNC::GCS::WindowLevelSetting::toString() const
-{
-	std::ostringstream ostr;
-	ostr << std::setiosflags(std::ios::fixed) << std::setprecision(2);
-	ostr << "(";
-	ostr << window;
-	ostr << "/";
-	ostr << level;
-	ostr << ")";
-	ostr << label;
-	return ostr.str();
-}
-
-void GNC::GCS::WindowLevelSetting::setWindow(double window)
-{
-	this->window = window;
-}
-
-void GNC::GCS::WindowLevelSetting::setLevel(double level)
-{
-	this->level = level;
-}
-
-void GNC::GCS::WindowLevelSetting::setLabel(const std::string& label)
-{
-	this->label = label;
-}
-/////////////////////////////////////////////////////
-GNC::GCS::DefaultModalitySettings::DefaultModalitySettings()
-{
-	this->interpolationMode = TIM_LINEAR;
-}
-
-GNC::GCS::DefaultModalitySettings::DefaultModalitySettings(wxXmlNode* defaultSettingsNode)
-{
-	this->modality = defaultSettingsNode->GetAttribute(DMS_ATT_MODALITY, wxEmptyString).ToUTF8();
-	this->initialWindowLevelLabel = defaultSettingsNode->GetAttribute(DMS_ATT_INITIAL_WL, wxEmptyString).ToUTF8();
-	wxString strInterpolation = defaultSettingsNode->GetAttribute(DMS_ATT_INTERPOLATION, wxEmptyString);
-	if (strInterpolation.CompareTo(DMS_ATT_INT_NEAREST) == 0) {
-		interpolationMode = TIM_NEAREST_NEIGHBOUR;
-	} else if (strInterpolation.CompareTo(DMS_ATT_LINEAR) == 0) {
-		interpolationMode = TIM_LINEAR;
-	} else if (strInterpolation.CompareTo(DMS_ATT_CUBIC) == 0) {
-		interpolationMode = TIM_CUBIC;
-	}
-	
-	for (wxXmlNode* child = defaultSettingsNode->GetChildren(); child != NULL; child = child->GetNext())
-	{
-		if (child->GetName().CmpNoCase(WLS_ROOT) == 0) {
-			//layouts...
-			for (wxXmlNode* wlChild = child->GetChildren(); wlChild != NULL; wlChild = wlChild->GetNext()) {
-				if (wlChild->GetName().CmpNoCase(WL_ROOT) == 0) {
-					GNC::GCS::Ptr<WindowLevelSetting> pWL(new WindowLevelSetting(wlChild));
-					this->addWindowLevel(pWL);
-				}
-			}			
-		}  else {
-			LOG_ERROR("HangingProtocol", "error deserializing DefaultModalitySettings, unknown node " << child->GetName().ToUTF8());
-		}
-	}
-}
-
-GNC::GCS::DefaultModalitySettings::DefaultModalitySettings(const DefaultModalitySettings& other)
-{
-	this->modality = other.modality;
-	this->initialWindowLevelLabel = other.initialWindowLevelLabel;
-	this->interpolationMode = other.interpolationMode;
-	for (GNC::GCS::DefaultModalitySettings::TListOfWLSettings::const_iterator it = other.listOfWLSettings.begin(); it != other.listOfWLSettings.end(); ++it) {
-		if ((*it).IsValid()) {
-			GNC::GCS::Ptr<GNC::GCS::WindowLevelSetting> settings(new GNC::GCS::WindowLevelSetting(*(*it)));
-			this->listOfWLSettings.push_back(settings);
-		}
-	}
-}
-
-GNC::GCS::DefaultModalitySettings::~DefaultModalitySettings()
-{
-}
-
-wxXmlNode* GNC::GCS::DefaultModalitySettings::serialize()
-{
-	wxXmlNode* defaultSettingsNode = new wxXmlNode(NULL, wxXML_ELEMENT_NODE, DMS_ROOT);
-	defaultSettingsNode->AddAttribute(DMS_ATT_MODALITY, wxString::FromUTF8(this->modality.c_str()));
-	defaultSettingsNode->AddAttribute(DMS_ATT_INITIAL_WL, wxString::FromUTF8(this->initialWindowLevelLabel.c_str()));
-	wxString strInterpolation;
-	switch (interpolationMode) {
-	case TIM_NEAREST_NEIGHBOUR:
-		strInterpolation = DMS_ATT_INT_NEAREST;
-		break;
-	case TIM_LINEAR:
-		strInterpolation = DMS_ATT_LINEAR;
-		break;
-	case TIM_CUBIC:
-		strInterpolation = DMS_ATT_CUBIC;
-		break;
-	}
-	defaultSettingsNode->AddAttribute(DMS_ATT_INTERPOLATION, strInterpolation );
-
-	wxXmlNode* wlSettingsNode = new wxXmlNode(defaultSettingsNode, wxXML_ELEMENT_NODE, WLS_ROOT);
-	for (GNC::GCS::DefaultModalitySettings::TListOfWLSettings::const_iterator it = listOfWLSettings.begin(); it != listOfWLSettings.end(); ++it) {
-		if ((*it).IsValid()) {
-			wlSettingsNode->AddChild((*it)->serialize());
-		}
-	} 
-
-	return defaultSettingsNode;
-}
-
-std::string GNC::GCS::DefaultModalitySettings::getDefaultWindowLevelLabel()
-{
-	return _Std("Default");
-}
-
-std::string GNC::GCS::DefaultModalitySettings::getAutocalculateWindowLevelLabel()
-{
-	return _Std("Autocalculate");
-}
-
-const GNC::GCS::DefaultModalitySettings::TListOfWLSettings& GNC::GCS::DefaultModalitySettings::getWLSettings() const
-{
-	return listOfWLSettings;
-}
-
-const std::string& GNC::GCS::DefaultModalitySettings::getModality() const
-{
-	return modality;
-}
-
-const std::string& GNC::GCS::DefaultModalitySettings::getInitialWindowLevelLabel() const
-{
-	return initialWindowLevelLabel;
-}
-
-GNC::GCS::DefaultModalitySettings::TInterpolationMode GNC::GCS::DefaultModalitySettings::getInterpolationMode() const
-{
-	return interpolationMode;
-}
-
-void GNC::GCS::DefaultModalitySettings::addWindowLevel(const GNC::GCS::Ptr<WindowLevelSetting>& wlSetting)
-{
-	if (wlSetting.IsValid()) {
-		listOfWLSettings.push_back(wlSetting);
-	}
-}
-
-void GNC::GCS::DefaultModalitySettings::clearWindowLevels()
-{
-	listOfWLSettings.clear();
-}
-
-void GNC::GCS::DefaultModalitySettings::setModality(const std::string& modality)
-{
-	this->modality = modality;
-}
-
-void GNC::GCS::DefaultModalitySettings::setInitialWindowLevelLabel(const std::string& label)
-{
-	this->initialWindowLevelLabel = label;
-}
-
-void GNC::GCS::DefaultModalitySettings::setInterpolationMode(TInterpolationMode mode)
-{
-	this->interpolationMode = mode;
-}
 
 
 /////////////////////////////////////////////////////
 GNC::GCS::HangingProtocol::HangingProtocol():active(true)
 {
-	LoadDefaultModalitySettings();
 }
 
 GNC::GCS::HangingProtocol::HangingProtocol(wxXmlNode* hangingNode)
@@ -852,14 +616,7 @@ GNC::GCS::HangingProtocol::HangingProtocol(wxXmlNode* hangingNode)
 			//retrocompatib...
 			GNC::GCS::Ptr<Layout> pLayout(new Layout(child));
 			this->addLayout(pLayout);
-		} else if (child->GetName().CmpNoCase(ML_ROOT) == 0)  {
-			for (wxXmlNode* modChild = child->GetChildren(); modChild != NULL; modChild = modChild->GetNext()) {
-				if (modChild->GetName().CmpNoCase(DMS_ROOT) == 0) {
-					GNC::GCS::Ptr<DefaultModalitySettings> modSettings(new DefaultModalitySettings(modChild));
-					this->addModalitySettings(modSettings);
-				}
-			}
-		} else if (child->GetName().CmpNoCase(MC_ROOT) == 0) {
+		}  else if (child->GetName().CmpNoCase(MC_ROOT) == 0) {
 			this->studyMatcher = new Matcher(child);
 		} else if (child->GetName().CmpNoCase(PROPERTY_NODE) == 0) {
 			const wxString key = child->GetAttribute(PROPERTY_KEY, wxEmptyString);
@@ -871,8 +628,6 @@ GNC::GCS::HangingProtocol::HangingProtocol(wxXmlNode* hangingNode)
 			LOG_ERROR("HangingProtocol", "error deserializing hanging protocol, unknown node " << child->GetName().ToUTF8());
 		}
 	}
-	//retrocompatibility
-	LoadDefaultModalitySettings();
 }
 
 GNC::GCS::HangingProtocol::HangingProtocol(const GNC::GCS::HangingProtocol& other)
@@ -890,12 +645,6 @@ GNC::GCS::HangingProtocol::HangingProtocol(const GNC::GCS::HangingProtocol& othe
 			this->layouts.push_back(layout);
 		}
 	}
-	for (GNC::GCS::HangingProtocol::TMapOfModalitySettings::const_iterator it = other.modalitySettings.begin(); it != other.modalitySettings.end(); ++it) {
-		if ((*it).second.IsValid()) {
-			GNC::GCS::Ptr<GNC::GCS::DefaultModalitySettings> settings(new GNC::GCS::DefaultModalitySettings(*((*it).second)));
-			this->modalitySettings[(*it).first] = settings;
-		}
-	}
 	this->properties = other.properties;
 	this->active = other.active;
 }
@@ -905,138 +654,6 @@ GNC::GCS::HangingProtocol::~HangingProtocol()
 	active = true;
 }
 
-void GNC::GCS::HangingProtocol::LoadDefaultModalitySettings()
-{
-	//basic modality settings....
-	if (modalitySettings.find("CT") == modalitySettings.end()) 
-	{
-		GNC::GCS::Ptr<GNC::GCS::DefaultModalitySettings> modSettings(new GNC::GCS::DefaultModalitySettings());
-		modSettings->setModality("CT");
-		{
-			GNC::GCS::Ptr<GNC::GCS::WindowLevelSetting> wlSettings(new GNC::GCS::WindowLevelSetting(300,35,_Std("SPINAL")));
-			modSettings->addWindowLevel(wlSettings);
-		}
-		{
-			GNC::GCS::Ptr<GNC::GCS::WindowLevelSetting> wlSettings(new GNC::GCS::WindowLevelSetting(100,50,_Std("CRANIUM")));
-			modSettings->addWindowLevel(wlSettings);
-		}
-		{
-			GNC::GCS::Ptr<GNC::GCS::WindowLevelSetting> wlSettings(new GNC::GCS::WindowLevelSetting(1800,400,_Std("BONE")));
-			modSettings->addWindowLevel(wlSettings);
-		}
-		{
-			GNC::GCS::Ptr<GNC::GCS::WindowLevelSetting> wlSettings(new GNC::GCS::WindowLevelSetting(3600,1000,_Std("CRANIUM BONE")));
-			modSettings->addWindowLevel(wlSettings);
-		}
-		{
-			GNC::GCS::Ptr<GNC::GCS::WindowLevelSetting> wlSettings(new GNC::GCS::WindowLevelSetting(400,40,_Std("MEDIASTINUM")));
-			modSettings->addWindowLevel(wlSettings);
-		}
-		{
-			GNC::GCS::Ptr<GNC::GCS::WindowLevelSetting> wlSettings(new GNC::GCS::WindowLevelSetting(1500,-500,_Std("LUNG")));
-			modSettings->addWindowLevel(wlSettings);
-		}
-		{
-			GNC::GCS::Ptr<GNC::GCS::WindowLevelSetting> wlSettings(new GNC::GCS::WindowLevelSetting(2200,200,_Std("BREAST")));
-			modSettings->addWindowLevel(wlSettings);
-		}
-		{
-			GNC::GCS::Ptr<GNC::GCS::WindowLevelSetting> wlSettings(new GNC::GCS::WindowLevelSetting(2000,350,_Std("VERTEBRA")));
-			modSettings->addWindowLevel(wlSettings);
-		}
-		addModalitySettings(modSettings);
-	}
-	if (modalitySettings.find("MR") == modalitySettings.end()) 
-	{
-		GNC::GCS::Ptr<GNC::GCS::DefaultModalitySettings> modSettings(new GNC::GCS::DefaultModalitySettings());
-		modSettings->setModality("MR");
-		{
-			GNC::GCS::Ptr<GNC::GCS::WindowLevelSetting> wlSettings(new GNC::GCS::WindowLevelSetting(1600,678,_Std("ANGIO")));
-			modSettings->addWindowLevel(wlSettings);
-		}
-		{
-			GNC::GCS::Ptr<GNC::GCS::WindowLevelSetting> wlSettings(new GNC::GCS::WindowLevelSetting(150,500,_Std("CT CRANIUM")));
-			modSettings->addWindowLevel(wlSettings);
-		}
-		{
-			GNC::GCS::Ptr<GNC::GCS::WindowLevelSetting> wlSettings(new GNC::GCS::WindowLevelSetting(750,400,_Std("T1 CRANIUM")));
-			modSettings->addWindowLevel(wlSettings);
-		}
-		{
-			GNC::GCS::Ptr<GNC::GCS::WindowLevelSetting> wlSettings(new GNC::GCS::WindowLevelSetting(563,33,_Std("T2 CRANIUM")));
-			modSettings->addWindowLevel(wlSettings);
-		}
-		{
-			GNC::GCS::Ptr<GNC::GCS::WindowLevelSetting> wlSettings(new GNC::GCS::WindowLevelSetting(2030,1245,_Std("KNEE")));
-			modSettings->addWindowLevel(wlSettings);
-		}
-		addModalitySettings(modSettings);
-	}
-	
-	if (modalitySettings.find("CR") == modalitySettings.end()) 
-	{
-		GNC::GCS::Ptr<GNC::GCS::DefaultModalitySettings> modSettings(new GNC::GCS::DefaultModalitySettings());
-		modSettings->setModality("CR");
-		addModalitySettings(modSettings);
-	}
-	
-	if (modalitySettings.find("US") == modalitySettings.end()) 
-	{
-		GNC::GCS::Ptr<GNC::GCS::DefaultModalitySettings> modSettings(new GNC::GCS::DefaultModalitySettings());
-		modSettings->setModality("US");
-		addModalitySettings(modSettings);
-	}
-	
-	if (modalitySettings.find("MG") == modalitySettings.end()) 
-	{
-		GNC::GCS::Ptr<GNC::GCS::DefaultModalitySettings> modSettings(new GNC::GCS::DefaultModalitySettings());
-		modSettings->setModality("MG");
-		addModalitySettings(modSettings);
-	}
-	
-	if (modalitySettings.find("NM") == modalitySettings.end()) 
-	{
-		GNC::GCS::Ptr<GNC::GCS::DefaultModalitySettings> modSettings(new GNC::GCS::DefaultModalitySettings());
-		modSettings->setModality("NM");
-		addModalitySettings(modSettings);
-	}
-	
-	if (modalitySettings.find("RF") == modalitySettings.end()) 
-	{
-		GNC::GCS::Ptr<GNC::GCS::DefaultModalitySettings> modSettings(new GNC::GCS::DefaultModalitySettings());
-		modSettings->setModality("RF");
-		addModalitySettings(modSettings);
-	}
-	
-	if (modalitySettings.find("SC") == modalitySettings.end()) 
-	{
-		GNC::GCS::Ptr<GNC::GCS::DefaultModalitySettings> modSettings(new GNC::GCS::DefaultModalitySettings());
-		modSettings->setModality("SC");
-		addModalitySettings(modSettings);
-	}
-		
-	if (modalitySettings.find("XA") == modalitySettings.end()) 
-	{
-		GNC::GCS::Ptr<GNC::GCS::DefaultModalitySettings> modSettings(new GNC::GCS::DefaultModalitySettings());
-		modSettings->setModality("XA");
-		addModalitySettings(modSettings);
-	}
-		
-	if (modalitySettings.find("OT") == modalitySettings.end()) 
-	{
-		GNC::GCS::Ptr<GNC::GCS::DefaultModalitySettings> modSettings(new GNC::GCS::DefaultModalitySettings());
-		modSettings->setModality("OT");
-		addModalitySettings(modSettings);
-	}
-		
-	if (modalitySettings.find("PT") == modalitySettings.end()) 
-	{
-		GNC::GCS::Ptr<GNC::GCS::DefaultModalitySettings> modSettings(new GNC::GCS::DefaultModalitySettings());
-		modSettings->setModality("PT");
-		addModalitySettings(modSettings);
-	}
-
-}
 
 wxXmlNode* GNC::GCS::HangingProtocol::serialize()
 {
@@ -1053,12 +670,6 @@ wxXmlNode* GNC::GCS::HangingProtocol::serialize()
 			layoutsNode->AddChild((*it)->serialize());
 		}
 	} 
-	wxXmlNode* modalitySettingsNode = new wxXmlNode(hangingNode, wxXML_ELEMENT_NODE, ML_ROOT);
-	for (GNC::GCS::HangingProtocol::TMapOfModalitySettings::const_iterator it = modalitySettings.begin(); it != modalitySettings.end(); ++it) {
-		if ((*it).second.IsValid()) {
-			modalitySettingsNode->AddChild((*it).second->serialize());
-		}
-	} 
 	if (this->studyMatcher.IsValid()) {
 		hangingNode->AddChild(this->studyMatcher->serialize());
 	}
@@ -1151,32 +762,6 @@ void GNC::GCS::HangingProtocol::clearLayouts()
 	this->layouts.clear();
 }
 
-const GNC::GCS::HangingProtocol::TMapOfModalitySettings& GNC::GCS::HangingProtocol::getModalitySettingsMap()
-{
-	return this->modalitySettings;
-}
-
-void GNC::GCS::HangingProtocol::addModalitySettings(const GNC::GCS::Ptr<DefaultModalitySettings>& settings)
-{
-	if (settings.IsValid()) {
-		this->modalitySettings[settings->getModality()] = settings;
-	}
-}
-
-void GNC::GCS::HangingProtocol::clearModalitySettings()
-{
-	this->modalitySettings.clear();
-}
-
-GNC::GCS::Ptr<GNC::GCS::DefaultModalitySettings> GNC::GCS::HangingProtocol::getModalitySettings(const std::string& modality)
-{
-	GNC::GCS::Ptr<GNC::GCS::DefaultModalitySettings> ptr;
-	if (modalitySettings.find(modality) != modalitySettings.end()) {
-		ptr = modalitySettings[modality];
-	}
-	return ptr;
-}
-
 std::map<std::string, std::string>& GNC::GCS::HangingProtocol::getProperties()
 {
 	return this->properties;
