@@ -503,11 +503,11 @@ std::string GNC::GCS::HistoryController::GetGinkgoDicomDir(bool barraAlFinal)
 	}
 }
 
-std::string GNC::GCS::HistoryController::GetDefaultDicomDirPath()
+std::string GNC::GCS::HistoryController::GetDefaultDicomDirPath(bool ignoreConfig)
 {
 	std::string value;
 	std::string path;
-	if(!GNC::GCS::ConfigurationController::Instance()->readStringUser("/GinkgoCore/Estacion", "DicomDir", value))
+	if(ignoreConfig || !GNC::GCS::ConfigurationController::Instance()->readStringUser("/GinkgoCore/Estacion", "DicomDir", value))
 	{
 		std::ostringstream out;
 		if (GNC::GCS::IControladorPermisos::Instance()->Get("core.restrictions", "anonymous_history")) {
