@@ -26,6 +26,8 @@
 #include "controladorhl7.h"
 #include "configurationcontroller.h"
 #include <commands/cloudcommand.h>
+#include <commands/pacsdownloadcommand.h>
+#include <commands/acquirefromurlcommand.h>
 #include <api/integration/dict.h>
 #include <api/dicom/dcmdictionary.h>
 #include <main/controllers/controladorpermisos.h>
@@ -34,7 +36,6 @@
 #include <main/gui/acquisition/downloadagaindialog.h>
 #include <main/gui/mainwindow/ventanaprincipal.h>
 #include <main/entorno.h>
-#include <commands/pacsdownloadcommand.h>
 #include <eventos/integration.h>
 #include <main/controllers/parserxmlenglish.h>
 #include <main/controllers/parserxmlspanish.h>
@@ -43,6 +44,8 @@
 #include <wx/sstream.h>
 #include <wx/tokenzr.h>
 
+#include <main/controllers/anonusagestats.h>
+
 GIL::IntegrationController* GIL::IntegrationController::m_pInstance = 0;
 
 GIL::IXMLIntegrationParser::~IXMLIntegrationParser()
@@ -121,6 +124,7 @@ bool GIL::IntegrationController::Process(GIL::IntegrationModelList& models)
 			modelo->atendido = true;
 		}
 		if(modelo->accion == GIL::IModeloIntegracion::TA_Dicomizar) {
+			LOG_STAT(ANON_STAT_INT_DICOMIZE)
 			//se busca el dicomizador del modulo indicado, habra un mapa que transformara sid en uids de modulo
 			std::string uidModulo("");
 			if (modelo->idPlantilla != "") {
@@ -153,40 +157,52 @@ bool GIL::IntegrationController::Process(GIL::IntegrationModelList& models)
 		}
 		else if(modelo->accion == GIL::IModeloIntegracion::TA_Obtener) 
 		{
-			GADAPI::PACSDownloadCommandParams * pParams = NULL;
-			std::string tag;
-			if (!modelo->TagsDICOMOverwrite.getTag("0008|0052", tag)) {
-				//show only acquisition form
-				GNC::Entorno::Instance()->GetVentanaPrincipal()->MostrarVentana();	
-				GNC::GUI::DialogoAdquisicion::Instance()->Show(modelo->GlobalVariables.GetValue(GKDI_PATIENT_ID), modelo->GlobalVariables.GetValue(GKDI_GLOBAL_PACS_RETRIEVE_SID));
-				numProcessed++;
-			} else {
-				GIL::DICOM::DicomDataset base = modelo->TagsDICOMOverwrite;
-				std::string qrlevel, uid;
-				base.getTag(GKDCM_QueryRetrieveLevel,qrlevel);
-				if (qrlevel == "STUDY" && base.getTag(GKDCM_StudyInstanceUID, uid) && GNC::GCS::HistoryController::Instance()->ExistsStudyWithUID(uid)) {
-					GNC::GUI::DownloadAgainDialog dlg(GNC::Entorno::Instance()->GetVentanaRaiz(), uid, false);
-					int answer = dlg.ShowModal();
-					if (answer != wxID_OK) {
-						continue;
-					}
-				} else if (qrlevel == "SERIES" && base.getTag(GKDCM_SeriesInstanceUID, uid) && GNC::GCS::HistoryController::Instance()->ExistsSeriesWithUID(uid)) {
-					GNC::GUI::DownloadAgainDialog dlg(GNC::Entorno::Instance()->GetVentanaRaiz(), uid, false);
-					int answer = dlg.ShowModal();
-					if (answer != wxID_OK) {
-						continue;
-					}
-				}
-				pParams = new GADAPI::PACSDownloadCommandParams(modelo->GlobalVariables.GetValue(GKDI_GLOBAL_PACS_RETRIEVE_SID), base);
-
-				GADAPI::PACSDownloadCommand* pComandoPACS = new GADAPI::PACSDownloadCommand(pParams);
-				GNC::Entorno::Instance()->GetCommandController()->ProcessAsync("Descargando PACS...",pComandoPACS, NULL);
+			LOG_STAT(ANON_STAT_INT_RETRIEVE)
+			//if wado retrieve...
+			if (!modelo->Files.empty()) {
+				//retrieve files downloading as wado files using acquirefromurl command
+				GADAPI::AcquireFromURLCommandParameters* pCmdParams = new GADAPI::AcquireFromURLCommandParameters(modelo->Files);
+				GADAPI::AcquireFromURLCommand* pCmd = new GADAPI::AcquireFromURLCommand(pCmdParams);
+				GNC::Entorno::Instance()->GetCommandController()->ProcessAsync("Downloading files...",pCmd, NULL);
 				GNC::Entorno::Instance()->GetVentanaPrincipal()->MostrarVentana();
-				numProcessed++;
-			} 
+				numProcessed++;				
+			} else {
+				GADAPI::PACSDownloadCommandParams * pParams = NULL;
+				std::string tag;
+				if (!modelo->TagsDICOMOverwrite.getTag("0008|0052", tag)) {
+					//show only acquisition form
+					GNC::Entorno::Instance()->GetVentanaPrincipal()->MostrarVentana();	
+					GNC::GUI::DialogoAdquisicion::Instance()->Show(modelo->GlobalVariables.GetValue(GKDI_PATIENT_ID), modelo->GlobalVariables.GetValue(GKDI_GLOBAL_PACS_RETRIEVE_SID));
+					numProcessed++;
+				} else {
+					GIL::DICOM::DicomDataset base = modelo->TagsDICOMOverwrite;
+					std::string qrlevel, uid;
+					base.getTag(GKDCM_QueryRetrieveLevel,qrlevel);
+					if (qrlevel == "STUDY" && base.getTag(GKDCM_StudyInstanceUID, uid) && GNC::GCS::HistoryController::Instance()->ExistsStudyWithUID(uid)) {
+						GNC::GUI::DownloadAgainDialog dlg(GNC::Entorno::Instance()->GetVentanaRaiz(), uid, false);
+						int answer = dlg.ShowModal();
+						if (answer != wxID_OK) {
+							continue;
+						}
+					} else if (qrlevel == "SERIES" && base.getTag(GKDCM_SeriesInstanceUID, uid) && GNC::GCS::HistoryController::Instance()->ExistsSeriesWithUID(uid)) {
+						GNC::GUI::DownloadAgainDialog dlg(GNC::Entorno::Instance()->GetVentanaRaiz(), uid, false);
+						int answer = dlg.ShowModal();
+						if (answer != wxID_OK) {
+							continue;
+						}
+					}
+					pParams = new GADAPI::PACSDownloadCommandParams(modelo->GlobalVariables.GetValue(GKDI_GLOBAL_PACS_RETRIEVE_SID), base);
+
+					GADAPI::PACSDownloadCommand* pComandoPACS = new GADAPI::PACSDownloadCommand(pParams);
+					GNC::Entorno::Instance()->GetCommandController()->ProcessAsync("Descargando PACS...",pComandoPACS, NULL);
+					GNC::Entorno::Instance()->GetVentanaPrincipal()->MostrarVentana();
+					numProcessed++;
+				} 
+			}
 		}
 		else if(modelo->accion == GIL::IModeloIntegracion::TA_Open) 
 		{
+			LOG_STAT(ANON_STAT_INT_OPEN)
 			for (GIL::IModeloIntegracion::ListOfPaths::iterator itFile = modelo->Files.begin(); itFile != modelo->Files.end(); ++itFile) 
 			{
 				wxFileName fileName(wxString::FromUTF8((*itFile).c_str()));
@@ -595,20 +611,22 @@ void GIL::IntegrationController::ParsearModeloIntegracion(GIL::IntegrationModelL
 		if (absoluteFile.FileExists()) {
 			absoluteFile = absoluteFile.GetPath();
 		}
-
 		for (GIL::IntegrationModelList::iterator it = modelos.begin(); it != modelos.end(); ++it) {
 			GNC::GCS::Ptr<GIL::IModeloIntegracion>& modelo = (*it);
-			GIL::IModeloIntegracion::ListOfPaths absoluteFiles;
-			for (GIL::IModeloIntegracion::ListOfPaths::iterator itFile = modelo->Files.begin(); itFile != modelo->Files.end(); ++itFile) 
-			{
-				wxFileName fileName(wxString::FromUTF8((*itFile).c_str()));
-				if (fileName.IsRelative() && absoluteFile.IsOk()) {
-					fileName.MakeAbsolute(absoluteFile.GetFullPath());
-				}						
-				std::string pathStd(fileName.GetFullPath().ToUTF8());
-				absoluteFiles.push_back(pathStd);
+			//if action is open... absolutize files
+			if (modelo->accion == GIL::IModeloIntegracion::TA_Open) {
+				GIL::IModeloIntegracion::ListOfPaths absoluteFiles;
+				for (GIL::IModeloIntegracion::ListOfPaths::iterator itFile = modelo->Files.begin(); itFile != modelo->Files.end(); ++itFile) 
+				{
+					wxFileName fileName(wxString::FromUTF8((*itFile).c_str()));
+					if (fileName.IsRelative() && absoluteFile.IsOk()) {
+						fileName.MakeAbsolute(absoluteFile.GetFullPath());
+					}						
+					std::string pathStd(fileName.GetFullPath().ToUTF8());
+					absoluteFiles.push_back(pathStd);
+				}
+				modelo->Files = absoluteFiles;
 			}
-			modelo->Files = absoluteFiles;
 		}
 
 	} else {
@@ -620,6 +638,7 @@ void GIL::IntegrationController::ParsearModeloIntegracion(GIL::IntegrationModelL
 
 std::string GIL::IntegrationController::ParsesModelFromURL(const wxString& url) const
 {
+	LOG_STAT(ANON_STAT_INT_URL)
 	//parse ginkgo cloud uris
 	if (url.StartsWith(wxT("ginkgocadx://cloud:"))) {
 		GNC::GCS::CloudGetCommandParams* pParams = new GNC::GCS::CloudGetCommandParams(std::string(url.SubString(19, url.size() - 1).ToUTF8()), true);
