@@ -1613,12 +1613,15 @@ namespace GIL {
 				ostr << server->GetWADOURI();
 				if (server->GetWADOURI().find("?") == std::string::npos) {
 					ostr << "?";
+				} else {
+					ostr << "&";
 				}
-				ostr << "requestType=WADO&contentType=application%2Fdicom&studyUID=" << studyInstanceUID;
+				ostr << "requestType=WADO&contentType=application/dicom&studyUID=" << studyInstanceUID;
 				ostr << "&seriesUID=" << seriesInstanceUID;
 				ostr << "&objectUID=" << (*itSopInstances);
 				std::string url = ostr.str();
 
+				LOG_DEBUG("DownloadWADOImages", "Downloading url: " << url)
 				if (link && curr > 1) {
 					//link it
 					const IModeloSerie* pSeries;
