@@ -342,6 +342,8 @@ GIL::IModeloIntegracion* GIL::ParserXMLEnglish::ParseGnkWorkflow(wxXmlNode* nodo
 		}		
 	}
 
+	modelo->GlobalVariables.InsertVariable(GKDI_HCE_ID, "defaultHCE");
+
 	//recorremos los hijos de las gnkworkflows
 	for (wxXmlNode* hijo = nodo->GetChildren(); hijo != NULL; hijo = hijo->GetNext()) {
 		//files...
@@ -459,10 +461,7 @@ GIL::IModeloIntegracion* GIL::ParserXMLEnglish::ParseGnkWorkflow(wxXmlNode* nodo
 				LOG_DEBUG("ParserXMLEnglish","application id unespecified, using \"defaultHCE\"");
 				modelo->GlobalVariables.InsertVariable(GKDI_HCE_ID, "defaultHCE");
 			}
-		} else {
-			LOG_DEBUG("ParserXMLEnglish","application id unespecified, using \"defaultHCE\"");
-			modelo->GlobalVariables.InsertVariable(GKDI_HCE_ID, "defaultHCE");
-		}
+		} 
 
 		if (hijo->GetName().CmpNoCase(wxT("metadata")) == 0) {
 			std::string codigo;
@@ -545,7 +544,7 @@ GIL::IModeloIntegracion* GIL::ParserXMLEnglish::ParseGnkWorkflow(wxXmlNode* nodo
 			LOG_DEBUG("ParserXMLEnglish", "\"petition-id\" attribute not specified");
 		}
 	} else if (modelo->accion == GIL::IModeloIntegracion::TA_Obtener) {
-		if (modelo->TagsDICOMOverwrite.tags.empty()) {
+		if (modelo->TagsDICOMOverwrite.tags.empty() && modelo->Files.empty()) {
 			throw IntegrationException(_Std("You must specify attributes you want to use in the query"), xpp, "CONF/template");
 		}
 	}
