@@ -3,7 +3,7 @@
  *  $Id: streamingloader.cpp $
  *  Ginkgo CADx Project
  *
- *  Copyright 2008-12 MetaEmotion S.L. All rights reserved.
+ *  Copyright 2008-14 MetaEmotion S.L. All rights reserved.
  *  http://ginkgo-cadx.com
  *
  *  This file is licensed under LGPL v3 license.
@@ -42,7 +42,6 @@
 #endif
 
 #include <vtkImageData.h>
-#include <vtkImageDataStreamer.h>
 
 #include <itkImage.h>
 
@@ -57,8 +56,8 @@
 #include <vtkAlgorithmOutput.h>
 #include <vtkImageChangeInformation.h>
 
-
 //#define DEBUG_PRINT_DIR_COSINES
+#define USE_STREAMING true
 
 class CargaItkProgressCallback : public itk::Command
 {
@@ -74,6 +73,7 @@ public:
 
 	/** Standard Command virtual methods */
 	void Execute(itk::Object *caller, const itk::EventObject &event){
+		return;
 		itk::ProcessObject* po = dynamic_cast<itk::ProcessObject*>(caller);
 		if( !po )
 			return;
@@ -98,6 +98,7 @@ public:
 	}
 
 	void Execute(const itk::Object *caller, const itk::EventObject &event){
+		return;
 		itk::ProcessObject* po = dynamic_cast<itk::ProcessObject*>( const_cast<itk::Object*>(caller));
 
 		if( !po ) return;
@@ -160,10 +161,9 @@ GNC::StreamingLoader::StreamingLoader(): DirectionCosines(GNC::GCS::IGinkgoMatri
 	//Esto da leaks no activar
 	//m_IO->SetLoadSequences(false);
 	//
-	m_IO->SetUseStreamedReading(true);
+	m_IO->SetUseStreamedReading(USE_STREAMING);
 	m_IO->SetMaxSizeLoadEntry(1024); // No permitir cargar campos de mas de 1K
 	m_pOutput = vtkSmartPointer<vtkImageChangeInformation>::New();
-	//m_pOutput->SetNumberOfStreamDivisions(1);
 
 	m_CurrentNumberOfComponents = 0;
 	m_CurrentComponentType      = ImageIO::UNKNOWNCOMPONENTTYPE;
@@ -262,21 +262,54 @@ void GNC::StreamingLoader::SetInput(const std::string& fichero)
 			itk::MetaDataDictionary& dict = m_IO->GetMetaDataDictionary();
 			if (dict.HasKey("0028|0107") && dict.HasKey( "0028|0103") && dict.HasKey("0028|0102")) {
 				//get highBit
-				if(itk::MetaDataObject <std::string> * highBit =dynamic_cast<itk::MetaDataObject <std::string> *>(dict["0028|0102"].GetPointer())) 
+				if(itk::MetaDataObject<std::string>* highBit = dynamic_cast<itk::MetaDataObject <std::string> *>(dict["0028|0102"].GetPointer())) 
 				{
-					//get largest value
-					if(itk::MetaDataObject <std::string> * largestValue =dynamic_cast<itk::MetaDataObject <std::string> *>(dict["0028|0107"].GetPointer())) 
+					if(itk::MetaDataObject<std::string>* bitsStored = dynamic_cast<itk::MetaDataObject <std::string> *>(dict["0028|0101"].GetPointer())) 
 					{
-						//get pixel representation
-						if(itk::MetaDataObject <std::string> * pixelRepresentation =dynamic_cast<itk::MetaDataObject <std::string> *>(dict["0028|0103"].GetPointer())) 
+						//get largest value
+						if(itk::MetaDataObject<std::string>* largestValue = dynamic_cast<itk::MetaDataObject <std::string> *>(dict["0028|0107"].GetPointer())) 
 						{
-							if (pixelRepresentation->GetMetaDataObjectValue() == "1") {//if its signed and largest value > (2^highbit)-1
-								if (atoi(largestValue->GetMetaDataObjectValue().c_str()) > (pow((double)2, atoi(highBit->GetMetaDataObjectValue().c_str())) -1)) {
-									throw GNC::GCS::ControladorCargaException( _Std("Error reading the study: Largest image pixel value data is not coherent with combination of Pixel Representation and High bit") , "ControladorCarga/CargaMultidimensional");
-								}					 
-							} else {
-								if (atoi(largestValue->GetMetaDataObjectValue().c_str()) > (pow((double)2, atoi(highBit->GetMetaDataObjectValue().c_str())+1) -1)) {
-									throw GNC::GCS::ControladorCargaException( _Std("Error reading the study: Largest image pixel value data is not coherent with combination of Pixel Representation and High bit") , "ControladorCarga/CargaMultidimensional");
+							//get pixel representation
+							if(itk::MetaDataObject<std::string>* pixelRepresentation = dynamic_cast<itk::MetaDataObject <std::string> *>(dict["0028|0103"].GetPointer())) 
+							{
+								long long minimum = 0;
+								double rescaleIntercept = 0.0;
+								double rescaleSlope = 1.0;
+								long long paddingValue = 0;
+
+								if(itk::MetaDataObject<std::string>* minimiumValue = dynamic_cast<itk::MetaDataObject<std::string>*>(dict["0028|0106"].GetPointer()))  {
+									minimum = (long long) atol(minimiumValue->GetMetaDataObjectValue().c_str());
+								}
+								if(itk::MetaDataObject<std::string>* rescaleInterceptValue = dynamic_cast<itk::MetaDataObject <std::string>*>(dict["0028|1052"].GetPointer()))  {
+									rescaleIntercept = (double) atof( rescaleInterceptValue->GetMetaDataObjectValue().c_str() );
+								}
+								if(itk::MetaDataObject <std::string> * rescaleSlopeValue = dynamic_cast<itk::MetaDataObject <std::string>*>(dict["0028|1053"].GetPointer()))  {
+									rescaleSlope = (double) atof(rescaleSlopeValue->GetMetaDataObjectValue().c_str());
+								}
+								if(itk::MetaDataObject <std::string> * pixelPaddingValue = dynamic_cast<itk::MetaDataObject <std::string>*>(dict["0028|0120"].GetPointer()))  {
+									paddingValue = (double) atol(pixelPaddingValue->GetMetaDataObjectValue().c_str());
+								}
+								if(itk::MetaDataObject <std::string> * pixelPaddingRangeLimitValue = dynamic_cast<itk::MetaDataObject <std::string>*>(dict["0028|0121"].GetPointer()))  {
+									std::string val = pixelPaddingRangeLimitValue->GetMetaDataObjectValue();
+									LOG_TRACE("ControladorCarga/CargaMultidimensional", "Pixel Padding Range Limit: " << val);
+								}
+
+								if (pixelRepresentation->GetMetaDataObjectValue() == "1") {//if its signed and largest value > (2^highbit)-1
+									long long exp = (long long) atol(bitsStored->GetMetaDataObjectValue().c_str());
+									long long limit = (1L << (exp-1));
+									long long val = (long long) atol(largestValue->GetMetaDataObjectValue().c_str());
+									long long maxVal = val;//(long long) (  (val * rescaleSlope) + rescaleIntercept );
+									if (maxVal > limit ) {
+										throw GNC::GCS::ControladorCargaException( _Std("Error reading the study: Largest image pixel value data is not coherent with combination of Pixel Representation and High bit") , "ControladorCarga/CargaMultidimensional");
+									}					 
+								} else {
+									long long exp = (long long) atol(bitsStored->GetMetaDataObjectValue().c_str());
+									long long limit = (1L << (exp));
+									long long val = (long long) atol(largestValue->GetMetaDataObjectValue().c_str());
+									long long maxVal = val; //(long long) (  (val * rescaleSlope) + rescaleIntercept );
+									if (maxVal > limit  ) {
+										throw GNC::GCS::ControladorCargaException( _Std("Error reading the study: Largest image pixel value data is not coherent with combination of Pixel Representation and High bit") , "ControladorCarga/CargaMultidimensional");
+									}
 								}
 							}
 						}
@@ -576,21 +609,7 @@ void GNC::StreamingLoader::SetInput(const std::string& fichero)
 	}
 }
 
-void GNC::StreamingLoader::Update()
-{
-	m_pOutput->Update();
-}
 
-void GNC::StreamingLoader::UpdateInformation()
-{
-	m_pOutput->UpdateInformation();
-}
-
-void GNC::StreamingLoader::SetCustomOrientation(GNC::GCS::Vector3D&, GNC::GCS::Vector3D&, GNC::GCS::Vector3D&, double&)
-{
-
-}
-		
 
 vtkSmartPointer<vtkAlgorithmOutput> GNC::StreamingLoader::GetOutputPort()
 {
@@ -607,20 +626,83 @@ void GNC::StreamingLoader::GetOutputCopy(vtkSmartPointer<vtkImageData>& output)
 
 }
 
-void GNC::StreamingLoader::GetDimensions(int dimensions[3])
+//------------------------------------------------------------------------------------------------
+//region IPipelineProperties realization
+
+void GNC::StreamingLoader::Update()
 {
-	for (int i = 0; i < 3; i++)
-		dimensions[i] = m_CurrentDimensions[i];
+	m_pOutput->Update();
 }
 
-void GNC::StreamingLoader::GetOutputDimensions(int currentDimensions[3])
+void GNC::StreamingLoader::UpdateInformation()
+{
+	m_pOutput->UpdateInformation();
+}
+
+const GNC::GCS::Ptr<GNC::GCS::IGinkgoMatrix4x4> GNC::StreamingLoader::GetDirection()
+{
+	return DirectionCosines;
+}
+
+void GNC::StreamingLoader::GetOrigin(double origin[3])
+{
+	for (int i = 0; i < 3; i++) {
+		origin[i] = m_Origin[i];
+	}
+}
+
+void GNC::StreamingLoader::GetSpacing(double spacing[3])
+{
+	for (int i = 0; i < 3; i++) {
+		spacing[i] = m_Spacing[i];
+	}
+}
+
+void GNC::StreamingLoader::GetDimensions(int dimensions[3])
+{
+	for (int i = 0; i < 3; i++) {
+		dimensions[i] = m_CurrentDimensions[i];
+	}
+}
+
+const GNC::GCS::Ptr<GNC::GCS::IGinkgoMatrix4x4> GNC::StreamingLoader::GetOutputDirection()
+{
+	return GetDirection();
+}
+
+void GNC::StreamingLoader::GetOutputOrigin(double origin[3])
+{
+	m_pOutput->GetOutputOrigin(origin);
+}
+
+void GNC::StreamingLoader::GetOutputSpacing(double spacing[3])
+{
+	m_pOutput->GetOutputSpacing(spacing);
+}
+
+void GNC::StreamingLoader::GetOutputDimensions(int dims[3])
 {
 	for (int i = 0; i<3; ++i)
 	{
-		currentDimensions[i] = m_CurrentDimensions[i];
+		dims[i] = m_CurrentDimensions[i];
 	}
 }
 
+//endregion
+
+void GNC::StreamingLoader::SetOutputSpacing(double spacing[3])
+{
+	if (spacing[0] <= 0 || spacing[1] <= 0) {
+		spacing[0] = spacing[1] = 1.0;
+	}
+	m_pOutput->SetOutputSpacing(spacing);
+}
+
+void GNC::StreamingLoader::SetOutputOrigin(double origin[3])
+{
+	m_pOutput->SetOutputOrigin(origin);
+}
+
 bool GNC::StreamingLoader::GetDefaultWindowLevel(double &window, double &level)
 {
 	std::string windowTag, levelTag;
@@ -638,51 +720,6 @@ bool GNC::StreamingLoader::GetDefaultWindowLevel(double &window, double &level)
 	return ok;	
 }
 
-const GNC::GCS::Ptr<GNC::GCS::IGinkgoMatrix4x4> GNC::StreamingLoader::GetDirection()
-{
-	return DirectionCosines;
-}
-
-void GNC::StreamingLoader::GetOrigin(double origin[3])
-{
-	for (int i = 0; i < 3; i++)
-		origin[i] = m_Origin[i];
-}
-
-void GNC::StreamingLoader::GetSpacing(double spacing[3])
-{
-	for (int i = 0; i < 3; i++)
-		spacing[i] = m_Spacing[i];
-}
-
-void GNC::StreamingLoader::SetOutputSpacing(double spacing[3])
-{
-	if (spacing[0] <= 0 || spacing[1] <= 0) {
-		spacing[0] = spacing[1] = 1.0;
-	}
-	m_pOutput->SetOutputSpacing(spacing);
-}
-
-void GNC::StreamingLoader::SetOutputOrigin(double origin[3])
-{
-	m_pOutput->SetOutputOrigin(origin);
-}
-
-void GNC::StreamingLoader::GetOutputOrigin(double origin[3])
-{
-	m_pOutput->GetOutputOrigin(origin);
-}
-
-void GNC::StreamingLoader::GetOutputSpacing(double spacing[3])
-{
-	m_pOutput->GetOutputSpacing(spacing);
-}
-
-int GNC::StreamingLoader::GetCurrentSliceIndex()  const
-{
-	return 0;
-}
-
 std::string GNC::StreamingLoader::GetPatientPosition()
 {
 	std::string patientPositionTag;
@@ -753,7 +790,7 @@ void GNC::StreamingLoader::RecomponerPipeline()
 		pIO->SetLoadPrivateTags(false);
 		//Esto da leaks no activar
 		//pIO->SetLoadSequences(false);
-		pIO->SetUseStreamedReading(true);
+		pIO->SetUseStreamedReading(USE_STREAMING);
 		pIO->SetMaxSizeLoadEntry(1024); // No permitir cargar campos de mas de 1K
 		switch(m_IO->GetNumberOfComponents()) {
 			case 1:
@@ -776,10 +813,9 @@ void GNC::StreamingLoader::RecomponerPipeline()
 
 								reader->SetImageIO(pIO);
 								reader->SetFileName(m_CurrentFile);
-								reader->SetUseStreaming(true);
+								reader->SetUseStreaming(USE_STREAMING);
 								m_pOutput->SetInputConnection(joiner->GetImporter()->GetOutputPort());
 								//reader->GetOutput()->ReleaseDataFlagOn();
-
 							}
 							break;
 						case ImageIO::CHAR:
@@ -799,7 +835,7 @@ void GNC::StreamingLoader::RecomponerPipeline()
 
 								reader->SetImageIO(pIO);
 								reader->SetFileName(m_CurrentFile);
-								reader->SetUseStreaming(true);
+								reader->SetUseStreaming(USE_STREAMING);
 								m_pOutput->SetInputConnection(joiner->GetImporter()->GetOutputPort());
 								//reader->GetOutput()->ReleaseDataFlagOn();
 							}
@@ -822,9 +858,9 @@ void GNC::StreamingLoader::RecomponerPipeline()
 
 								reader->SetImageIO(pIO);
 								reader->SetFileName(m_CurrentFile);
-								reader->SetUseStreaming(true);
+								reader->SetUseStreaming(USE_STREAMING);
 								m_pOutput->SetInputConnection(joiner->GetImporter()->GetOutputPort());
-
+								//reader->GetOutput()->ReleaseDataFlagOn();
 							}
 							break;
 						case ImageIO::SHORT:
@@ -844,8 +880,7 @@ void GNC::StreamingLoader::RecomponerPipeline()
 
 								reader->SetImageIO(pIO);
 								reader->SetFileName(m_CurrentFile);
-								reader->SetUseStreaming(true);
-								
+								reader->SetUseStreaming(USE_STREAMING);
 								m_pOutput->SetInputConnection(joiner->GetImporter()->GetOutputPort());
 								//reader->GetOutput()->ReleaseDataFlagOn();
 
@@ -868,7 +903,7 @@ void GNC::StreamingLoader::RecomponerPipeline()
 
 								reader->SetImageIO(pIO);
 								reader->SetFileName(m_CurrentFile);
-								reader->SetUseStreaming(true);
+								reader->SetUseStreaming(USE_STREAMING);
 								m_pOutput->SetInputConnection(joiner->GetImporter()->GetOutputPort());
 								//reader->GetOutput()->ReleaseDataFlagOn();
 							}
@@ -890,7 +925,7 @@ void GNC::StreamingLoader::RecomponerPipeline()
 
 								reader->SetImageIO(pIO);
 								reader->SetFileName(m_CurrentFile);
-								reader->SetUseStreaming(true);
+								reader->SetUseStreaming(USE_STREAMING);
 								m_pOutput->SetInputConnection(joiner->GetImporter()->GetOutputPort());
 								//reader->GetOutput()->ReleaseDataFlagOn();
 							}
@@ -912,10 +947,9 @@ void GNC::StreamingLoader::RecomponerPipeline()
 
 								reader->SetImageIO(pIO);
 								reader->SetFileName(m_CurrentFile);
-								reader->SetUseStreaming(true);
+								reader->SetUseStreaming(USE_STREAMING);
 								m_pOutput->SetInputConnection(joiner->GetImporter()->GetOutputPort());
 								//reader->GetOutput()->ReleaseDataFlagOn();
-
 							}
 							break;
 						case ImageIO::LONG:
@@ -935,7 +969,7 @@ void GNC::StreamingLoader::RecomponerPipeline()
 
 								reader->SetImageIO(pIO);
 								reader->SetFileName(m_CurrentFile);
-								reader->SetUseStreaming(true);
+								reader->SetUseStreaming(USE_STREAMING);
 								m_pOutput->SetInputConnection(joiner->GetImporter()->GetOutputPort());
 								//reader->GetOutput()->ReleaseDataFlagOn();
 							}
@@ -957,7 +991,7 @@ void GNC::StreamingLoader::RecomponerPipeline()
 
 								reader->SetImageIO(pIO);
 								reader->SetFileName(m_CurrentFile);
-								reader->SetUseStreaming(true);
+								reader->SetUseStreaming(USE_STREAMING);
 								m_pOutput->SetInputConnection(joiner->GetImporter()->GetOutputPort());
 								//reader->GetOutput()->ReleaseDataFlagOn();
 							}
@@ -979,7 +1013,7 @@ void GNC::StreamingLoader::RecomponerPipeline()
 
 								reader->SetImageIO(pIO);
 								reader->SetFileName(m_CurrentFile);
-								reader->SetUseStreaming(true);
+								reader->SetUseStreaming(USE_STREAMING);
 								m_pOutput->SetInputConnection(joiner->GetImporter()->GetOutputPort());
 								//reader->GetOutput()->ReleaseDataFlagOn();
 							}
@@ -1011,8 +1045,9 @@ void GNC::StreamingLoader::RecomponerPipeline()
 
 								reader->SetImageIO(pIO);
 								reader->SetFileName(m_CurrentFile);
-								reader->SetUseStreaming(true);
+								reader->SetUseStreaming(USE_STREAMING);
 								m_pOutput->SetInputConnection(joiner->GetImporter()->GetOutputPort());
+								//reader->GetOutput()->ReleaseDataFlagOn();
 							}
 							break;
 						case ImageIO::CHAR:
@@ -1034,7 +1069,7 @@ void GNC::StreamingLoader::RecomponerPipeline()
 
 								reader->SetImageIO(pIO);
 								reader->SetFileName(m_CurrentFile);
-								reader->SetUseStreaming(true);
+								reader->SetUseStreaming(USE_STREAMING);
 								m_pOutput->SetInputConnection(joiner->GetImporter()->GetOutputPort());
 								//reader->GetOutput()->ReleaseDataFlagOn();
 							}
@@ -1058,7 +1093,7 @@ void GNC::StreamingLoader::RecomponerPipeline()
 							
 							reader->SetImageIO(pIO);
 							reader->SetFileName(m_CurrentFile);
-							reader->SetUseStreaming(true);
+							reader->SetUseStreaming(USE_STREAMING);
 							m_pOutput->SetInputConnection(joiner->GetImporter()->GetOutputPort());
 							//reader->GetOutput()->ReleaseDataFlagOn();
 						}
@@ -1082,7 +1117,7 @@ void GNC::StreamingLoader::RecomponerPipeline()
 							
 							reader->SetImageIO(pIO);
 							reader->SetFileName(m_CurrentFile);
-							reader->SetUseStreaming(true);
+							reader->SetUseStreaming(USE_STREAMING);
 							m_pOutput->SetInputConnection(joiner->GetImporter()->GetOutputPort());
 							//reader->GetOutput()->ReleaseDataFlagOn();
 						}
@@ -1106,7 +1141,7 @@ void GNC::StreamingLoader::RecomponerPipeline()
 							
 							reader->SetImageIO(pIO);
 							reader->SetFileName(m_CurrentFile);
-							reader->SetUseStreaming(true);
+							reader->SetUseStreaming(USE_STREAMING);
 							m_pOutput->SetInputConnection(joiner->GetImporter()->GetOutputPort());
 							//reader->GetOutput()->ReleaseDataFlagOn();
 						}
@@ -1130,7 +1165,7 @@ void GNC::StreamingLoader::RecomponerPipeline()
 							
 							reader->SetImageIO(pIO);
 							reader->SetFileName(m_CurrentFile);
-							reader->SetUseStreaming(true);
+							reader->SetUseStreaming(USE_STREAMING);
 							m_pOutput->SetInputConnection(joiner->GetImporter()->GetOutputPort());
 							//reader->GetOutput()->ReleaseDataFlagOn();
 						}
@@ -1154,7 +1189,7 @@ void GNC::StreamingLoader::RecomponerPipeline()
 							
 							reader->SetImageIO(pIO);
 							reader->SetFileName(m_CurrentFile);
-							reader->SetUseStreaming(true);
+							reader->SetUseStreaming(USE_STREAMING);
 							m_pOutput->SetInputConnection(joiner->GetImporter()->GetOutputPort());
 							//reader->GetOutput()->ReleaseDataFlagOn();
 						}
@@ -1178,7 +1213,7 @@ void GNC::StreamingLoader::RecomponerPipeline()
 							
 							reader->SetImageIO(pIO);
 							reader->SetFileName(m_CurrentFile);
-							reader->SetUseStreaming(true);
+							reader->SetUseStreaming(USE_STREAMING);
 							m_pOutput->SetInputConnection(joiner->GetImporter()->GetOutputPort());
 							//reader->GetOutput()->ReleaseDataFlagOn();
 						}
