@@ -52,6 +52,8 @@
 #include <eventos/progresocomando.h>
 #include <commands/pacsdownloadcommand.h>
 
+#include <main/controllers/anonusagestats.h>
+
 #define SIZE_ICONOS 16
 
 #define ICONO_ESTUDIO 0
@@ -177,6 +179,7 @@ GNC::GUI::DialogoAdquisicion::~DialogoAdquisicion()
 
 bool GNC::GUI::DialogoAdquisicion::Show(const std::string& idPatient, const std::string& idPACS)
 {
+	LOG_STAT(ANON_STAT_DLG_PACS_SEARCH)
 	CenterOnParent();
 	m_pTextControlField->Show(true);
 	m_pFieldCombo->Show(true);
@@ -1018,11 +1021,7 @@ void GNC::GUI::DialogoAdquisicion::PACSCargarListado(IModeloDicom * pModelo)
 			wxTreeItemId estudioTreeId;
 			wxTreeItemId serieTreeId;
 
-			if (m_pComandoPACS->m_pPACSParams->m_error.size() > 0) {
-				m_pComandoPACS = NULL;
-				return;
-			}
-			else if(pModelo->ListaPacientes().size() == 0){
+			if(pModelo->ListaPacientes().size() == 0){
 				if (!m_pComandoPACS->EstaAbortado()) {
 					LimpiarBusquedas(false);
 					wxTreeItemId topTreeId = m_pTreeListResultados->GetRootItem();
