@@ -38,9 +38,10 @@ namespace GNC {
 			virtual void OnCheckInstituciones( wxCommandEvent& event );
 			virtual void OnCheckPhysician( wxCommandEvent& event );
 			virtual void OnCheckComentarios( wxCommandEvent& event );
+			virtual void OnAddNewTag( wxCommandEvent &evt);
 
 			void Anonymize(const std::string& clave, bool anonimizar);
-			void Anonymize(const std::string& clave, bool anonimizar, const std::string& value);
+			void Anonymize(const std::string& clave, bool anonimizar, const std::string& value, bool anonymizeIfNotExists = true);
 			void RemoveFromTable(const std::string& clave);
 
 			void OnPropertyChanged(wxPropertyGridEvent& event);
