@@ -598,177 +598,7 @@ namespace GNC {
 					GNC::GCS::ModoControlador::T_HangingProtocolSupportLevel hangingSupportLevel;
 				};//end StudyWindow
 
-			class ModalityPanel: public ModalityPanelBase
-			{
-			public:
-				class AddWindowLevelDialog: public AddWLDialogBase
-				{
-				public:
-					AddWindowLevelDialog(ModalityPanel* pParent): AddWLDialogBase(pParent),
-						Parent(pParent), 
-						EditMode(false)
-					{
-					}
-
-					AddWindowLevelDialog(ModalityPanel* pParent, const wxString& label, const wxString& window, const wxString& level): 
-						AddWLDialogBase(pParent),
-						Parent(pParent),
-						EditMode(true)
-					{
-						m_pLabel->SetValue(label);
-						m_pWindow->SetValue(window);
-						m_pLevel->SetValue(level);
-					}
-
-					virtual bool Validate()
-					{
-						if (m_pLabel->GetValue().empty() || m_pWindow->GetValue().empty() || m_pLevel->GetValue().empty()) {
-							wxMessageBox(_("You must fill in all fields"),_("Info"),wxOK | wxICON_INFORMATION, this);
-							return false;
-						} else {
-							double window, level;
-							if (m_pWindow->GetValue().ToDouble(&window) && m_pLevel->GetValue().ToDouble(&level)) {
-								if (!EditMode && Parent->m_pDefaultWindowLevel->FindString(m_pLabel->GetValue()) > 0) {
-									wxMessageBox(_("Window/level label in use"),_("Info"),wxOK | wxICON_INFORMATION, this);
-									return false;
-								}
-								return true;
-							} else {
-								wxMessageBox(_("Fill in valid numbers in window and level fields."),_("Info"),wxOK | wxICON_INFORMATION, this);
-								return false;
-							}
-						}
-					}
-
-					ModalityPanel* Parent;
-					bool EditMode;
-				};
-
-
-				ModalityPanel(wxWindow* pParent, const GNC::GCS::Ptr<GNC::GCS::DefaultModalitySettings>& lo): ModalityPanelBase(pParent),
-						modSettings(lo)
-				{
-				}
-
-				void InitPanels()
-				{
-					
-					wxTreeItemId idRoot = m_pWLList->AddRoot(wxT("Root"));
-					for (GNC::GCS::DefaultModalitySettings::TListOfWLSettings::const_iterator it = modSettings->getWLSettings().begin(); it != modSettings->getWLSettings().end(); ++it)
-					{
-						wxTreeItemId idItem = m_pWLList->AppendItem(m_pWLList->GetRootItem(),wxString::FromUTF8((*it)->getLabel().c_str()));
-						m_pWLList->SetItemText(idItem, COL_WINDOW_ID, wxString::Format(wxT("%.2lf"), (*it)->getWindow()));
-						m_pWLList->SetItemText(idItem, COL_LEVEL_ID, wxString::Format(wxT("%.2lf"), (*it)->getLevel()));
-					}
-					RebuildComboWL();
-					m_pChoiceInterpolate->Append(_("Nearest neighbour"));
-					m_pChoiceInterpolate->Append(_("Linear"));
-					m_pChoiceInterpolate->Append(_("Cubic"));
-					if (modSettings->getInterpolationMode() == GNC::GCS::DefaultModalitySettings::TIM_NEAREST_NEIGHBOUR) {
-						m_pChoiceInterpolate->Select(0);
-					} else if (modSettings->getInterpolationMode() == GNC::GCS::DefaultModalitySettings::TIM_LINEAR) {
-						m_pChoiceInterpolate->Select(1);
-					}  else if (modSettings->getInterpolationMode() == GNC::GCS::DefaultModalitySettings::TIM_CUBIC) {
-						m_pChoiceInterpolate->Select(2);
-					}
-				}
-
-				void RebuildComboWL()
-				{
-					m_pDefaultWindowLevel->Clear();
-					m_pDefaultWindowLevel->Append(wxString::FromUTF8(GNC::GCS::DefaultModalitySettings::getDefaultWindowLevelLabel().c_str()));
-					m_pDefaultWindowLevel->Append(wxString::FromUTF8(GNC::GCS::DefaultModalitySettings::getAutocalculateWindowLevelLabel().c_str()));
-					m_pDefaultWindowLevel->Select(0);
-					if (modSettings->getInitialWindowLevelLabel() == GNC::GCS::DefaultModalitySettings::getAutocalculateWindowLevelLabel()) {
-						m_pDefaultWindowLevel->Select(1);
-					}
-					for (GNC::GCS::DefaultModalitySettings::TListOfWLSettings::const_iterator it = modSettings->getWLSettings().begin(); it != modSettings->getWLSettings().end(); ++it)
-					{
-						int item = m_pDefaultWindowLevel->Append(wxString::FromUTF8((*it)->getLabel().c_str()));
-						if ((*it)->getLabel() == modSettings->getInitialWindowLevelLabel()) {
-							m_pDefaultWindowLevel->Select (item); 
-						}
-					}
-				}
-
-				const std::string& getModalityName() 
-				{
-					return modSettings->getModality();
-				}
-
-				virtual void OnAddWL(wxCommandEvent& /*evt*/) 
-				{
-					AddWindowLevelDialog dlg(this);
-					if (dlg.ShowModal() == wxID_OK) {
-						m_pDefaultWindowLevel->Append(dlg.m_pLabel->GetValue());
-
-						wxTreeItemId idItem = m_pWLList->AppendItem(m_pWLList->GetRootItem(),dlg.m_pLabel->GetValue());
-						m_pWLList->SetItemText(idItem, COL_WINDOW_ID, dlg.m_pWindow->GetValue());
-						m_pWLList->SetItemText(idItem, COL_LEVEL_ID, dlg.m_pLevel->GetValue());
-					}
-				}
-
-				virtual void OnEditWL(wxCommandEvent& /*evt*/) 
-				{
-					wxTreeItemId item = m_pWLList->GetSelection();
-					if (item.IsOk()) {
-						wxString oldLabel = m_pWLList->GetItemText(item, COL_LABEL_ID);
-						wxString oldWindow = m_pWLList->GetItemText(item, COL_WINDOW_ID);
-						wxString oldLevel = m_pWLList->GetItemText(item, COL_LEVEL_ID);
-						AddWindowLevelDialog dlg(this, oldLabel, oldWindow, oldLevel);
-						if (dlg.ShowModal() == wxID_OK) {
-							int comboItem = m_pDefaultWindowLevel->FindString(oldLabel);
-							if (comboItem > 0) {
-								m_pDefaultWindowLevel->SetString(comboItem, dlg.m_pLabel->GetValue());
-							}
-							m_pWLList->SetItemText(item, COL_LABEL_ID, dlg.m_pLabel->GetValue());
-							m_pWLList->SetItemText(item, COL_WINDOW_ID, dlg.m_pWindow->GetValue());
-							m_pWLList->SetItemText(item, COL_LEVEL_ID, dlg.m_pLevel->GetValue());
-						}
-					}
-				}
-
-				virtual void OnDeleteWL(wxCommandEvent& /*evt*/)
-				{
-					wxTreeItemId item = m_pWLList->GetSelection();
-					if (item.IsOk()) {
-						int answer = wxMessageBox(_("Do you confirm the removal of the preset?"), _("Data modified"), wxYES_NO | wxCANCEL, this);
-						if(answer == wxYES){
-							wxString oldLabel = m_pWLList->GetItemText(item, COL_LABEL_ID);
-							int comboItem = m_pDefaultWindowLevel->FindString(oldLabel);
-							if (comboItem > 0) {
-								m_pDefaultWindowLevel->Delete(comboItem);
-								if (m_pDefaultWindowLevel->GetSelection() < 0) {
-									m_pDefaultWindowLevel->Select(0);
-								}
-							}
-							m_pWLList->Delete(item);
-						}
-					}
-				}
-
-				GNC::GCS::Ptr<GNC::GCS::DefaultModalitySettings> GetSettings()
-				{
-					modSettings->clearWindowLevels();
-					modSettings->setInitialWindowLevelLabel(std::string(m_pDefaultWindowLevel->GetString(m_pDefaultWindowLevel->GetSelection()).ToUTF8()));
-
-					wxTreeItemIdValue cookie;
-					for (wxTreeItemId item = m_pWLList->GetFirstChild(m_pWLList->GetRootItem(), cookie); item.IsOk(); item = m_pWLList->GetNextChild(m_pWLList->GetRootItem(), cookie))
-					{
-						double window;
-						double level;
-						if (m_pWLList->GetItemText(item, COL_WINDOW_ID).ToDouble(&window) && m_pWLList->GetItemText(item, COL_LEVEL_ID).ToDouble(&level)) {
-							GNC::GCS::Ptr<GNC::GCS::WindowLevelSetting> wlSettings(new GNC::GCS::WindowLevelSetting(window, level, std::string(m_pWLList->GetItemText(item, COL_LABEL_ID).ToUTF8())));
-							modSettings->addWindowLevel(wlSettings);
-						}
-					}
-
-					modSettings->setInterpolationMode((GNC::GCS::DefaultModalitySettings::TInterpolationMode)m_pChoiceInterpolate->GetSelection());
-					return modSettings;
-				}
-
-				GNC::GCS::Ptr<GNC::GCS::DefaultModalitySettings> modSettings;
-			};
+			
 		public:
 			EditHangingProtocolDialog(wxWindow* pParent): EditHangingProtocolDialogBase(pParent)
 			{	
@@ -810,8 +640,6 @@ namespace GNC {
 
 			void InitPanels()
 			{
-				m_currentModality = NULL;
-
 				editStudyCriteriaPanel = new EditCriteriaPanel(m_pGeneralPanel);
 				m_pSizerStudyCriteria->Add(editStudyCriteriaPanel, 1, wxEXPAND|wxALL, 5);
 
@@ -840,25 +668,6 @@ namespace GNC {
 				m_textName->SetValue(wxString::FromUTF8(hangingProtocol->getName().c_str()));
 				this->editStudyCriteriaPanel->loadMatcher(hangingProtocol->getStudyMatcher());	
 
-				//default modality settings...
-				wxTreeItemId root = m_pTreeNavigation->AddRoot(_("Modalities"));
-				for (GNC::GCS::HangingProtocol::TMapOfModalitySettings::const_iterator it = hangingProtocol->getModalitySettingsMap().begin(); it != hangingProtocol->getModalitySettingsMap().end(); ++it)
-				{
-					if ((*it).second.IsValid()) {
-						ModalityPanel * mp = new ModalityPanel(m_pModalityPanel, (*it).second);
-						wxTreeItemId id = m_pTreeNavigation->AppendItem(root, wxString::FromUTF8(mp->getModalityName().c_str()));
-						modalityBrowser[id.m_pItem] = mp;
-						mp->InitPanels();
-						mp->Hide();
-						m_pSizerModalities->Add(mp, 1, wxEXPAND|wxALL, 5);
-						m_pModalityPanel->Layout();
-					}
-				}
-				wxTreeItemIdValue cookie;
-				m_pTreeNavigation->SelectItem(m_pTreeNavigation->GetFirstChild(root, cookie));
-				LoadCurrent();
-				//
-
 				m_pNoteBookWindows->Layout();
 				m_pGeneralPanel->Layout();
 				m_pMainNoteBook->Layout();
@@ -882,48 +691,11 @@ namespace GNC {
 						}
 					}
 				}
-				this->hangingProtocol->clearModalitySettings();
-				for (wxWindowList::iterator it = m_pModalityPanel->GetChildren().begin(); it != m_pModalityPanel->GetChildren().end(); ++it) {
-					ModalityPanel* mp = dynamic_cast<ModalityPanel*>((*it));
-					if (mp != NULL) {
-						GNC::GCS::Ptr<GNC::GCS::DefaultModalitySettings> settings = mp->GetSettings();
-						if (settings.IsValid()) {
-							this->hangingProtocol->addModalitySettings(settings);
-						}
-					}
-				}
 				return this->hangingProtocol;
 			}
 
 
 		protected:
-			void OnNavigationChanged(wxTreeEvent &){
-				LoadCurrent();
-			}
-
-			void LoadCurrent() 
-			{
-				wxTreeItemId id = m_pTreeNavigation->GetSelection();
-				if (id.IsOk()) {
-					if(modalityBrowser.find(id.m_pItem) != modalityBrowser.end()){
-						ModalityPanel* pCurrent = modalityBrowser[id.m_pItem];
-						if( pCurrent!=NULL && pCurrent!=m_currentModality){
-							m_pTitledPanelModalities->Freeze();
-							if(m_currentModality!=NULL){
-								m_currentModality->Hide();
-							}
-							m_currentModality = pCurrent;
-							wxString modName = wxString::Format(_("%s settings"),wxString::FromUTF8(pCurrent->getModalityName().c_str()).c_str());
-							m_pTitledPanelModalities->SetToolTip(modName);
-							m_currentModality->Show();
-							m_pModalityPanel->SetScrollbars(20, 20, 50, 50, 0, 0, false);
-							m_pModalityPanel->AdjustScrollbars();
-							m_pTitledPanelModalities->Layout();
-							m_pTitledPanelModalities->Thaw();					
-						}
-					}
-				}
-			}			
 
 			virtual void OnPageChanging( wxAuiNotebookEvent& event ) 
 			{
@@ -962,9 +734,6 @@ namespace GNC {
 			GNC::GCS::ModoControlador::T_HangingProtocolSupportLevel hangingSupportLevel;
 			EditCriteriaPanel* editStudyCriteriaPanel;	
 			GNC::GCS::Ptr<GNC::GCS::HangingProtocol> hangingProtocol;	
-			typedef std::map<wxTreeItemIdValue ,ModalityPanel*> TModalityMap;
-			TModalityMap modalityBrowser;
-			ModalityPanel* m_currentModality;
 		};
 		////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 		class wxTreeItemDataProtocols: public wxTreeItemData
