@@ -3,7 +3,7 @@
  *  $Id: panelconfiguraciongeneral.h $
  *  Ginkgo CADx Project
  *
- *  Copyright 2008-12 MetaEmotion S.L. All rights reserved.
+ *  Copyright 2008-14 MetaEmotion S.L. All rights reserved.
  *  http://ginkgo-cadx.com
  *
  *  This file is licensed under LGPL v3 license.
@@ -42,16 +42,14 @@ namespace GNC {
 				bool Guardar();
 				//endregion
 
-
 			protected:
 				wxString m_pathDicomDir;
 				void OnCheckForUpdates(wxCommandEvent &event);
 				void OnTextoCambiado(wxCommandEvent &event);
 				void OnIdiomaCambiado(wxCommandEvent &event);
-				void OnSeleccionarDirectorio(wxCommandEvent &event);
-				void OnSize(wxSizeEvent& event);
 				virtual void OnProxySettings(wxCommandEvent &event);
 				virtual void OnCheckEnableProxySettings(wxCommandEvent &event);
+
 				bool m_idiomaCambiado;
 				typedef std::map<std::string, int> TMapLanguages;
 				TMapLanguages m_mapLanguages;
