@@ -3,7 +3,7 @@
  *  $Id: panelconfiguracionpermisos.cpp $
  *  Ginkgo CADx Project
  *
- *  Copyright 2008-12 MetaEmotion S.L. All rights reserved.
+ *  Copyright 2008-14 MetaEmotion S.L. All rights reserved.
  *  http://ginkgo-cadx.com
  *
  *  This file is licensed under LGPL v3 license.
@@ -218,6 +218,7 @@ namespace GNC {
 				char* vectorWidgets = new char[out.GetLength()];
 				out.CopyTo(vectorWidgets,out.GetLength());
 				xml = std::string(vectorWidgets, out.GetLength());
+				delete[] vectorWidgets;
 			}
 
 			virtual void OnPgDoubleClick(wxPropertyGridEvent &event) 
@@ -476,8 +477,9 @@ namespace GNC {
 		bool PanelConfiguracionPermisos::Validar()
 		{
 			bool ok = true;
-			//si modificado... los cambios se aplicarán al volver a reiniciar
+			//si modificado... los cambios se recargaran ahora pero puede haber incongruencias
 			if(m_permisosCambiados) {
+				GNC::ControladorPermisos::FreeInstance();
 				wxMessageBox(_("Ginkgo CADx must restart for the permission changes to take effect"),_("Info"));
 			}
 			return ok;
