@@ -31,6 +31,8 @@
 #include <wx/imaglist.h>
 #include <wx/msgdlg.h>
 
+#include <main/controllers/anonusagestats.h>
+
 
 #define CLOUD_STUDY_UID "studyInstanceUID"
 #define CLOUD_MD5 "md5File"
@@ -119,6 +121,9 @@ GNC::GUI::GinkgoCloudSearchDialog::~GinkgoCloudSearchDialog()
 
 bool GNC::GUI::GinkgoCloudSearchDialog::Show(bool show)
 {
+	if (show) {
+		LOG_STAT(ANON_STAT_DLG_CLOUD_SEARCH)
+	}
 	if (IsIconized()) {
 		Iconize(false);
 	}
@@ -424,19 +429,41 @@ void GNC::GUI::GinkgoCloudSearchDialog::LoadResults(const std::string& bucketId,
 	
 	for (GNC::GCS::CloudFindCommandParams::Results::const_iterator itTuples = results.begin(); itTuples != results.end(); ++itTuples) {
 		const GNC::GCS::CloudFindCommandParams::ResultTuple& tuple = (*itTuples);
-		wxTreeItemId studyTreeId = m_pTreeListResults->AppendItem(topTreeId, wxString::FromUTF8(tuple.find(CLOUD_DESCRIPTION)->second.c_str()));
-		m_pTreeListResults->SetItemText(studyTreeId, MODALITY_COLUMN, wxString::FromUTF8(tuple.find(CLOUD_MODALITIES)->second.c_str()));
-		m_pTreeListResults->SetItemText(studyTreeId, CREATOR_USER_NAME_COLUMN, wxString::FromUTF8(tuple.find(CLOUD_CREATOR_USER_NAME)->second.c_str()));
-		m_pTreeListResults->SetItemText(studyTreeId, LAST_MODIFICATOR_USER_NAME_COLUMN, wxString::FromUTF8(tuple.find(CLOUD_LAST_MOD_USER_NAME)->second.c_str()));
-		wxDateTime wxDate;
-		wxString dateStr = wxString::FromUTF8(tuple.find(CLOUD_DATE)->second.c_str());
-		wxDate.ParseFormat( dateStr, wxT("%Y-%m-%d %H:%M:%S"), wxDefaultDateTime);
+		wxTreeItemId studyTreeId;
+		if (tuple.find(CLOUD_DESCRIPTION) != tuple.end()) {
+			studyTreeId = m_pTreeListResults->AppendItem(topTreeId, wxString::FromUTF8(tuple.find(CLOUD_DESCRIPTION)->second.c_str()));
+		} else {
+			studyTreeId = m_pTreeListResults->AppendItem(topTreeId, _("?"));
+		}
+		if (tuple.find(CLOUD_MODALITIES) != tuple.end()) {
+			m_pTreeListResults->SetItemText(studyTreeId, MODALITY_COLUMN, wxString::FromUTF8(tuple.find(CLOUD_MODALITIES)->second.c_str()));
+		} else {
+			m_pTreeListResults->SetItemText(studyTreeId, MODALITY_COLUMN, _("?"));
+		}
+		if (tuple.find(CLOUD_CREATOR_USER_NAME) != tuple.end()) {
+			m_pTreeListResults->SetItemText(studyTreeId, CREATOR_USER_NAME_COLUMN, wxString::FromUTF8(tuple.find(CLOUD_CREATOR_USER_NAME)->second.c_str()));
+		} else {
+			m_pTreeListResults->SetItemText(studyTreeId, CREATOR_USER_NAME_COLUMN, _("?"));
+		}
+		if (tuple.find(CLOUD_CREATOR_USER_NAME) != tuple.end()) {
+			m_pTreeListResults->SetItemText(studyTreeId, LAST_MODIFICATOR_USER_NAME_COLUMN, wxString::FromUTF8(tuple.find(CLOUD_LAST_MOD_USER_NAME)->second.c_str()));
+		} else {
+			m_pTreeListResults->SetItemText(studyTreeId, LAST_MODIFICATOR_USER_NAME_COLUMN, _("?"));
+		}
+
+		if (tuple.find(CLOUD_DATE) != tuple.end()) {
+			wxDateTime wxDate;
+			wxString dateStr = wxString::FromUTF8(tuple.find(CLOUD_DATE)->second.c_str());
+			wxDate.ParseFormat( dateStr, wxT("%Y-%m-%d %H:%M:%S"), wxDefaultDateTime);
 		
-		if(wxDate.IsValid()){
-			dateStr = wxString(wxDate.Format(_("%m/%d/%Y %H:%M:%S"), wxDateTime::TimeZone(wxDateTime::GMT1)));
+			if(wxDate.IsValid()){
+				dateStr = wxString(wxDate.Format(_("%m/%d/%Y %H:%M:%S"), wxDateTime::TimeZone(wxDateTime::GMT1)));
+			}
+			m_pTreeListResults->SetItemText(studyTreeId, DATE_COLUMN, dateStr);
+		}
+		if (tuple.find(CLOUD_URL) != tuple.end()) {
+			m_pTreeListResults->SetItemText(studyTreeId, URL_COLUMN, wxString::FromUTF8(tuple.find(CLOUD_URL)->second.c_str()));
 		}
-		m_pTreeListResults->SetItemText(studyTreeId, DATE_COLUMN, dateStr);
-		m_pTreeListResults->SetItemText(studyTreeId, URL_COLUMN, wxString::FromUTF8(tuple.find(CLOUD_URL)->second.c_str()));
 		m_pTreeListResults->SetItemText(studyTreeId, BUCKET_ID_COLUMN, wxString::FromUTF8(bucketId.c_str()));
 
 		//
