@@ -67,6 +67,8 @@
 #include <vtk/interactor/ginkgointeractorstyleimage2d.h>
 #include <main/gui/droptargetmainwindow.h>
 
+#include <main/controllers/anonusagestats.h>
+
 #define SIZE_ICONOS 16
 
 #define ICONO_ESTUDIO 0
@@ -623,6 +625,14 @@ GNC::GUI::HistoryPanel3::~HistoryPanel3()
 
 }
 
+bool GNC::GUI::HistoryPanel3::Show(bool show)
+{
+	if (show) {
+		LOG_STAT(ANON_STAT_DLG_HISTORY);
+	}
+	return GNC::GUI::HistoryPanel3Base::Show(show);
+}
+
 void GNC::GUI::HistoryPanel3::ReloadHistory()
 {
 	ReloadCombos(false);
