@@ -9,6 +9,7 @@
 #pragma once
 
 #include <wx/thumbnailctrl/thumbnailctrl.h>
+#include <api/controllers/ihistorycontroller.h>
 
 namespace GNC {
 	namespace GUI {
@@ -20,7 +21,7 @@ namespace GNC {
 				TI_Image
 			}TItemType;
 
-			wxHistoryImageThumbnailItem(const wxString& filename, TItemType type, long series_pk, long file_pk, bool linked);
+			wxHistoryImageThumbnailItem(const wxString& filename, TItemType type, long series_pk, long file_pk, GNC::GCS::IHistoryController::TLocation source);
 
 			TItemType GetType() 
 			{
@@ -41,7 +42,7 @@ namespace GNC {
 
 		protected:
 			TItemType m_type;
-			bool isLinked;
+			GNC::GCS::IHistoryController::TLocation m_source;
 			long m_filepk;
 			long m_seriespk;
 		};
