@@ -3,7 +3,7 @@
  *  $Id: wxtreelistctrlhistory.h $
  *  Ginkgo CADx Project
  *
- *  Copyright 2008-12 MetaEmotion S.L. All rights reserved.
+ *  Copyright 2008-14 MetaEmotion S.L. All rights reserved.
  *  http://ginkgo-cadx.com
  *
  *  This file is licensed under LGPL v3 license.
@@ -124,11 +124,19 @@ public:
 							wxTimeSpan diff = date1.Subtract(date2);
 							if (diff.IsPositive()) {
 								result = 1;
+							} else if (diff.IsEqualTo(wxTimeSpan(0))) {
+								result = 0;
 							} else {
 								result = -1;
 							}
 						} else {
-							result = 0;
+							if (date1.IsValid()) {
+								result = 1;
+							} else if (date2.IsValid()) {
+								result = -1;
+							} else {
+								result = 0;
+							}
 						}
 					}
 					break;
