@@ -18,8 +18,10 @@
 #include <main/controllers/configurationcontroller.h>
 #include <main/controllers/controladorpermisos.h>
 #include <api/internationalization/internationalization.h>
+#include <main/controllers/anonusagestats.h>
 #include <api/globals.h>
 #include <main/license.h>
+#include <wx/ginkgostyle/ginkgostyle.h>
 
 
 
@@ -31,6 +33,13 @@ GNC::GUI::AcceptLicenseDialog::AcceptLicenseDialog(wxWindow* pPadre):GNC::GUI::A
 	GNC::GCS::Permisos::EstadoPermiso updates = GNC::GCS::IControladorPermisos::Instance()->Get("core.update","check_updates");
 	m_pCheckForUpdates->Show(updates);
 	m_pCheckForUpdates->SetValue(updates);
+#ifdef GINKGO_PRO
+	m_pCheckAnonUsageStats->Show();
+#else
+	m_pCheckAnonUsageStats->Show(false);
+#endif
+	m_pFooter->Layout();
+	Layout();
 }
 
 GNC::GUI::AcceptLicenseDialog::~AcceptLicenseDialog()
@@ -42,4 +51,9 @@ void GNC::GUI::AcceptLicenseDialog::OnAceptarClick(wxCommandEvent &event)
 	GNC::GCS::ConfigurationController::Instance()->writeBoolGeneral("/GinkgoCore/Estacion", "CheckForUpdates", m_pCheckForUpdates->GetValue());
 	GNC::GCS::ConfigurationController::Instance()->Flush();
 	event.Skip(true);
+#ifdef GINKGO_PRO
+	GNC::GCS::ConfigurationController::Instance()->writeBoolGeneral("/GinkgoCore/General", "AnonUsageStats", m_pCheckAnonUsageStats->GetValue());
+	GNC::GCS::ConfigurationController::Instance()->Flush();
+	GNC::GCS::AnonUsageStats::Instance()->resetSettings();
+#endif
 }
