@@ -3,7 +3,7 @@
  *  $Id: ventanaprincipal.cpp $
  *  Ginkgo CADx Project
  *
- *  Copyright 2008-12 MetaEmotion S.L. All rights reserved.
+ *  Copyright 2008-14 MetaEmotion S.L. All rights reserved.
  *  http://ginkgo-cadx.com
  *
  *  This file is licensed under LGPL v3 license.
@@ -183,7 +183,7 @@ EVT_CLOSE(VentanaPrincipal::OnWindowClose)
 EVT_MENU(ID_Inicio_Aplicacion, VentanaPrincipal::OnInicioAplicacion)
 END_EVENT_TABLE()
 
-VentanaPrincipal::VentanaPrincipal(const wxString& title) : VentanaPrincipalBase(NULL, wxID_ANY, title), m_mgr(m_pPanelCentral, AUI_NAMESPACE wxAUI_MGR_ALLOW_FLOATING | AUI_NAMESPACE  wxAUI_MGR_TRANSPARENT_DRAG |AUI_NAMESPACE  wxAUI_MGR_VENETIAN_BLINDS_HINT ),
+VentanaPrincipal::VentanaPrincipal(wxWindow* pParent, const wxString& title) : VentanaPrincipalBase(pParent, wxID_ANY, title), m_mgr(m_pPanelCentral, AUI_NAMESPACE wxAUI_MGR_ALLOW_FLOATING | AUI_NAMESPACE  wxAUI_MGR_TRANSPARENT_DRAG |AUI_NAMESPACE  wxAUI_MGR_VENETIAN_BLINDS_HINT ),
 	StartupView(NULL)
 {
 	//load attributes
@@ -904,9 +904,9 @@ void VentanaPrincipal::ShowStartUp(bool show)
 	}
 	if (StartupView->GetWindow()->IsShown() != show) {
 		m_mgr.GetPane(StartupView->GetWindow()).Show(show);
-		GNC::GCS::ControladorVistas::Instance()->SolicitarActivarVista(StartupView);
 		update = true;
 	}
+	GNC::GCS::ControladorVistas::Instance()->SolicitarActivarVista(StartupView);
 	if (m_pNoteBook->IsShown() == show) {
 		m_mgr.GetPane(m_pNoteBook).Show(!show);
 		update = true;
