@@ -21,6 +21,7 @@
 #include <api/globals.h>
 #include <api/icontexto.h>
 #include <api/iwidgetsrenderer.h>
+#include <api/iannotator.h>
 
 #include <eventos/modificacionwidget.h>
 
@@ -74,12 +75,20 @@ protected:
 	double                     m_Frecuencia;
 };
 
-GNC::WidgetsManager::WidgetsManager(GNC::GCS::IVista* pVista):GNC::GCS::IWidgetsManager(pVista) {
+GNC::WidgetsManager::WidgetsManager(GNC::GCS::IVista* pVista):GNC::GCS::IWidgetsManager(pVista), m_pAnnotator(new GNC::GCS::IAnnotator(pVista))
+{
 	m_pRendererActivo = NULL;
 	m_cursor = GNC::GCS::Widgets::CUR_FLECHA;
 	m_mouseDerechoDown = false;
 	m_mouseIzquierdoDown = false;
 	m_pTimerAnimation = new TimerAnimation(this);
+
+	GNC::GCS::Widgets::WAnotador* pW = new GNC::GCS::Widgets::WAnotador(this,-1,"",-1);
+	InsertarWidget(pW);
+	GNC::GCS::Widgets::WAnotacionPosicion* pPosicion = new GNC::GCS::Widgets::WAnotacionPosicion(this,-1,"",-1);
+	InsertarWidget(pPosicion);
+	GNC::GCS::Widgets::WStaticRule* pStaticRule = new GNC::GCS::Widgets::WStaticRule(this,-1,"",-1);
+	InsertarWidget(pStaticRule);
 }
 
 GNC::WidgetsManager::~WidgetsManager() {
@@ -952,28 +961,20 @@ void GNC::WidgetsManager::NotificarModificacion(GNC::GCS::Widgets::IWidget* pWid
 
 //----------------------------------------------------------------------------------------------------
 //region "Interfaz general"
-void GNC::WidgetsManager::CrearWidgetAnotador(GNC::GCS::IAnotador* pAnotador)
+
+void GNC::WidgetsManager::SetAnnotator(const GNC::GCS::Ptr<GNC::GCS::IAnnotator>& pAnnotador)
 {
-	GNC::GCS::Widgets::WAnotador* pW = new GNC::GCS::Widgets::WAnotador(pAnotador,this,-1,"",-1);
-	InsertarWidget(pW);
-	GNC::GCS::Widgets::WAnotacionPosicion* pPosicion = new GNC::GCS::Widgets::WAnotacionPosicion(pAnotador,this,-1,"",-1);
-	InsertarWidget(pPosicion);
-	GNC::GCS::Widgets::WStaticRule* pStaticRule = new GNC::GCS::Widgets::WStaticRule(this,-1,"",-1);
-	InsertarWidget(pStaticRule);
+	m_pAnnotator = pAnnotador;
+	Modificado();
+	Render();
 }
 
-void GNC::WidgetsManager::EnableAnotacionDinamica(bool /*enable*/)
+const GNC::GCS::Ptr<GNC::GCS::IAnnotator>& GNC::WidgetsManager::GetAnnotator()
 {
-	//buscamos los widgets anotadores y los establecemos el modo
-	for( GNC::GCS::ListaWidgets::iterator it = m_Widgets.begin(); it != m_Widgets.end(); ++it) {
-		GNC::GCS::Widgets::IWidget* w = *it;
-		if (w->GetVID() == -1 && w->GetGID() == -1) {
-			//GNC::GCS::Widgets::WAnotador* pAnotador = dynamic_cast<GNC::GCS::Widgets::WAnotador*> (w);
-		}
-	}
+	return m_pAnnotator;
 }
 
-void GNC::WidgetsManager::MostrarOcultarAnotador()
+void GNC::WidgetsManager::ShowAnnotations(bool show)
 {
 	//buscamos los widgets anotadores y los establecemos el modo
 	for( GNC::GCS::ListaWidgets::iterator it = m_Widgets.begin(); it != m_Widgets.end(); ++it) {
@@ -981,18 +982,18 @@ void GNC::WidgetsManager::MostrarOcultarAnotador()
 		if (w->GetVID() == -1 && w->GetGID() == -1) {
 			GNC::GCS::Widgets::WAnotador* pAnotador = dynamic_cast<GNC::GCS::Widgets::WAnotador*> (w);
 			if (pAnotador != NULL) {
-				pAnotador->Ocultar(!pAnotador->EstaOculto());
+				pAnotador->Ocultar(!show);
 			} else {
 				GNC::GCS::Widgets::WStaticRule* pStaticRule = dynamic_cast<GNC::GCS::Widgets::WStaticRule*> (w);
 				if (pStaticRule != NULL) {
-					pStaticRule->Ocultar(!pStaticRule->EstaOculto());
+					pStaticRule->Ocultar(!show);
 				}
 			}
 		}
 	}
 }
 
-bool GNC::WidgetsManager::IsVisibleAnotador()
+bool GNC::WidgetsManager::IsShownAnnotations()
 {
 	for( GNC::GCS::ListaWidgets::iterator it = m_Widgets.begin(); it != m_Widgets.end(); ++it) {
 		GNC::GCS::Widgets::IWidget* w = *it;
