@@ -20,7 +20,6 @@
 #include <api/iwidgetsmanager.h>
 #include <api/observers/iwidgetsobserver.h>
 #include <api/observers/ieventsobserver.h>
-#include <api/ianotador.h>
 #include <api/controllers/ieventscontroller.h>
 
 //----------------------------------------------------------------------------------------------------
@@ -133,12 +132,12 @@ namespace GNC {
 	//endregion
 
 	//----------------------------------------------------------------------------------------------------
-	//region "Interfaz anotacion estatica"
+	//region "Interfaz annotation"
 
-		virtual void CrearWidgetAnotador(GNC::GCS::IAnotador* pAnotador);
-		virtual void EnableAnotacionDinamica(bool enable);
-		virtual void MostrarOcultarAnotador();
-		virtual bool IsVisibleAnotador();
+		virtual void SetAnnotator(const GNC::GCS::Ptr<GNC::GCS::IAnnotator>& pAnnotador);
+		virtual const GNC::GCS::Ptr<GNC::GCS::IAnnotator>& GetAnnotator();
+		virtual void ShowAnnotations(bool show);
+		virtual bool IsShownAnnotations();
 
 	//enderegion
 
@@ -177,6 +176,7 @@ namespace GNC {
 	private:
 		inline void ModificarRenderersDeWidget(GNC::GCS::Widgets::IWidget* w);
 		TimerAnimation* m_pTimerAnimation;
+		GNC::GCS::Ptr<GNC::GCS::IAnnotator> m_pAnnotator;
 	//endregion
 	};
 }
