@@ -3,7 +3,7 @@
  *  $Id: coretools.cpp $
  *  Ginkgo CADx Project
  *
- *  Copyright 2008-12 MetaEmotion S.L. All rights reserved.
+ *  Copyright 2008-14 MetaEmotion S.L. All rights reserved.
  *  http://ginkgo-cadx.com
  *
  *  This file is licensed under LGPL v3 license.
@@ -39,19 +39,21 @@
 #include "showhistorytool.h"
 #include "imageexporttool.h"
 #include "imageprinttool.h"
+#include "queryretrievetool.h"
 #include "trackballtool.h"
+#include "camerarotationtool.h"
 #include "videotool.h"
 #include "secondarycapturetool.h"
 #include "pacsuploadtool.h"
 #include "startdicomizationtool.h"
 #include "addfiletohistorytool.h"
 #include "openginkgocloudlinktool.h"
-#include "searchginkgocloudtool.h"
 #include "copyimagetoclipboardtool.h"
+#include "brightnesscontrasttool.h"
+
 #include <main/tools/historytools.h>
 #include <main/controllers/historytoolscontroller.h>
 
-
 void GNC::RegisterCoreTools() {
 	
 	#ifdef ENABLE_ANGLETOOL
@@ -99,28 +101,15 @@ void GNC::RegisterCoreTools() {
 	#ifdef ENABLE_NOTETOOL
 		(new GNC::NoteTool())->RegisterTool();
 	#endif
-	/*
-	#ifdef ENABLE_OPENFILETOOL
-		(new GNC::OpenFileTool())->RegisterTool();
-	#endif
-	#ifdef ENABLE_OPENFOLDERTOOL
-		(new GNC::OpenFolderTool())->RegisterTool();
-	#endif
-	#ifdef ENABLE_OPENREMOVABLETOOL
-		(new GNC::OpenRemovableTool())->RegisterTool();
-	#endif
-	*/
 	#ifdef ENABLE_PANTOOL
 		(new GNC::ToolPan())->RegisterTool();
 	#endif
 	#ifdef ENABLE_POINTERTOOL
 		(new GNC::PointerTool())->RegisterTool();
 	#endif
-	/*
 	#ifdef ENABLE_QUERYRETRIEVETOOL
 		(new GNC::QueryRetrieveTool())->RegisterTool();
 	#endif
-	*/
 	#ifdef ENABLE_RESETTOOL
 		(new GNC::ResetTool())->RegisterTool();
 	#endif	
@@ -151,6 +140,9 @@ void GNC::RegisterCoreTools() {
 	#ifdef ENABLE_ZOOMTOOL
 		(new GNC::ToolZoom())->RegisterTool();
 	#endif
+	#ifdef ENABLE_BRIGHTNESSCONTRASTTOOL
+		(new GNC::BrightnessContrastTool())->RegisterTool();
+	#endif
 
 		(new GNC::RotateAndFlipTool())->RegisterTool();
 		(new GNC::ColorMapTool())->RegisterTool();
@@ -164,6 +156,7 @@ void GNC::RegisterCoreTools() {
 		(new GNC::StartDicomizationTool())->RegisterTool();
 		(new GNC::AddFileToHistory())->RegisterTool();
 		(new GNC::CopyImageToClipboardTool())->RegisterTool();
+		(new GNC::CameraRotationTool())->RegisterTool();
 
 	//history
 	GNC::HistoryToolsController::Instance()->RegisterTool(new GNC::AnonymizeTool());
@@ -172,9 +165,9 @@ void GNC::RegisterCoreTools() {
 	GNC::HistoryToolsController::Instance()->RegisterTool(new GNC::OpenFolderTool());
 	GNC::HistoryToolsController::Instance()->RegisterTool(new GNC::OpenRemovableTool());
 	GNC::HistoryToolsController::Instance()->RegisterTool(new GNC::DicomizeTool());
-	GNC::HistoryToolsController::Instance()->RegisterTool(new GNC::QueryRetrieveTool());
+	GNC::HistoryToolsController::Instance()->RegisterTool(new GNC::QueryRetrieveHistoryTool());
 	GNC::HistoryToolsController::Instance()->RegisterTool(new GNC::SendPACSTool());
 	GNC::HistoryToolsController::Instance()->RegisterTool(new GNC::ExportDicomDirTool());
 	GNC::HistoryToolsController::Instance()->RegisterTool(new GNC::OpenGinkgoCloudLinkTool());
-	GNC::HistoryToolsController::Instance()->RegisterTool(new GNC::SearchGinkgoCloudTool());
+	GNC::HistoryToolsController::Instance()->RegisterTool(new GNC::SearchGinkgoCloudHistoryTool());
 }
