@@ -67,7 +67,7 @@ GNC::CornerAnnotationsTool::~CornerAnnotationsTool()
 		
 bool GNC::CornerAnnotationsTool::ExecuteAction()
 {
-	WidgetsContract->GetManager()->MostrarOcultarAnotador();
+	WidgetsContract->GetManager()->ShowAnnotations(!WidgetsContract->GetManager()->IsShownAnnotations());
 	GNC::GCS::ControladorEventos::Instance()->ProcesarEvento(new GNC::GCS::Events::EventoRender(WidgetsContract->GetManager()->GetVista()));
 	return true;
 }
@@ -82,6 +82,6 @@ void GNC::CornerAnnotationsTool::AppendToolIn(wxEvtHandler* pParent, wxMenu* pMe
 
 bool GNC::CornerAnnotationsTool::IsVisible()
 {
-	return WidgetsContract->GetManager()->IsVisibleAnotador();
+	return WidgetsContract->GetManager()->IsShownAnnotations();
 }
 #endif
