@@ -54,7 +54,6 @@ void GNC::PointerTool::Connect()
 		delete m_pSeleccionBuilder;
 		m_pSeleccionBuilder = NULL;
 	}
-	WidgetsContract->GetManager()->EnableAnotacionDinamica(true);
 	m_pSeleccionBuilder = new TSeleccionBuilder(WidgetsContract->GetManager(), GetTriggerButton(), (unsigned long)this);
 	WidgetsContract->GetViewerActivo()->SetInteractionStyle(vtkGinkgoImageViewer::ZOOM_INTERACTION);
 	WidgetsContract->GetManager()->SetCursor(m_pSeleccionBuilder->GetCursor());		
@@ -62,7 +61,6 @@ void GNC::PointerTool::Connect()
 
 void GNC::PointerTool::Disconnect()
 {
-	WidgetsContract->GetManager()->EnableAnotacionDinamica(false);
 	WidgetsContract->GetViewerActivo()->SetInteractionStyle(vtkGinkgoImageViewer::ZOOM_INTERACTION);
 	WidgetsContract->GetManager()->SetCursor(GNC::GCS::Widgets::CUR_FLECHA);
 	if (m_pSeleccionBuilder != NULL)
