@@ -24,7 +24,7 @@
 
 //----------------------------------------------------------------------
 
-GNC::ShowTagsHistoryTool::ShowTagsHistoryTool(): GNC::GCS::IHistoryTool(ID,GNC::GCS::IHistoryTool::TFamily_ShowMetadata, _Std("Show metadatada"), _Std("Show metadatada"), GinkgoResourcesManager::ToolIcons::GetIcoMostrarOcultarTags()) 
+GNC::ShowTagsHistoryTool::ShowTagsHistoryTool(): GNC::GCS::IHistoryTool(ID,GNC::GCS::IHistoryTool::TFamily_ShowMetadata, _Std("DICOM inspector"), _Std("DICOM inspector"), GinkgoResourcesManager::ToolIcons::GetIcoMostrarOcultarTags()) 
 {
 }
 
