@@ -3,7 +3,7 @@
  *  $Id: toolzoom.cpp $
  *  Ginkgo CADx Project
  *
- *  Copyright 2008-12 MetaEmotion S.L. All rights reserved.
+ *  Copyright 2008-14 MetaEmotion S.L. All rights reserved.
  *  http://ginkgo-cadx.com
  *
  *  This file is licensed under LGPL v3 license.
@@ -87,7 +87,7 @@ void GNC::ToolZoom::Connect()
 		m_pBuilder = NULL;
 	}
 
-	m_pBuilder = new TBuilder(WidgetsContract->GetManager(),this, GetTriggerButton(), (unsigned long)this);
+	m_pBuilder = new TBuilder(WidgetsContract->GetManager(), GetTriggerButton(), (unsigned long)this);
 	WidgetsContract->GetViewerActivo()->SetInteractionStyle(vtkGinkgoImageViewer::ZOOM_INTERACTION);
 	WidgetsContract->GetManager()->SetCursor(m_pBuilder->GetCursor());
 }
@@ -113,25 +113,6 @@ void GNC::ToolZoom::AppendDropDownMenu(wxEvtHandler* pParent, wxMenu* pMenu)
 	pMenu->Append(new GNC::GUI::wxMenuItemTool(pMenu, ZOOM_1_1,_("Reset size to display resolution"), GinkgoResourcesManager::MagnifierBar::GetIcoZoomIn(), new GNC::GUI::EventHandlerZoomTool(pParent, this)));
 }
 
-//endregion
-
-
-//region "IWZoomObserver"
-void GNC::ToolZoom::ChangeZoom(int steps)
-{
-	if (WidgetsContract->Inicializado()) 
-	{
-		vtkSmartPointer<vtkInteractorStyle> interactor = WidgetsContract->GetViewerActivo()->GetInteractorStyle();
-		if (interactor != NULL) {
-			interactor->StartDolly();
-			double factor = 0.1 *steps * interactor->GetMouseWheelMotionFactor();
-			//this->Dolly(pow((double)1.1, factor));
-			WidgetsContract->GetViewerActivo()->SyncSetZoom(pow((double) 1.1, factor) * WidgetsContract->GetViewerActivo()->GetZoom());
-			interactor->EndDolly();	
-		}
-	}
-}
-//endregion
 
 void GNC::ToolZoom::ZoomOneOne()
 {
