@@ -3,7 +3,7 @@
  *  $Id: toolzoom.h $
  *  Ginkgo CADx Project
  *
- *  Copyright 2008-12 MetaEmotion S.L. All rights reserved.
+ *  Copyright 2008-14 MetaEmotion S.L. All rights reserved.
  *  http://ginkgo-cadx.com
  *
  *  This file is licensed under LGPL v3 license.
@@ -17,13 +17,12 @@
 #ifndef ZOOMTOOL_H
 #define ZOOMTOOL_H
 #include <export/tools/itoolzoom.h>
-#include <api/toolhandlers/izoomhandler.h>
 #include <api/api.h>
 #include <widgets/wzoom.h>
 
 namespace GNC {
 
-	class EXTAPI ToolZoom : public GNC::GCS::IToolZoom, public GNC::GCS::ToolHandlers::IZoomHandler {
+	class EXTAPI ToolZoom : public GNC::GCS::IToolZoom {
 	public:
 		typedef GNC::GCS::Events::EventoRaton       TEventoRaton;
 		typedef GNC::GCS::Events::EventoTeclado     TEventoTeclado;
@@ -37,9 +36,6 @@ namespace GNC {
 		virtual bool HasDropDownMenu();
 		virtual void AppendDropDownMenu(wxEvtHandler* pParent, wxMenu* pMenu);
 
-//region "IWZoomObserver"
-		virtual void ChangeZoom(int steps);
-//endregion
 		virtual void ZoomOneOne();
 
 	protected:
