@@ -3,7 +3,7 @@
  *  $Id: toolcontroller.cpp $
  *  Ginkgo CADx Project
  *
- *  Copyright 2008-12 MetaEmotion S.L. All rights reserved.
+ *  Copyright 2008-14 MetaEmotion S.L. All rights reserved.
  *  http://ginkgo-cadx.com
  *
  *  This file is licensed under LGPL v3 license.
@@ -28,6 +28,8 @@
 #include <api/icontract.h>
 #include <api/ientorno.h>
 
+#include <wx/aui/auibar.h>
+
 namespace GNC {
 	namespace GUI {
 		const wxEventType wxEVT_ACTIVATE_TOOL_ASYNC = wxNewEventType();
@@ -249,33 +251,20 @@ wxWindow* GNC::ToolController::CreateNewToolBar(wxWindow* pParent, GNC::GCS::ITo
 	if (!alignLeft) {
 		pToolController->AddStretchSpacer(1);
 	}
-	for (TToolMap::iterator it = m_tools.begin(); it != m_tools.end(); ++it) 
-	{
-		GNC::GCS::ITool*& pTool = (*it).second;
-		if (pTool->GetFamily() == family && pTool->IsReady()) {
-			pTool->AppendToolIn(pToolController);
-		}
-	}
+	AppendsToolsInToolBar(pToolController, family);
 	pToolController->Realize();
 	return pToolController;
 }
 
 wxWindow* GNC::ToolController::CreateNewToolBar(wxWindow* pParent, const GNC::GCS::IToolController::TIdList& toolsToInclude, bool alignLeft)
 {
-	std::set<long> setOfIds;
-	setOfIds.insert(toolsToInclude.begin(), toolsToInclude.end());
-
 	GNC::GUI::wxGinkgoToolBar* pToolController = new GNC::GUI::wxGinkgoToolBar(pParent, this, GNC::GCS::ITool::TFamiliaGlobal);
 	if (!alignLeft) {
 		pToolController->AddStretchSpacer(1);
 	}
-	for (TToolMap::iterator it = m_tools.begin(); it != m_tools.end(); ++it) 
-	{
-		GNC::GCS::ITool*& pTool = (*it).second;
-		if (setOfIds.find(pTool->ID) != setOfIds.end() && pTool->IsReady()) {
-			pTool->AppendToolIn(pToolController);
-		}
-	}
+
+	AppendsToolsInToolBar(pToolController, toolsToInclude);
+	
 	pToolController->Realize();
 	return pToolController;
 }
@@ -345,6 +334,31 @@ void GNC::ToolController::AppendsToolInMenu(wxEvtHandler* pParent, wxMenu* pMenu
 	}
 }
 
+void GNC::ToolController::AppendsToolsInToolBar(wxAuiToolBar* pToolBar, GNC::GCS::ITool::TToolFamily family)
+{
+	for (TToolMap::iterator it = m_tools.begin(); it != m_tools.end(); ++it) 
+	{
+		GNC::GCS::ITool*& pTool = (*it).second;
+		if (pTool->GetFamily() == family && pTool->IsReady()) {
+			pTool->AppendToolIn(pToolBar);
+		}
+	}
+}
+
+void GNC::ToolController::AppendsToolsInToolBar(wxAuiToolBar* pToolBar, const GNC::GCS::IToolController::TIdList& toolsToInclude)
+{
+	std::set<long> setOfIds;
+	setOfIds.insert(toolsToInclude.begin(), toolsToInclude.end());
+
+	for (TToolMap::iterator it = m_tools.begin(); it != m_tools.end(); ++it) 
+	{
+		GNC::GCS::ITool*& pTool = (*it).second;
+		if (pTool != NULL && setOfIds.find(pTool->ID) != setOfIds.end() && pTool->IsReady()) {
+			pTool->AppendToolIn(pToolBar);
+		}
+	}
+}
+
 void GNC::ToolController::OnKeyAccelerator(GNC::GCS::Events::EventoTeclado& evento, wxWindow* pWindow)
 {
 	if (evento.ControlDown() || evento.GetKeyCode() == WXK_ESCAPE) {
