@@ -3,7 +3,7 @@
  *  $Id: ginkgoresourcemanager.h $
  *  Ginkgo CADx Project
  *
- *  Copyright 2008-12 MetaEmotion S.L. All rights reserved.
+ *  Copyright 2008-14 MetaEmotion S.L. All rights reserved.
  *  http://ginkgo-cadx.com
  *
  *  This file is licensed under LGPL v3 license.
@@ -123,6 +123,7 @@
 		static wxBitmap GetIcoDownloadCloud();
 		static wxBitmap GetIcoSearchCloud();
 		static wxBitmap GetIcoCopyToClipboard();
+		static wxBitmap GetIcoBrightnessContrast();
 	};
 
  	class EXTAPI MenuIcons {
@@ -197,6 +198,7 @@
 		static wxImage GetCursorWindowLevel();
 		static wxImage GetCursorAnclaSimple();
 		static wxImage GetCursorAnclaCompuesta();
+		static wxImage GetRotationCursor();
 	};
 
 	class EXTAPI ProgressBar {
