@@ -3,7 +3,7 @@
  *  $Id: ginkgosqlite.h $
  *  Ginkgo CADx Project
  *
- *  Copyright 2008-12 MetaEmotion S.L. All rights reserved.
+ *  Copyright 2008-14 MetaEmotion S.L. All rights reserved.
  *  http://ginkgo-cadx.com
  *
  *  This file is licensed under LGPL v3 license.
@@ -40,6 +40,7 @@ int AbrirConexion(wxSQLite3Database& dataBase,const std::string& DBFileName)
 	dataBase.EnableForeignKeySupport(true);
 
 	dataBase.ExecuteUpdate(wxT("PRAGMA recursive_triggers = true;"));
+	dataBase.ExecuteUpdate(wxT("PRAGMA synchronous=NORMAL;"));
 
 #ifdef _GINKGO_TRACE
 
@@ -194,12 +195,12 @@ int CreateGinkgoDB(wxSQLite3Database& dataBase,const char *DBFileName)
 
 	sentencia = wxEmptyString;
    sentencia << wxT("CREATE Index department ");
-	sentencia << wxT("ON Series(station_name);");
+	sentencia << wxT("ON Series(department);");
 	dataBase.ExecuteUpdate(sentencia);
 	
 	sentencia = wxEmptyString;
    sentencia << wxT("CREATE Index perf_physician ");
-	sentencia << wxT("ON Series(station_name);");
+	sentencia << wxT("ON Series(perf_physician);");
 	dataBase.ExecuteUpdate(sentencia);
 
 	sentencia = wxEmptyString;
