@@ -33,6 +33,7 @@ PURPOSE.  See the above copyright notices for more information.
 #include <vtkRenderWindowInteractor.h>
 #include <vtkImageData.h>
 #include <vtkRenderWindow.h>
+#include <wx/timer.h>
 
 vtkCxxRevisionMacro(GinkgoInteractorStyleImage2D, "$Revision: 752 $");
 vtkStandardNewMacro(GinkgoInteractorStyleImage2D);
@@ -40,6 +41,20 @@ vtkStandardNewMacro(GinkgoInteractorStyleImage2D);
 #include <vtkCamera.h>
 #include <vtkRenderer.h>
 
+class ISTimerZoom: public wxTimer
+{
+public:
+	ISTimerZoom(GinkgoInteractorStyleImage2D* pIS): IS(pIS)
+	{
+	}
+	virtual void Notify()
+	{
+		IS->EndZoom();
+	}
+
+	GinkgoInteractorStyleImage2D* IS;
+};
+
 //----------------------------------------------------------------------------
 
 GinkgoInteractorStyleImage2D::GinkgoInteractorStyleImage2D()
@@ -50,12 +65,17 @@ GinkgoInteractorStyleImage2D::GinkgoInteractorStyleImage2D()
 	this->LevelStep = 0.0;
 	this->WindowStep = 0.0;
 	this->PreviewMode = false;
+	this->TimerZoom = new ISTimerZoom(this);
 }
 
 //----------------------------------------------------------------------------
 
 GinkgoInteractorStyleImage2D::~GinkgoInteractorStyleImage2D()
 {
+	if (TimerZoom != NULL) {
+		TimerZoom->Stop();
+		delete TimerZoom;
+	}
 }
 
 //----------------------------------------------------------------------------
@@ -800,11 +820,8 @@ void GinkgoInteractorStyleImage2D::OnMouseWheelForward()
 			this->EndZSliceMove();
 			break;
 		case vtkGinkgoImageViewer::ZOOM_WITH_SELECT_INTERACTION :
-			this->StartDolly();
 			factor = 10.0 * 0.2 * this->MouseWheelMotionFactor;
-			//this->Dolly(pow((double)1.1, factor));
-			this->View->SyncSetZoom(pow((double) 1.1, factor) * this->View->GetZoom());
-			this->EndDolly();
+			DoZoom(factor);
 			break;
 		/*
 		case vtkGinkgoImageViewer::FULL_PAGE_INTERACTION :
@@ -812,11 +829,8 @@ void GinkgoInteractorStyleImage2D::OnMouseWheelForward()
 			break;
 		*/
 		case vtkGinkgoImageViewer::ZOOM_INTERACTION :
-			this->StartDolly();
 			factor = 10.0 * 0.2 * this->MouseWheelMotionFactor;
-			//this->Dolly(pow((double)1.1, factor));
-			this->View->SyncSetZoom(pow((double) 1.1, factor) * this->View->GetZoom());
-			this->EndDolly();
+			DoZoom(factor);
 			break;
 
 		default:
@@ -853,11 +867,8 @@ void GinkgoInteractorStyleImage2D::OnMouseWheelBackward()
 			this->EndZSliceMove();
 			break;
 		case vtkGinkgoImageViewer::ZOOM_WITH_SELECT_INTERACTION :
-			this->StartDolly();
 			factor = 10.0 * -0.2 * this->MouseWheelMotionFactor;
-			//this->Dolly(pow((double)1.1, factor));
-			this->View->SyncSetZoom(pow((double) 1.1, factor) * this->View->GetZoom());
-			this->EndDolly();
+			DoZoom(factor);
 			break;
 			/*
 		case vtkGinkgoImageViewer::FULL_PAGE_INTERACTION :
@@ -865,11 +876,8 @@ void GinkgoInteractorStyleImage2D::OnMouseWheelBackward()
 			break;
 		*/
 		case vtkGinkgoImageViewer::ZOOM_INTERACTION :
-			this->StartDolly();
 			factor = 10.0 * -0.2 * this->MouseWheelMotionFactor;
-			//this->Dolly(pow((double)1.1, factor));
-			this->View->SyncSetZoom(pow((double) 1.1, factor) * this->View->GetZoom());
-			this->EndDolly();
+			DoZoom(factor);
 			break;
 
 		default:
@@ -878,5 +886,22 @@ void GinkgoInteractorStyleImage2D::OnMouseWheelBackward()
 
 }
 
+void GinkgoInteractorStyleImage2D::DoZoom(double factor, bool launchTimer)
+{
+	if (TimerZoom->IsRunning()) {
+		TimerZoom->Stop();
+	}
+
+	if (this->State != VTKIS_ZOOM) {
+		this->StartZoom();
+	}
+	this->View->SyncSetZoom(pow((double) 1.1, factor) * this->View->GetZoom());
+	GetInteractor()->Render();
+	
+	if (launchTimer) {
+		TimerZoom->Start(600, true);
+	}
+}
+
 
 
