@@ -3,7 +3,7 @@
 *  $Id: vtkginkgoimageviewer.cpp $
 *  Ginkgo CADx Project
 *
-*  Copyright 2008-12 MetaEmotion S.L. All rights reserved.
+*  Copyright 2008-14 MetaEmotion S.L. All rights reserved.
 *  http://ginkgo-cadx.com
 *
 *  This file is licensed under LGPL v3 license.
@@ -76,14 +76,14 @@
 #include <vtkMatrix4x4.h>
 #include <vtkPointData.h>
 
-//#include <vtk/hackimageactor.h>
+//#define DEBUG_PIPELINE
+
+#include <vtkCellArray.h>
+#include <vtkDoubleArray.h>
 
 #define VTK_GINKGO_ZOOM_MIN 0.25f
 #define VTK_GINKGO_ZOOM_MAX 200
 
-//extern int vtkrint(double a);
-
-
 class vtkGinkgoTexture : public vtkOpenGLTexture {
 protected:
 	vtkGinkgoTexture() : m_IdTextura(-1),  m_vtkRenderWindow(NULL) {}
@@ -119,6 +119,10 @@ protected:
 
 vtkStandardNewMacro(vtkGinkgoTexture);
 
+#if defined(DEBUG_PIPELINE)
+static vtkIdType pts[6][4]={{0,1,2,3}, {4,5,6,7}, {0,1,5,4}, {1,2,6,5}, {2,3,7,6}, {3,0,4,7}};
+#endif
+
 class Pipeline {
 public:
 	vtkSmartPointer<vtkAlgorithmOutput>             InputConnection;
@@ -131,6 +135,18 @@ public:
 	vtkSmartPointer<vtkImageData>                   ImageData;
 	vtkSmartPointer<vtkImageData>                   OverlayData;
 	vtkSmartPointer<vtkActor>                       ImageActor;
+	#if defined(DEBUG_PIPELINE)
+
+	GNC::GCS::Vector3D coords[8];
+
+	vtkSmartPointer<vtkPolyData>                    DebugVolumePolyData;
+	vtkSmartPointer<vtkPoints>                      DebugVolumePoints;
+	vtkSmartPointer<vtkCellArray>                   DebugVolumePolys;
+	vtkSmartPointer<vtkDoubleArray>                 DebugVolumeScalars;
+
+	vtkSmartPointer<vtkPolyDataMapper>              DebugVolumeMapper;
+	vtkSmartPointer<vtkActor>                       DebugVolumeActor;
+	#endif
 	vtkSmartPointer<vtkActor>                       OverlayActor;
 	vtkSmartPointer<vtkPlaneSource>                 PlaneSource;
 	vtkSmartPointer<vtkProperty>                    PlaneProperty;
@@ -142,10 +158,8 @@ public:
 
 	vtkSmartPointer<vtkImageMapToWindowLevelColors> WindowLevel;
 
-	vtkSmartPointer<vtkImageDataStreamer>           StreamConnector;
-
 	vtkSmartPointer<vtkScalarsToColors>             LookupTable;
-	int															LookupTableId;
+	int                                             LookupTableId;
 
 	GNC::GCS::Ptr<GNC::GCS::IGinkgoMatrix4x4> ModelMatrix;
 	GNC::GCS::Ptr<GNC::GCS::IGinkgoMatrix4x4> ModelMatrixInv;
@@ -154,6 +168,30 @@ public:
 		ModelMatrixInv(GNC::GCS::IGinkgoMatrix4x4::New())
 	{
 		ImageActor      = vtkSmartPointer<vtkActor>::New();
+
+		#if defined(DEBUG_PIPELINE)
+
+		DebugVolumePolyData = vtkSmartPointer<vtkPolyData>::New();
+		DebugVolumePoints = vtkSmartPointer<vtkPoints>::New();
+		DebugVolumePolys = vtkSmartPointer<vtkCellArray>::New();
+		DebugVolumeScalars = vtkSmartPointer<vtkDoubleArray>::New();
+		DebugVolumeMapper = vtkSmartPointer<vtkPolyDataMapper>::New();
+		DebugVolumeActor = vtkSmartPointer<vtkActor>::New();
+		
+		for (int i=0; i<8; i++) DebugVolumePoints->InsertPoint(i, 0, 0, 0);
+		for (int i=0; i<6; i++) DebugVolumePolys->InsertNextCell(4, pts[i]);
+		for (int i=0; i<8; i++) DebugVolumeScalars->InsertTuple1(i,i);
+
+		DebugVolumePolyData->SetPoints(DebugVolumePoints);
+		DebugVolumePolyData->SetPolys(DebugVolumePolys);
+		DebugVolumePolyData->GetPointData()->SetScalars(DebugVolumeScalars);
+		DebugVolumeMapper->SetInput(DebugVolumePolyData);
+		DebugVolumeMapper->SetScalarVisibility(0);
+		DebugVolumeActor->SetMapper(DebugVolumeMapper);
+		DebugVolumeActor->GetProperty()->SetRepresentationToWireframe();
+
+		#endif
+
 		OverlayActor    = vtkSmartPointer<vtkActor>::New();
 		PlaneProperty   = vtkSmartPointer<vtkProperty>::New();
 
@@ -205,8 +243,7 @@ public:
 		MapperPlanoOverlay->SetInput(vtkPolyData::SafeDownCast(PlaneSource->GetOutput()));
 
 		WindowLevel = vtkSmartPointer<vtkImageMapToWindowLevelColors>::New();
-		StreamConnector = vtkSmartPointer<vtkImageDataStreamer>::New();
-		StreamConnector->SetNumberOfStreamDivisions(1);
+
 		vtkLookupTable* tbl = vtkLookupTableManager::GetLinearLookupTable();
 		LookupTableId = vtkLookupTableManager::LUT_LINEAR;
 		LookupTable = tbl;
@@ -224,7 +261,6 @@ public:
 		OverlayActor->PickableOff();
 
 		ResetMatrices();
-
 	}
 
 	void ResetMatrices()
@@ -268,28 +304,29 @@ class Propiedades {
 public:
 	unsigned int Orientacion;
 	unsigned int Conventions;
-	GNC::GCS::Ptr<GNC::GCS::IGinkgoMatrix4x4> DirectionCosines;
-	double       CameraFocalPoint[4];
-	double       CameraPosition[4];
-	double       CameraViewUp[4];
-	double       ParallelScale;
-	bool         Interaction;
-	bool         LinkRender;
-	bool         LinkCameraFocalAndPosition;
-	bool         LinkZoom;
+	
+	GNC::GCS::Vector3D  CameraFocalPoint;
+	GNC::GCS::Vector3D  CameraPosition;
+	GNC::GCS::Vector3D  CameraViewUp;
+	double              ParallelScale;
+	bool                Interaction;
+	bool                LinkRender;
+	bool                LinkCameraFocalAndPosition;
+	bool                LinkZoom;
 
 	bool         Modificado;
 
+private:
+	GNC::GCS::Ptr<GNC::GCS::IGinkgoMatrix4x4> DirectionCosines;
 
+public:
 
 	Propiedades(): DirectionCosines(GNC::GCS::IGinkgoMatrix4x4::New())
 	{
 		Orientacion = vtkGinkgoImageViewer::AXIAL_ID;
 		Conventions = vtkGinkgoImageViewer::RADIOLOGIC;
-		DirectionCosines->Zero();
-		CameraFocalPoint[0] = CameraFocalPoint[1] = CameraFocalPoint[2] = CameraFocalPoint[3] = 0.0;
-		CameraPosition[0] = CameraPosition[1] = CameraPosition[2] = CameraPosition[3] = 0.0;
-		CameraViewUp[0] = CameraViewUp[1] = CameraViewUp[2] = CameraViewUp[3] = 0.0;
+		DirectionCosines->Identity();
+
 		Interaction = false;
 		LinkRender = false;
 		LinkCameraFocalAndPosition = true;
@@ -299,9 +336,14 @@ public:
 
 	}
 
-	void SetDirection(const GNC::GCS::Ptr<GNC::GCS::IGinkgoMatrix4x4>& directionMatrix)
+	GNC::GCS::Ptr<GNC::GCS::IGinkgoMatrix4x4>& GetDirection()
 	{
-		DirectionCosines = directionMatrix;
+		return DirectionCosines;
+	}
+
+	void SetDirection(const GNC::GCS::IGinkgoMatrix4x4* directionCosines)
+	{
+		DirectionCosines->DeepCopy(directionCosines);
 		Modificado = true;
 	}
 
@@ -456,8 +498,14 @@ void vtkGinkgoImageViewer::Initialize(void)
 	if (p.Renderer) {
 		p.Renderer->GetActiveCamera()->ParallelProjectionOn();
 		p.Renderer->AddActor(p.ImageActor);
+		#if defined(DEBUG_PIPELINE)
+		p.Renderer->AddActor(p.DebugVolumeActor);
+		#endif
 		p.Renderer->AddActor(p.OverlayActor);
 		p.ImageActor->VisibilityOff();
+		#if defined(DEBUG_PIPELINE)
+		p.DebugVolumeActor->VisibilityOff();
+		#endif
 		p.OverlayActor->VisibilityOff();
 	}
 }
@@ -584,6 +632,9 @@ void vtkGinkgoImageViewer::RemoveInputs()
 	p.InputConnection = NULL;
 	p.ImageData = NULL;
 	p.ImageActor->VisibilityOff();
+	#if defined(DEBUG_PIPELINE)
+	p.DebugVolumeActor->VisibilityOff();
+	#endif
 	p.OverlayActor->VisibilityOff();
 	IImagePropertiesProxy = NULL;
 }
@@ -629,27 +680,24 @@ void vtkGinkgoImageViewer::UpdateDisplayExtent()
 
 	GNC::GCS::Vector3D origin;
 	GNC::GCS::Vector3D spacing;
-	int dimensions[3] = {0, 0, 0};
-	GNC::GCS::Ptr<GNC::GCS::IGinkgoMatrix4x4> directionCosines(GNC::GCS::IGinkgoMatrix4x4::New());
-	directionCosines->Identity();
-	GetDimensions(dimensions);
 
 
 	//if we have an input connection we take properties from proxy
 	if (p.InputConnection != NULL) {
 		if (IImagePropertiesProxy != NULL) {
 			IImagePropertiesProxy->UpdateInformation();
-			directionCosines->DeepCopy(IImagePropertiesProxy->GetDirection());
-			IImagePropertiesProxy->GetOutputOrigin(origin.v);
-			IImagePropertiesProxy->GetOutputSpacing(spacing.v);
+			//std::cout << GetTickCount() << " Update direction" << std::endl;
+			pr.SetDirection(IImagePropertiesProxy->GetOutputDirection());
+			IImagePropertiesProxy->GetOutputOrigin(origin);
+			IImagePropertiesProxy->GetOutputSpacing(spacing);
 		} else {
 			LOG_ERROR("ginkgoImageViewer", "you are tying to load an image from a input connection without properties proxy");
 		}
 	}
 	else {
 		p.ImageData->UpdateInformation();
-		p.ImageData->GetOrigin(origin.v);
-		p.ImageData->GetSpacing(spacing.v);
+		p.ImageData->GetOrigin(origin);
+		p.ImageData->GetSpacing(spacing);
 	}
 
 #if 0
@@ -657,27 +705,26 @@ void vtkGinkgoImageViewer::UpdateDisplayExtent()
 	std::cout << "Spacing = " << spacing << std::endl;
 #endif
 
-	pr.SetDirection(directionCosines);
+	CurrentOrigin = origin;
 
 	p.ResetMatrices();
+	
+	//build model matrix with directioncosines + spacing + origin
 
+	#if defined(REAL_WORLD_IMAGE_POSITION) 
+	p.ModelMatrix->DeepCopy(pr.GetDirection());
+	#endif
 
-	{
-		//build model matrix with directioncosines + spacing + origin
-		p.ModelMatrix->DeepCopy(directionCosines);
+	GNC::GCS::Ptr<GNC::GCS::IGinkgoMatrix4x4> spacingMatrix(GNC::GCS::IGinkgoMatrix4x4::New());
+	spacingMatrix->Identity();
+	spacingMatrix->SetElement(0,0, spacing.x);
+	spacingMatrix->SetElement(1,1, spacing.y);
+	spacingMatrix->SetElement(2,2, spacing.z);
 
-		GNC::GCS::Ptr<GNC::GCS::IGinkgoMatrix4x4> spacingMatrix(GNC::GCS::IGinkgoMatrix4x4::New());
-		spacingMatrix->Identity();
-		spacingMatrix->SetElement(0,0, spacing.x);
-		spacingMatrix->SetElement(1,1, spacing.y);
-		spacingMatrix->SetElement(2,2, spacing.z);
-
-		p.ModelMatrix = p.ModelMatrix->Multiply4x4(spacingMatrix);
-		p.ModelMatrix->SetElement(0, 3, origin.x);
-		p.ModelMatrix->SetElement(1, 3, origin.y);
-		p.ModelMatrix->SetElement(2, 3, origin.z);
-
-	}
+	p.ModelMatrix = p.ModelMatrix->Multiply4x4(spacingMatrix);
+	p.ModelMatrix->SetElement(0, 3, origin.x);
+	p.ModelMatrix->SetElement(1, 3, origin.y);
+	p.ModelMatrix->SetElement(2, 3, origin.z);
 
 	p.ModelMatrixInv = p.ModelMatrix->Invert();
 
@@ -690,15 +737,12 @@ void vtkGinkgoImageViewer::UpdateDisplayExtent()
 	std::cout << "Matriz Modelo Invertida:" << std::endl;
 	p.ModelMatrixInv->Print(std::cout);
 #endif
-
-	//bounds of the matrix
-	ResetCameraClippingRange();
-
 }
 
-void vtkGinkgoImageViewer::ResetCameraClippingRange()
+void vtkGinkgoImageViewer::ResetCameraClippingRange(bool resetCameraPosition)
 {
 	Pipeline& p  = members->Pipeline;
+	//Propiedades& pr = members->Propiedades;
 
 	//update planeSource...
 	double zpos = 0.0;
@@ -723,6 +767,9 @@ void vtkGinkgoImageViewer::ResetCameraClippingRange()
 			for (int i = 0; i < 4; i++) {
 				p.ModelMatrix->MultiplyPoint(ptest[i], r);
 				GNC::GCS::Vector3D tptest = r;
+
+				CoordenadasMundoACoordenadasMundoReal(tptest.v, tptest.v);
+
 				LOG_DEBUG(ambitolog, "P(" << ptest[i][0] << "," << ptest[i][1] << "," << ptest[i][2] << ") * M  = " << tptest);
 			}
 		}
@@ -746,7 +793,7 @@ void vtkGinkgoImageViewer::ResetCameraClippingRange()
 		p.MapperPlanoOverlay->Modified();
 		p.ImageActor->Modified();
 
-		{
+		if (resetCameraPosition) { // Depending on interaction, could not be desirable to re-position the camera each time (ex: 3D interaction)
 			Estado& e = members->Estado;
 			GNC::GCS::Vector3D plane_center;
 			GNC::GCS::Vector3D plane_normal;
@@ -763,8 +810,8 @@ void vtkGinkgoImageViewer::ResetCameraClippingRange()
 			p.PlaneSource->GetPoint2(plane_p2.v);
 
 			camera_focal_point = plane_center;			
-			camera_view_up =  (plane_origin - plane_p2);
-			camera_position = plane_center - plane_normal;
+			camera_view_up =  (plane_origin - plane_p2).Normalizado();
+			camera_position = plane_center - (plane_normal * 1000.0);
 
 			double rotation = e.RollOffset;
 			if (IImagePropertiesProxy != NULL) {
@@ -774,34 +821,34 @@ void vtkGinkgoImageViewer::ResetCameraClippingRange()
 			bool hflip = e.FlipHorizontal;
 
 			if (e.FlipVertical) {
-				camera_view_up =  (plane_p2 - plane_origin);
+				camera_view_up =  (plane_p2 - plane_origin).Normalizado();
 				hflip = !hflip;
 			}
 			if (hflip) {
-				camera_position = plane_center + plane_normal;
+				camera_position = plane_center + (plane_normal * 1000.0);
 			}			
 
 			vtkCamera *cam = p.Renderer ? p.Renderer->GetActiveCamera() : NULL;
 
 			if (cam != NULL) {
 				cam->SetFocalPoint(camera_focal_point.v);
-				cam->SetPosition(camera_position.v);
-				//necessary for views synchronization in standard view
-				Propiedades& pr = members->Propiedades;
-				pr.CameraFocalPoint[0] = camera_focal_point.v[0];
-				pr.CameraFocalPoint[1] = camera_focal_point.v[1];
-				pr.CameraFocalPoint[2] = camera_focal_point.v[2];
-
-				pr.CameraPosition[0] = camera_position.v[0];
-				pr.CameraPosition[1] = camera_position.v[1];
-				pr.CameraPosition[2] = camera_position.v[2];
-
+				cam->SetPosition(camera_position.v);				
 				cam->SetViewUp(camera_view_up.v);
 				cam->Roll(rotation);
-			}
-		}
+				cam->OrthogonalizeViewUp();
 
-		p.Renderer->ResetCameraClippingRange();
+				//necessary for views synchronization in standard view				
+				Propiedades& pr = members->Propiedades;
+				pr.CameraFocalPoint = camera_focal_point;
+				pr.CameraPosition = camera_position;
+				pr.CameraViewUp = camera_view_up;
+				p.Renderer->ResetCameraClippingRange();
+			}			
+		}
+		else {
+			p.Renderer->ResetCameraClippingRange();
+		}
+		
 	}
 }
 
@@ -809,7 +856,7 @@ void vtkGinkgoImageViewer::UpdateOrientation()
 {
 	Propiedades& pr = members->Propiedades;
 
-	ResetCameraClippingRange();
+	ResetCameraClippingRange(true);
 
 	pr.ResetModifiedStatus();
 }
@@ -833,7 +880,7 @@ void vtkGinkgoImageViewer::IntersectarRayo(double wp[4], double vd[3], double pt
 	}
 }
 
-void vtkGinkgoImageViewer::Proyect2D(const double wp[4], double ip[3]) const
+double* vtkGinkgoImageViewer::Proyect2D(const double wp[4], double ip[3]) const
 {
 	Pipeline& p = members->Pipeline;
 	double pt[4] = {0.0, 0.0, 0.0, 1.0};
@@ -841,14 +888,10 @@ void vtkGinkgoImageViewer::Proyect2D(const double wp[4], double ip[3]) const
 	ip[0] = pt[0];
 	ip[1] = pt[1];
 	ip[2] = pt[2];
-	/*
-	if (IImagePropertiesProxy != NULL) {
-	ip[2] = (double)IImagePropertiesProxy->GetCurrentSliceIndex();
-	}
-	*/
+	return ip;
 }
 
-void vtkGinkgoImageViewer::UnProyect2D(const double ip[3], double wp[4]) const
+double* vtkGinkgoImageViewer::UnProyect2D(const double ip[3], double wp[4]) const
 {
 	Pipeline& p = members->Pipeline;
 	double pt[4] = {0.0, 0.0, 0.0, 1.0};
@@ -861,6 +904,7 @@ void vtkGinkgoImageViewer::UnProyect2D(const double ip[3], double wp[4]) const
 	}
 
 	p.ModelMatrix->MultiplyPoint(pt, wp);
+	return wp;
 }
 
 void vtkGinkgoImageViewer::SetupPipeline(bool forceReload)
@@ -904,7 +948,34 @@ void vtkGinkgoImageViewer::SetupPipeline(bool forceReload)
 		//std::cout << "NULL input" << std::endl;
 	}
 
+	#if defined(DEBUG_PIPELINE)
+
+	if (IImagePropertiesProxy != NULL) {
+		GNC::GCS::Vector3D origin;
+		GNC::GCS::Vector3D spacing;
+		GNC::GCS::Vector3D dimensions;
+		
+		IImagePropertiesProxy->GetOrigin(origin);
+		IImagePropertiesProxy->GetSpacing(spacing);
+		IImagePropertiesProxy->GetFPDimensions(dimensions);
+		
+		const GNC::GCS::Vector3D pt[8] = {
+			GNC::GCS::Vector3D(0.0, 0.0, 0.0), GNC::GCS::Vector3D(1.0, 0.0, 0.0), GNC::GCS::Vector3D(1.0, 1.0, 0.0), GNC::GCS::Vector3D(0.0, 1.0, 0.0),
+			GNC::GCS::Vector3D(0.0, 0.0, 1.0), GNC::GCS::Vector3D(1.0, 0.0, 1.0), GNC::GCS::Vector3D(1.0, 1.0, 1.0), GNC::GCS::Vector3D(0.0, 1.0, 1.0)
+		};
+
+		GNC::GCS::Vector3D pp;		
+		for (int i = 0; i < 8; ++i) {
+			IImagePropertiesProxy->GetDirection()->MultiplyPoint( (dimensions * spacing * pt[i]).v, pp.v);
+			pp = (origin + pp);
+			p.DebugVolumePolyData->GetPoints()->SetPoint(i, pp.v);
+		}
+		
+	}
+	#endif
+
 	if (!e.PipelineInstalled) {
+
 		if (nc == 1)  {
 			p.Textura->MapColorScalarsThroughLookupTableOn();
 			if (p.ImageData != NULL) {
@@ -945,6 +1016,12 @@ void vtkGinkgoImageViewer::SetupPipeline(bool forceReload)
 		}
 		p.ImageActor->Modified();
 		p.ImageActor->VisibilityOn();
+		#if defined(DEBUG_PIPELINE)
+		if (IImagePropertiesProxy != NULL) {
+			p.DebugVolumeActor->Modified();
+			p.DebugVolumeActor->VisibilityOn();
+		}
+		#endif
 		e.PipelineInstalled = true;
 		e.CurrentNumberOfComponents = nc;
 	}
@@ -952,7 +1029,7 @@ void vtkGinkgoImageViewer::SetupPipeline(bool forceReload)
 		if (nc != e.CurrentNumberOfComponents) {
 			if (nc == 1)  { // NC = 1. Antes era 0, 2, 3 o 4
 				p.Textura->MapColorScalarsThroughLookupTableOn();
-				p.StreamConnector->RemoveAllInputs();
+				//p.StreamConnector->RemoveAllInputs();
 				if (p.ImageData != NULL) {
 					GNC::GCS::ILocker lock(p.Textura);
 					p.Textura->SetInput(p.ImageData);
@@ -1032,8 +1109,6 @@ void vtkGinkgoImageViewer::SetupPipeline(bool forceReload)
 	GetOrigin(curOrigin);
 	GetDimensions(curDimensions);
 
-
-
 	for (int i = 0; mantenerVista && i < 3; i++) {
 		if ( (curSpacing[i] != oldSpacing[i]) || (curOrigin[i] != oldOrigin[i]) || (curDimensions[i] != oldDimensions[i])) {
 			mantenerVista = false;
@@ -1048,10 +1123,9 @@ void vtkGinkgoImageViewer::SetupPipeline(bool forceReload)
 	//save camera position to restore if we have to mantain zoom or zoom and pan
 	double focal[3], pos[3];
 	GetRelativePositionOfCamera(focal, pos);
-	UpdateOrientation();
-
+	
 	UpdateDisplayExtent();
-
+	ResetCameraClippingRange(true);
 	//se comprueba si han cambiado las dimensiones o el spacing
 	bool mantenerZoom = true;
 	{
@@ -1384,11 +1458,22 @@ bool vtkGinkgoImageViewer::GetOrigin( double origin[3] , bool testProxy)
 
 bool vtkGinkgoImageViewer::GetBounds( double bounds[6]  )
 {
-	double b[3];
-
 	Estado&   e  = members->Estado;
 	Pipeline& p  = members->Pipeline;
 	if (e.PipelineInstalled) {
+
+		#if defined(DEBUG_PIPELINE)
+		double b1[6];
+		double b2[6];
+		p.DebugVolumeActor->GetBounds(b1);
+		p.ImageActor->GetBounds(b2);
+		for (int i = 0, j = 1; i < 6; i+=2, j+=2) {
+			bounds[i] = std::min(b1[i], b2[i]);
+			bounds[j] = std::max(b1[j], b2[j]);
+		}
+		return true;
+		#else
+		double b[3];
 		GNC::GCS::Vector3D p1, p2, pt;
 		p.PlaneSource->GetOrigin(b);
 		bounds[0] = b[0];
@@ -1408,6 +1493,8 @@ bool vtkGinkgoImageViewer::GetBounds( double bounds[6]  )
 		bounds[3] = pt.y;
 		bounds[5] = pt.z;
 		return true;
+		#endif
+		
 	}
 	else {
 		for (int i = 0; i < 6; i++) {
@@ -1783,6 +1870,40 @@ void vtkGinkgoImageViewer::CopyCameraStatus(vtkGinkgoImageViewer* w)
 	}
 }
 
+void vtkGinkgoImageViewer::CopyCamera(const vtkGinkgoImageViewer* w)
+{
+	if (w == this || w == NULL) {
+		return;
+	}
+	else {
+		Pipeline& p            = members->Pipeline;
+		const Pipeline& po     = w->members->Pipeline;
+
+		Propiedades& pr        = members->Propiedades;
+		const Propiedades& pro = w->members->Propiedades;
+
+		pr.CameraPosition       = pro.CameraPosition;
+		pr.CameraFocalPoint     = pro.CameraFocalPoint;
+		pr.CameraViewUp         = pro.CameraViewUp;
+		pr.ParallelScale        = pro.ParallelScale;
+
+		vtkCamera *c        = p.Renderer->GetActiveCamera();
+		vtkCamera *co = po.Renderer->GetActiveCamera();
+
+		double tmp[3];
+		co->GetPosition(tmp);
+		c->SetPosition(tmp);
+
+		co->GetFocalPoint(tmp);
+		c->SetFocalPoint(tmp);
+
+		co->GetViewUp(tmp);
+		c->SetViewUp(tmp);
+
+		c->SetParallelScale(co->GetParallelScale());
+	}
+}
+
 void vtkGinkgoImageViewer::ClearRotationAndFlip(bool update)
 {
 	Estado& e = members->Estado;
@@ -1791,7 +1912,9 @@ void vtkGinkgoImageViewer::ClearRotationAndFlip(bool update)
 	e.FlipHorizontal = false;
 
 	if (update) {
-		UpdateOrientation();
+		Propiedades& pr = members->Propiedades;
+		ResetCameraClippingRange(true);
+		pr.ResetModifiedStatus();
 	}
 }
 
@@ -1811,6 +1934,22 @@ void vtkGinkgoImageViewer::RotateCamera( bool right)
 	UpdateOrientation();
 }
 
+void vtkGinkgoImageViewer::RotateCamera( double angle)
+{
+	Estado& e = members->Estado;
+
+	e.RollOffset += angle;
+
+	if (e.RollOffset > 180.0) {
+		e.RollOffset -= 360.0;
+	}
+	else if (e.RollOffset <= -180.0) {
+		e.RollOffset += 360.0;
+	}
+
+	//update has to be call UpdateOrientation();
+}
+
 void vtkGinkgoImageViewer::Flip(bool vertical)
 {
 	Estado& e = members->Estado;
@@ -2047,6 +2186,35 @@ int vtkGinkgoImageViewer::GetIdLookupTable()
 	return members->Pipeline.LookupTableId;
 }
 
+/** Set Image Brightness (-1.0, 0.0, 1.0) (Only aplicable with RGB Images) **/
+void vtkGinkgoImageViewer::SetBrightness(float brightness)
+{
+	members->Pipeline.Textura->SetBrightness(brightness);
+}
+
+/** Set Image Contrast (-1.0, 0.0, 1.0) (Only aplicable with RGB Images) **/
+void vtkGinkgoImageViewer::SetContrast(float contrast)
+{
+	members->Pipeline.Textura->SetContrast(contrast);
+}
+
+/** Get Image Brightness (-1.0, 0.0, 1.0) (Only aplicable with RGB Images) **/
+float vtkGinkgoImageViewer::GetBrightness()
+{
+	return members->Pipeline.Textura->GetBrightness();
+}
+
+/** Get Image Contrast (-1.0, 0.0, 1.0) (Only aplicable with RGB Images) **/
+float vtkGinkgoImageViewer::GetContrast()
+{
+	return members->Pipeline.Textura->GetContrast();
+}
+
+void vtkGinkgoImageViewer::ResetBrightnessAndContrast()
+{
+	members->Pipeline.Textura->ResetBrightnessAndContrast();
+}
+
 //region Control: Zoom
 void vtkGinkgoImageViewer::ResetZoom(bool mantenerZoom, int zoomMode)
 {
@@ -2277,7 +2445,7 @@ void vtkGinkgoImageViewer::CoordenadasMundoACoordenadasImagen(const double wp[3]
 	ip[2] = (wp[2] - origin[2]) / spacing[2];
 }
 
-void vtkGinkgoImageViewer::CoordenadasImagenACoordenadasPixel(const double ip[3], int pp[2])
+void vtkGinkgoImageViewer::CoordenadasImagenACoordenadasPixel(const double ip[3], int pp[3])
 {
 	//Transforma a coordenadas pixel para usar con vtk (un 0.5 del desplazamiento y otro para hacer un round)
 	pp[0] = floor(ip[0] + 0.5);
@@ -2290,6 +2458,26 @@ void vtkGinkgoImageViewer::CoordenadasImagenACoordenadasPixel(GNC::GCS::Vector&
 	vector += 0.5;
 }
 
+void vtkGinkgoImageViewer::CoordenadasMundoACoordenadasMundoReal(const double wp[3], double rwp[3])
+{
+	#if defined(REAL_WORLD_IMAGE_POSITION)
+		if (wp != rwp) {
+			rwp[0] = wp[0];
+			rwp[1] = wp[1];
+			rwp[2] = wp[2];
+		}
+	#else
+		Propiedades& pr = members->Propiedades;
+		GNC::GCS::Vector3D v = wp;
+		v -= CurrentOrigin;
+		pr.GetDirection()->MultiplyPoint(v.v, v.v);
+		v += CurrentOrigin;
+		rwp[0] = v.x;
+		rwp[1] = v.y;
+		rwp[2] = v.z;
+	#endif
+}
+
 //--------------------------------------------------------------------
 //region Anotaciones
 void vtkGinkgoImageViewer::ActualizarAnotaciones()
@@ -2421,6 +2609,12 @@ bool vtkGinkgoImageViewer::GetLinkRender()
 	return p.LinkRender;
 }
 
+void vtkGinkgoImageViewer::InternalEnableShaders(bool enabled)
+{
+	Pipeline& p = members->Pipeline;
+	p.Textura->ForceEnableShaders(enabled);
+}
+
 //------------------------------------------------------------------------------------------------------
 
 void vtkGinkgoImageViewer::SetupAnnotations()
