@@ -3,7 +3,7 @@
  *  $Id: vtkginkgoimageviewer.h $
  *  Ginkgo CADx Project
  *
- *  Copyright 2008-12 MetaEmotion S.L. All rights reserved.
+ *  Copyright 2008-14 MetaEmotion S.L. All rights reserved.
  *  http://ginkgo-cadx.com
  *
  *  This file is licensed under LGPL v3 license.
@@ -13,6 +13,8 @@
  */
 #pragma once
 
+#define REAL_WORLD_IMAGE_POSITION // Use direction cosines to position image plane. Otherwise vtk position is used (identity cosines) and real position is calculated translating and rotating.
+
 #include <vector>
 #include <iostream>
 
@@ -139,7 +141,7 @@ public:
 	*/
 	void Detach (void);
 
-	void ResetCameraClippingRange();
+	void ResetCameraClippingRange(bool resetCameraPosition = true);
 
 	void UpdateOrientation();
 
@@ -156,10 +158,10 @@ public:
 	void IntersectarRayo(double wp[4], double vd[3], double pt[3]);
 
 	/** Proyecta un punto en coordenadas mundo a coordenadas imagen (plano con z=currentSlice) **/
-	void Proyect2D(const double wp[4], double ip[2]) const;
+	double* Proyect2D(const double wp[4], double ip[2]) const;
 
 	/** Proyecta un punto en coordenadas imagen (plano con z=currentSlice) a coordenadas mundo **/
-	void UnProyect2D(const double ip[3], double wp[4]) const;
+	double* UnProyect2D(const double ip[3], double wp[4]) const;
 
 	void SetupPipeline(bool forceReload = false);
 
@@ -263,7 +265,11 @@ public:
 
 	int GetOrientation();
 	
-	void CopyCameraStatus(vtkGinkgoImageViewer* w);
+	/** Copy camera status from other **/
+	void CopyCameraStatus(vtkGinkgoImageViewer* other);
+
+	/** Copy camera from other **/
+	void CopyCamera(const vtkGinkgoImageViewer* other);
 
 	/** Returns the current camera rotation in radians (-PI/2, PI/2] **/
 	double GetCameraRotation() const;
@@ -313,6 +319,7 @@ public:
 
 	void ClearRotationAndFlip(bool update = false);
 	void RotateCamera( bool right);
+	void RotateCamera( double angle);
 	void Flip(bool vertical);
 
 
@@ -340,6 +347,20 @@ public:
 	vtkSmartPointer<vtkScalarsToColors> GetLookupTable();
 	int GetIdLookupTable();
 
+	/** Set Image Brightness (-1.0, 0.0, 1.0) (Only aplicable with RGB Images) **/
+	void SetBrightness(float brightness);
+	
+	/** Set Image Contrast (-1.0, 0.0, 1.0) (Only aplicable with RGB Images) **/
+	void SetContrast(float contrast);
+
+	/** Get Image Brightness (-1.0, 0.0, 1.0) (Only aplicable with RGB Images) **/
+	float GetBrightness();
+
+	/** Get Image Contrast (-1.0, 0.0, 1.0) (Only aplicable with RGB Images) **/
+	float GetContrast();
+
+	void ResetBrightnessAndContrast();
+
 	//region Control: Zoom
 	void SetInitialParallelScale(double scale);
 	/**
@@ -373,6 +394,9 @@ public:
 
 	void CoordenadasMundoACoordenadasImagen(const double wp[3], double ip[3]);
 
+	/** Apply cosines correction if needed **/
+	void CoordenadasMundoACoordenadasMundoReal(const double wp[3], double rwp[3]);
+
 	//--------------------------------------------------------------------
 	//region Anotaciones
 	void ActualizarAnotaciones();
@@ -452,6 +476,9 @@ public:
 	void SetLinkRender(bool linkRender);
 	bool GetLinkRender();
 
+	/**force disable shaders...*/
+	void InternalEnableShaders(bool enabled);
+
 protected:
 
 	//BTX
@@ -491,4 +518,6 @@ public:
 
 	GNC::GCS::Vector3D SliceCoordinates[4];
 
+	GNC::GCS::Vector3D CurrentOrigin;
+
 };
