@@ -66,6 +66,43 @@ vtkCxxRevisionMacro(vtkGinkgoOpenGLTexture, "$Revision: 1.81 $");
 vtkStandardNewMacro(vtkGinkgoOpenGLTexture);
 #endif
 
+#define ADAPTATIVE_BRIGHNESS_CONTRAST
+
+inline char clampByte(int color) {
+	if( color & (~255) ) {
+		color = (char)((-(color)) >> 31);
+	}
+	else{
+		color = (char)(color);
+	}
+}
+
+// integer implementation (fast but incomplete)
+inline char mixFixedPoint( char x, char y, char a) {
+	unsigned int alpha = a;
+    unsigned int inv_alpha = 255 - a;
+    return clampByte( (alpha * x + inv_alpha * y) >> 8);
+}
+
+/** Interpolate the normalized values between "x" and "y" with factor "1-a, a" (slow) **/
+inline float mixNormalized(float x, float y, float a) {
+	return x * (1.0f - a) + (y * a);        
+}
+
+inline float clamp(float min, float max, float val) {
+	if (val > max) {
+		return max;
+	}
+	else {
+		if (val < min) {
+			return min;
+		}
+		else {
+			return val;
+		}
+	}
+}
+
 // ----------------------------------------------------------------------------
 // Initializes an instance, generates a unique index.
 vtkGinkgoOpenGLTexture::vtkGinkgoOpenGLTexture()
@@ -84,11 +121,57 @@ vtkGinkgoOpenGLTexture::vtkGinkgoOpenGLTexture()
 	this->ProgramObject=0;
 	this->LUTIndex=0;
 	this->UseShader=false;
+	this->InternalEnableShaders = true;
 	this->zsize=0;
 	this->TIndex=0;
 	this->TIndexChanged=false;
 	this->LookupTableChanged = false;
+	this->RGBImage = false;
+	this->ResetBrightnessAndContrast();
+}
 
+void vtkGinkgoOpenGLTexture::SetBrightness(float brightness)
+{
+	#if defined(ADAPTATIVE_BRIGHNESS_CONTRAST)
+		this->Brightness = brightness;
+	#else
+		this->Brightness = clamp(-1.0f, 1.0f, brightness);
+	#endif
+
+	this->LookupTableChanged = true;
+}
+
+void vtkGinkgoOpenGLTexture::SetContrast(float contrast)
+{
+	#if defined(ADAPTATIVE_BRIGHNESS_CONTRAST)
+		this->Contrast = contrast;
+	#else
+	this->Contrast = clamp(0.0f, 2.0f, contrast);
+	#endif
+	
+	this->LookupTableChanged = true;
+}
+
+float vtkGinkgoOpenGLTexture::GetBrightness()
+{
+	return this->Brightness;
+}
+
+float vtkGinkgoOpenGLTexture::GetContrast()
+{
+	return this->Contrast;
+}
+
+void vtkGinkgoOpenGLTexture::ResetBrightnessAndContrast() 
+{
+
+	#if defined(ADAPTATIVE_BRIGHNESS_CONTRAST)
+	this->Brightness = 1.0f;
+	#else
+	this->Brightness = 0.0f;
+	#endif
+	this->Contrast = 1.0f;
+	this->LookupTableChanged = true;
 }
 
 // ----------------------------------------------------------------------------
@@ -159,6 +242,7 @@ void vtkGinkgoOpenGLTexture::ReleaseGraphicsResources(vtkWindow *renWin)
 void vtkGinkgoOpenGLTexture::Load(vtkRenderer *ren)
 {
 	vtkImageData *input = NULL;
+
 	GNC::GCS::ILocker lock(this);
 	{
 		input = this->GetInput();
@@ -232,6 +316,7 @@ void vtkGinkgoOpenGLTexture::Load(vtkRenderer *ren)
 			( this->GetMTime() > this->LoadTime.GetMTime() )
 			|| ( input->GetMTime() > this->LoadTime.GetMTime() )
 			|| ( !UseShader && this->GetLookupTable() && (this->GetLookupTable()->GetMTime () > this->LoadTime.GetMTime()) )
+			|| ( !UseShader && LookupTableChanged )
 			|| ( renWin != this->RenderWindow.GetPointer() )
 			|| ( renWin->GetContextCreationTime() > this->LoadTime );
 
@@ -286,7 +371,7 @@ void vtkGinkgoOpenGLTexture::Load(vtkRenderer *ren)
 			ysize = size[1];
 			zsize = size[2];
 
-			if (xsize == 0 || ysize == 0 || zsize == 0)
+			if (xsize <= 0 || ysize <= 0 || zsize <= 0)
 			{
 				LOG_ERROR("OpenGLComponent", "Wrong size: " << xsize << "x" << ysize << "x" << zsize);
 				return;
@@ -305,12 +390,15 @@ void vtkGinkgoOpenGLTexture::Load(vtkRenderer *ren)
 					m->LoadExtension("GL_ARB_multitexture");
 					m->LoadExtension("GL_VERSION_2_0");
 					//ENABLE/DISABLE SHADER!
-					if (GNC::GCS::IControladorPermisos::Instance()->Get("core.opengl", "enable_shaders").Activo()) {
+					if (this->InternalEnableShaders && GNC::GCS::IControladorPermisos::Instance()->Get("core.opengl", "enable_shaders").Activo()) {
 						this->UseShader = true;
 					}
 				}
 			}
 
+			if (!UseShader) {
+				LookupTableChanged = false; // Reset LUT changed state
+			}
 
 			TIndex = std::max<int>(0, std::min<int>(TIndex, zsize - 1));
 			TIndexChanged = false;
@@ -319,14 +407,16 @@ void vtkGinkgoOpenGLTexture::Load(vtkRenderer *ren)
 
 			// make sure using unsigned char data of color scalars type
 			// IF MAP SCALARS
-			if (1 && (this->MapColorScalarsThroughLookupTable ||
-				scalars->GetDataType() != VTK_UNSIGNED_CHAR) )
+			if ( (this->MapColorScalarsThroughLookupTable) || (scalars->GetDataType() != VTK_UNSIGNED_CHAR) )
 			{
 				const unsigned int wdh = size[0] * size[1];
 				const unsigned int numComponents = scalars->GetNumberOfComponents();
+				
+				this->RGBImage = false;
 
 				//IF THERE IS ONLY ONE COMPONENT COULD USE SHADERS...
 				if (numComponents == 1) {
+
 					if (UseShader) {
 						double range[2] = {0.0, 1.0};
 						scalars->GetRange(range);
@@ -356,6 +446,7 @@ void vtkGinkgoOpenGLTexture::Load(vtkRenderer *ren)
 							off = size[0] * size[1] * TIndex * bytesPerPixel;
 							unsigned char* dptr = (unsigned char*) scalars->GetVoidPointer(0);
 							if (dptr == NULL) {
+								delete[] resamplePixelData;
 								LOG_ERROR("OpenGLComponent", "Could not get pixel data pointer");
 								return;
 							}
@@ -365,14 +456,29 @@ void vtkGinkgoOpenGLTexture::Load(vtkRenderer *ren)
 							unsigned short* dst = resamplePixelData;
 							short* src = (short*)vptr;
 
+							// Verificaciones extra para VIX. El flujo permanece igual.
 							unsigned short v;
+							long long maxVal1 = - ( (long long) std::numeric_limits<unsigned short>::min());
+							long long minVal1 = ( (long long) std::numeric_limits<unsigned short>::max());
+
+							long long maxVal2 = - ( (long long) std::numeric_limits<unsigned short>::min());
+							long long minVal2 = ( (long long) std::numeric_limits<unsigned short>::max());
+
 							for (unsigned int i = 0; i < psize; i++) {
 								if (scalars->GetDataType() == VTK_UNSIGNED_SHORT) {
-									const unsigned short v1 = *((unsigned short*)src);
-									v = (unsigned short)(( scale * ( v1 - range[0]) )*std::numeric_limits<unsigned short>::max());
-									src++;
+									const unsigned short v1 = *((unsigned short*) src++);
+									minVal1 = std::min(minVal1, (long long)v1);
+									maxVal1 = std::max(maxVal1, (long long)v1);
+									v = (unsigned short)(( scale * ((double)v1 - range[0]) ) * std::numeric_limits<unsigned short>::max());
+									minVal2 = std::min(minVal2, (long long)v);
+									maxVal2 = std::max(maxVal2, (long long)v);
 								} else {
-									v = (unsigned short)(( scale * ((short) *(src++) - range[0]) )*std::numeric_limits<unsigned short>::max());
+									const signed short v1 = *((signed short*) src++);
+									minVal1 = std::min(minVal1, (long long)v1);
+									maxVal1 = std::max(maxVal1, (long long)v1);
+									v = (unsigned short)(( scale * ((double)v1 - range[0]) ) * std::numeric_limits<unsigned short>::max());
+									minVal2 = std::min(minVal2, (long long)v);
+									maxVal2 = std::max(maxVal2, (long long)v);
 								}
 								*(dst++) =  v;
 							}
@@ -398,6 +504,7 @@ void vtkGinkgoOpenGLTexture::Load(vtkRenderer *ren)
 							off = size[0] * size[1] * TIndex * bytesPerPixel;
 							unsigned char* dptr = (unsigned char*) scalars->GetVoidPointer(0);
 							if (dptr == NULL) {
+								delete[] resamplePixelData;
 								LOG_ERROR("OpenGLComponent", "Could not get pixel data pointer");
 								return;
 							}
@@ -421,7 +528,7 @@ void vtkGinkgoOpenGLTexture::Load(vtkRenderer *ren)
 							pResampledPixelData = (unsigned char*) resamplePixelData;
 							vptr = pResampledPixelData;
 						} else {
-							LOG_WARN("OpenGLComponent", "Shaders don't support this component type: Wrong size: " << scalars->GetDataTypeAsString());
+							LOG_DEBUG("OpenGLComponent", "Shaders don't support this component type: Wrong size: " << scalars->GetDataTypeAsString());
 							this->UseShader = false;
 						}
 					} 
@@ -651,6 +758,7 @@ void vtkGinkgoOpenGLTexture::Load(vtkRenderer *ren)
 						}
 						break;
 					default:
+						delete[] pResampledPixelData;
 						LOG_ERROR("OpenGLComponent", "Pixel data not supported");
 						return;
 					}
@@ -661,21 +769,49 @@ void vtkGinkgoOpenGLTexture::Load(vtkRenderer *ren)
 			}
 			else
 			{
+				if ( (scalars->GetDataType() == VTK_UNSIGNED_CHAR) ) {
+					this->RGBImage = true;
+				}
+				else {
+					this->RGBImage = false;
+					this->UseShader = false;
+				}
+
 				//RGB IMAGES
 				unsigned char *s_array = static_cast<vtkUnsignedCharArray *>(scalars)->GetPointer(0);
 				if (s_array != NULL) {
-					vptr = s_array + off;
+					int bsize = bytesPerPixel * size[0] * size[1];
+
+					unsigned char *src = s_array + off;
+					unsigned char *dst = vptr = pResampledPixelData = new unsigned char[bsize];
+
+					#if defined (ADAPTATIVE_BRIGHNESS_CONTRAST)
+					for (int i = 0; i < bsize; i++) {
+						const float colorIn = (float) ( *(src++) ) / 255.0f;
+						const float clampedResult = clamp(0.0f, 1.0f, mixNormalized( colorIn * Brightness, mixNormalized(0.5f, colorIn, Contrast), 0.5f ));
+						const char colorOut = (char) ( clamp(0.0f, 255.0f, 255.0f * clampedResult) );
+						*(dst++) = colorOut;
+					}
+					#else
+					std::cout << "---\nBrightness = " << Brightness << std::endl;
+					std::cout << "Contrast =  " << Contrast << std::endl;
+
+					for (int i = 0; i < bsize; i++) {
+						const float colorIn = (float) ( *(src++) ) / 255.0f;
+						const float clampedResult = clamp(0.0f, 1.0f, ((colorIn - 0.5f) * std::max<float>(Contrast, 0.0f)) + 0.5f + Brightness );
+						const char colorOut = (char) ( clamp(0.0f, 255.0f, 255.0f * clampedResult) );
+						*(dst++) = colorOut;
+					}
+					#endif
 				}
 				else {
 					LOG_DEBUG("OpenGLComponent", "Could not get pixel data pointer");
 					return;
 				}
-
-				this->UseShader = false;
 			}
 
 			//if no use pixel shader...
-			if (!this->UseShader) {
+			if (!this->UseShader || RGBImage) {
 				TexInternalFormat = bytesPerPixel;
 				TexType = GL_UNSIGNED_BYTE;
 				switch (bytesPerPixel)
@@ -741,8 +877,7 @@ void vtkGinkgoOpenGLTexture::Load(vtkRenderer *ren)
 			if(resampleNeeded)
 			{
 				vtkDebugMacro(<< "Resampling texture to power of two for OpenGL");
-				resultData = this->ResampleToPowerOfTwo(xsize, ysize, vptr,
-					bytesPerPixel);
+				resultData = this->ResampleToPowerOfTwo(xsize, ysize, vptr, bytesPerPixel);
 				pNPOTPixelData = resultData;
 
 			}
@@ -881,7 +1016,38 @@ void vtkGinkgoOpenGLTexture::Load(vtkRenderer *ren)
 
 					this->FragmentProgram = vtkgl::CreateShader(vtkgl::FRAGMENT_SHADER);
 					terror = glGetError();
-					std::string FragmenProgramCode =
+
+					std::string FragmenProgramCode;
+
+					if (this->RGBImage) { // RGB Frament shader program.  
+						#if defined(ADAPTATIVE_BRIGHNESS_CONTRAST) // "The OpenGL Shading Language" C.19.
+						FragmenProgramCode =
+						"uniform sampler2D imagetexture;"
+						"uniform float brightness;"
+						"uniform float contrast;"
+						"vec4 averageLuminance = vec4(0.5, 0.5, 0.5, 1.0);"
+						"void main(void)"
+						"{"
+						"vec4 color = texture2D(imagetexture, gl_TexCoord[0].xy);"
+						"gl_FragColor = mix(color * brightness, mix(averageLuminance, color, contrast), 0.5);"
+						"}";
+						#else
+						FragmenProgramCode =
+						"uniform sampler2D imagetexture;"
+						"uniform float brightness;"
+						"uniform float contrast;"
+						"void main(void)"
+						"{"
+						"vec4 color = texture2D(imagetexture, gl_TexCoord[0].xy);"
+						"float pa = color.a;"
+						"color = ((color - 0.5) * max(contrast, 0.0)) + 0.5 + brightness;"
+						"color.a = pa;"
+						"gl_FragColor = color;"
+						"}";
+						#endif
+					}
+					else { // GrayLevel Frament shader program
+						FragmenProgramCode =
 						"uniform sampler2D imagetexture;"
 						"uniform sampler1D lookuptable;"
 						"uniform float lutShift;"
@@ -902,6 +1068,7 @@ void vtkGinkgoOpenGLTexture::Load(vtkRenderer *ren)
 						//"cr.a = 1.0;"
 						"gl_FragColor = cr;"
 						"}";
+					}
 					const char* ptr2 = (const char*)FragmenProgramCode.c_str();
 					vtkgl::ShaderSource(this->FragmentProgram, 1, &ptr2, 0);
 					terror = glGetError();
@@ -967,13 +1134,15 @@ void vtkGinkgoOpenGLTexture::Load(vtkRenderer *ren)
 				increments[0] = 0;
 				increments[1] = 0;
 
-				/*this->PBO->Upload2D(VTK_UNSIGNED_CHAR,resultData,dims,bytesPerPixel,
-				increments);*/
-				if (UseShader) { 
-					this->PBO->Upload2D(scalars->GetDataType(), resultData, dims, scalars->GetNumberOfComponents(), increments);
-				} else {
-					this->PBO->Upload2D(VTK_UNSIGNED_CHAR,resultData,dims,bytesPerPixel,
-						increments);
+				if (RGBImage) {
+					this->PBO->Upload2D(VTK_UNSIGNED_CHAR, resultData, dims, bytesPerPixel, increments);
+				}
+				else {
+					if (UseShader) { 
+						this->PBO->Upload2D(scalars->GetDataType(), resultData, dims, scalars->GetNumberOfComponents(), increments);
+					} else {
+						this->PBO->Upload2D(VTK_UNSIGNED_CHAR, resultData, dims, bytesPerPixel, increments);
+					}
 				}
 				// non-blocking call
 				this->PBO->Bind(vtkPixelBufferObject::UNPACKED_BUFFER);
@@ -1005,33 +1174,49 @@ void vtkGinkgoOpenGLTexture::Load(vtkRenderer *ren)
 		}// end if changes...
 
 		//UPLOAD LOOKUP TABLE IF NEEDED
-		if (this->UseShader && (this->LUTIndex == 0 || LookupTableChanged)) {
-			LookupTableChanged = false;
+		bool LUT_NeedsToBeInitialized = !RGBImage && this->LUTIndex == 0;
 
-			//glEnable(GL_TEXTURE_1D);
-#if defined(_WINDOWS) || defined(__WXGTK__)
-			vtkgl::ActiveTextureARB(vtkgl::TEXTURE1_ARB);
-#else
-			glActiveTexture(vtkgl::TEXTURE1_ARB);
-#endif
-			glGenTextures(1, &this->LUTIndex);
-			glBindTexture(GL_TEXTURE_1D, this->LUTIndex);
-			glTexParameterf( GL_TEXTURE_1D, GL_TEXTURE_MIN_FILTER,
-				GL_NEAREST);
-			glTexParameterf( GL_TEXTURE_1D, GL_TEXTURE_MAG_FILTER,
-				GL_NEAREST );
-			glTexParameterf( GL_TEXTURE_1D, GL_TEXTURE_WRAP_S,     GL_CLAMP );
-			glTexParameterf( GL_TEXTURE_1D, GL_TEXTURE_WRAP_T,     GL_CLAMP );
+		if (this->UseShader && ( LUT_NeedsToBeInitialized || LookupTableChanged)) {
+			if (RGBImage) {
+			}
+			else if (LookupTable != NULL) {
 
-			glTexImage1D( GL_TEXTURE_1D, 0 , GL_RGBA,
-				static_cast<vtkLookupTable*>(LookupTable)->GetNumberOfTableValues(), 0, GL_RGBA,
-				GL_UNSIGNED_BYTE, static_cast<vtkLookupTable*>(LookupTable)->GetPointer(0));
-#if defined(_WINDOWS) || defined(__WXGTK__)
-			vtkgl::ActiveTextureARB(vtkgl::TEXTURE0_ARB);
-#else
-			glActiveTexture(vtkgl::TEXTURE0_ARB);
-#endif
+				GLsizei lutNvals = 1024;
+				GLvoid* lutData = NULL;
+				
+				if (LookupTable != NULL) {
+					vtkLookupTable* LUT = static_cast<vtkLookupTable*>(LookupTable);
+					lutNvals = LUT->GetNumberOfTableValues();
+					lutData = LUT->GetPointer(0);
+				}
+				else {
+					LOG_ERROR("OpenGLComponent", "LUT Not found. Bad initiallization");
+				}
+
+				//glEnable(GL_TEXTURE_1D);
+				#if defined(_WINDOWS) || defined(__WXGTK__)
+				vtkgl::ActiveTextureARB(vtkgl::TEXTURE1_ARB);
+				#else
+				glActiveTexture(vtkgl::TEXTURE1_ARB);
+				#endif
+				glGenTextures(1, &this->LUTIndex);
+				glBindTexture(GL_TEXTURE_1D, this->LUTIndex);
+				glTexParameterf( GL_TEXTURE_1D, GL_TEXTURE_MIN_FILTER, GL_NEAREST);
+				glTexParameterf( GL_TEXTURE_1D, GL_TEXTURE_MAG_FILTER, GL_NEAREST );
+				glTexParameterf( GL_TEXTURE_1D, GL_TEXTURE_WRAP_S,     GL_CLAMP );
+				glTexParameterf( GL_TEXTURE_1D, GL_TEXTURE_WRAP_T,     GL_CLAMP );
+
+				glTexImage1D( GL_TEXTURE_1D, 0 , GL_RGBA,
+					lutNvals, 0, GL_RGBA,
+					GL_UNSIGNED_BYTE, lutData);
+				#if defined(_WINDOWS) || defined(__WXGTK__)
+				vtkgl::ActiveTextureARB(vtkgl::TEXTURE0_ARB);
+				#else
+				glActiveTexture(vtkgl::TEXTURE0_ARB);
+				#endif
+			}
 		}
+		LookupTableChanged = false;
 	}
 
 	// execute the display list that uses creates the texture
@@ -1057,7 +1242,9 @@ void vtkGinkgoOpenGLTexture::Load(vtkRenderer *ren)
 
 	// now bind it
 	if (this->UseShader) {
-		glEnable(GL_TEXTURE_1D);
+		if (!this->RGBImage) {
+			glEnable(GL_TEXTURE_1D);
+		}
 	}
 	glEnable(GL_TEXTURE_2D);
 	// clear any texture transform
@@ -1108,6 +1295,9 @@ void vtkGinkgoOpenGLTexture::Load(vtkRenderer *ren)
 		vtkgl::UseProgram(this->ProgramObject);
 		error = glGetError();
 
+		// Common parameters for shaders
+
+		// === imageTexture ===
 		loc = vtkgl::GetUniformLocation(this->ProgramObject,"imagetexture");
 		if(loc != -1)
 		{
@@ -1115,47 +1305,79 @@ void vtkGinkgoOpenGLTexture::Load(vtkRenderer *ren)
 		}
 		else
 		{
-			LOG_ERROR("OpenGLComponent", "error: image is not a uniform");
+			LOG_ERROR("OpenGLComponent", "error: imagetexture is not a uniform");
 		}
 
-		loc = vtkgl::GetUniformLocation(this->ProgramObject,"lookuptable");
-		if(loc != -1)
-		{
-			vtkgl::Uniform1i(loc, 1);
+		if (this->RGBImage) { // Parameters for RGB shader
+			
+			// === brightness ===
+			loc = vtkgl::GetUniformLocation(this->ProgramObject, "brightness");
+			if(loc != -1)
+			{
+				vtkgl::Uniform1f(loc, Brightness);
+			}
+			else
+			{
+				LOG_ERROR("OpenGLComponent", "error: brightness is not a uniform");
+			}
+
+			// === contrast ===
+			loc = vtkgl::GetUniformLocation(this->ProgramObject, "contrast");
+			if(loc != -1)
+			{
+				vtkgl::Uniform1f(loc, Contrast);
+			}
+			else
+			{
+				LOG_ERROR("OpenGLComponent", "error: contrast is not a uniform");
+			}
+												
 		}
-		else
-		{
-			LOG_ERROR("OpenGLComponent", "error: lut is not a uniform");
+		else { // Parameters for LUT shader
+
+			// === lookupTable ===
+			loc = vtkgl::GetUniformLocation(this->ProgramObject,"lookuptable");
+			if(loc != -1)
+			{
+				vtkgl::Uniform1i(loc, 1);
+			}
+			else
+			{
+				LOG_ERROR("OpenGLComponent", "error: lut is not a uniform");
+			}
+
+			double normRange[2] = {0.0, 1.0};		
+			vtkDataArray *scalars = this->GetInputArrayToProcess(0, input);
+			scalars->GetRange(normRange);
+			double* drange = LookupTable->GetRange();
+
+			float range[2] = { (drange[0]-normRange[0]) / (normRange[1]-normRange[0]), (drange[1]-normRange[0]) / (normRange[1]-normRange[0])};
+
+			// === shift ===
+			float shift = -range[0];
+			loc = vtkgl::GetUniformLocation(this->ProgramObject,"lutShift");
+			if(loc != -1)
+			{
+				vtkgl::Uniform1f(loc, shift);
+			}
+			else
+			{
+				LOG_ERROR("OpenGLComponent", "error: shift is not a uniform");
+			}
+
+			// === scale ===
+			float scale = (1.0f)/(range[1] - range[0]);
+			loc = vtkgl::GetUniformLocation(this->ProgramObject,"lutScale");
+			if(loc != -1)
+			{
+				vtkgl::Uniform1f(loc, scale);
+			}
+			else
+			{
+				LOG_ERROR("OpenGLComponent", "error: scale is not a uniform");
+			}
 		}
 
-		double normRange[2] = {0.0, 1.0};		
-		vtkDataArray *scalars = this->GetInputArrayToProcess(0, input);
-		scalars->GetRange(normRange);
-		double* drange = LookupTable->GetRange();
-
-		float range[2] = { (drange[0]-normRange[0]) / (normRange[1]-normRange[0]), (drange[1]-normRange[0]) / (normRange[1]-normRange[0])};
-		float shift = -range[0];
-		float scale = (1.0f)/(range[1] - range[0]);
-
-		loc = vtkgl::GetUniformLocation(this->ProgramObject,"lutShift");
-		if(loc != -1)
-		{
-			vtkgl::Uniform1f(loc, shift);
-		}
-		else
-		{
-			LOG_ERROR("OpenGLComponent", "error: shift is not a uniform");
-		}
-
-		loc = vtkgl::GetUniformLocation(this->ProgramObject,"lutScale");
-		if(loc != -1)
-		{
-			vtkgl::Uniform1f(loc, scale);
-		}
-		else
-		{
-			LOG_ERROR("OpenGLComponent", "error: scale is not a uniform");
-		}
 		glDisable(vtkgl::FRAGMENT_PROGRAM_ARB);
 	}
 }
@@ -1313,3 +1535,9 @@ void vtkGinkgoOpenGLTexture::PrintSelf(ostream& os, vtkIndent indent)
 	this->Superclass::PrintSelf(os,indent);
 	os << indent << "Index: " << this->Index << endl;
 }
+
+
+void vtkGinkgoOpenGLTexture::ForceEnableShaders(bool force)
+{
+	InternalEnableShaders = force;
+}
