@@ -31,12 +31,15 @@
 #include <api/icontexto.h>
 #include <api/math/geometry3d.h>
 #include <api/westilo.h>
+#include <api/dicom/dcmdictionary.h>
+#include <api/iannotator.h>
 
 #include <eventos/modificacionimagen.h>
 
 #include <main/entorno.h>
 #include <main/controllers/controladoreventos.h>
 #include <main/controllers/configurationcontroller.h>
+#include <main/controllers/modalitysettingscontroller.h>
 
 #include "wanotacionesquina.h"
 
@@ -47,12 +50,11 @@
 #include <vtk/vtkginkgoimageviewer.h>
 #include "striptexthelper.h"
 
-
 #define ANNOTATOR_TEXT_COLOR 0.9f, 0.9f, 0.9f, 1.0f
 
 namespace GNC {
-	const char* PatientOrientation[9*3*3] = {
-		"", "", "",   "", "", "",   "", "", "", // N/A
+	const char* PatientOrientation[10*3*3] = {
+		"",  "",  "",    "", "",  "",    "", "",  "", // N/A
 		"R", "", "L",   "A", "", "P",   "I", "", "S", // HFS
 		"L", "", "R",   "P", "", "A",   "I", "", "S", // HFP
 		"A", "", "P",   "L", "", "R",   "I", "", "S", // HFDR
@@ -61,6 +63,7 @@ namespace GNC {
 		"A", "", "P",   "R", "", "L",   "S", "", "I", // FFDL
 		"L", "", "R",   "A", "", "P",   "S", "", "I", // FFS
 		"R", "", "L",   "P", "", "A",   "S", "", "I", // FFP
+		"?", "", "?",   "?", "", "?",   "?", "", "?", // Unknown
 
 	};
 }
@@ -72,14 +75,14 @@ namespace GNC {
 			//----------------------------------------------------------------------------------------------------
 			class OrientationMarks
 			{
-				public:
-					typedef enum TOrientationPosition {
-						TP_Top,
-						TP_Right,
-						TP_Bottom,
-						TP_Left,
-						TP_NumPosiciones
-					} TPosicionAnotacion;
+			public:
+				typedef enum TOrientationPosition {
+					TP_Top,
+					TP_Right,
+					TP_Bottom,
+					TP_Left,
+					TP_NumPosiciones
+				} TPosicionAnotacion;
 				OrientationMarks() {
 					m_StripTextRenderer.Update("RLAPIS", GNC::GCS::GLHelper::TColor(ANNOTATOR_TEXT_COLOR), TAMFUENTE);
 				}
@@ -126,15 +129,48 @@ namespace GNC {
 				GNC::GCS::Widgets::StripTextRenderer m_StripTextRenderer;
 			};
 
+			/**
+			annotationn items
+			*/
+			class AnnotationItem 
+			{
+			public:
+				AnnotationItem(): isModified(true), value("")
+				{
+				}
+
+				AnnotationItem(const std::string& value): isModified(true)
+				{
+					this->value = value;
+				}
+
+				AnnotationItem(const AnnotationItem& other) {
+					(*this) = other;
+				}
+
+				AnnotationItem& operator = (const AnnotationItem& o)
+				{
+					this->isModified = o.isModified;
+					this->value = o.value;
+					return *this;
+				}
+
+				void setValue(const std::string& value)
+				{
+					if (value != this->value) {
+						isModified = true;
+					}
+				}
+
+			protected:
+				bool isModified;
+				std::string value;
+
+			};
+
 			class Anotaciones {
 			public:
-				typedef enum TPosicionAnotacion {
-					TP_TopLeft = 0,
-					TP_TopRight,
-					TP_BottomLeft,
-					TP_BottomRight,
-					TP_NumPosiciones
-				} TPosicionAnotacion;
+				typedef std::map<std::string, AnnotationItem> TAnnotationItemDictionary;
 
 				Anotaciones(GNC::GCS::IWidgetsRenderer* pRenderer)
 				{
@@ -143,15 +179,15 @@ namespace GNC {
 					m_RecalcularTamOptimo = false;
 					m_pRenderer           = pRenderer;
 					m_Modificada          = false;
-					for (int i = 0; i < Anotaciones::TP_NumPosiciones; i++)
+					for (int i = 0; i < GNC::GCS::AnnotationSettings::TP_NumPos; i++)
 					{
 						m_TexturaModificada[i] = false;
 					}
 
-					m_Alineacion[Anotaciones::TP_TopLeft] = GNC::GCS::Widgets::HelperTexto::TA_Izquierda;
-					m_Alineacion[Anotaciones::TP_TopRight] = GNC::GCS::Widgets::HelperTexto::TA_Derecha;
-					m_Alineacion[Anotaciones::TP_BottomLeft] = GNC::GCS::Widgets::HelperTexto::TA_Izquierda;
-					m_Alineacion[Anotaciones::TP_BottomRight] = GNC::GCS::Widgets::HelperTexto::TA_Derecha;
+					m_Alineacion[GNC::GCS::AnnotationSettings::TP_TopLeft] = GNC::GCS::Widgets::HelperTexto::TA_Izquierda;
+					m_Alineacion[GNC::GCS::AnnotationSettings::TP_TopRight] = GNC::GCS::Widgets::HelperTexto::TA_Derecha;
+					m_Alineacion[GNC::GCS::AnnotationSettings::TP_BottomLeft] = GNC::GCS::Widgets::HelperTexto::TA_Izquierda;
+					m_Alineacion[GNC::GCS::AnnotationSettings::TP_BottomRight] = GNC::GCS::Widgets::HelperTexto::TA_Derecha;
 
 					m_pFontOptions = cairo_font_options_create();
 					m_TexturaMetrica.Redimensionar(2, 2);
@@ -167,6 +203,36 @@ namespace GNC {
 					//std::cout << "Destruyendo recursos de " << m_pRenderer << std::endl;
 				}
 
+				void Recalculate(GNC::GCS::Contexto3D* c, const GNC::GCS::Ptr<GNC::GCS::IAnnotator>& pAnnotator)
+				{
+					if (!pAnnotator.IsValid()) {
+						m_Correcta = false;
+						return;
+					}
+					//firstly get modality to get the pattern...
+					const std::string modality = pAnnotator->GetTagValue(c, GKDCM_Modality);
+
+					GNC::GCS::Ptr<GNC::GCS::DefaultModalitySettings> pModalitySettings = GNC::GCS::ModalitySettingsController::Instance()->getModalitySettings(modality);
+					if (!pModalitySettings.IsValid()) {
+						pModalitySettings = GNC::GCS::ModalitySettingsController::Instance()->getModalitySettings("OT");
+						if (!pModalitySettings.IsValid()) {
+							LOG_WARN("WCornerAnnotations", "settings for default modality OT not found");
+							m_Correcta = false;
+							return;
+						}
+					}
+					
+					const GNC::GCS::Ptr<GNC::GCS::AnnotationSettings>& pAnnotationSettings = pModalitySettings->getAnnotationSettings();
+
+					for (int i = 0; i < GNC::GCS::AnnotationSettings::TP_NumPos; ++i) {
+						//recalculate annotation
+						SetAnotation((GNC::GCS::AnnotationSettings::TAnnotationPosition)i, pAnnotationSettings->getAnnotation((GNC::GCS::AnnotationSettings::TAnnotationPosition)i), c, pAnnotator);
+					}
+
+					m_Correcta = true;
+				}
+
+
 				void Redimensionar(double* viewport)
 				{
 					bool redimensionado = false;
@@ -221,10 +287,68 @@ namespace GNC {
 					return m_Modificada;
 				}
 
-				bool SetAnotation(TPosicionAnotacion index, const std::string& str)
+				bool SetAnotation(GNC::GCS::AnnotationSettings::TAnnotationPosition index, const std::string& str, GNC::GCS::Contexto3D* c, const GNC::GCS::Ptr<GNC::GCS::IAnnotator>& pAnnotator)
 				{
-					if (m_TextoAnotacion[index] != str) {
-						m_TextoAnotacion[index] = str;
+					//parse annotation...
+					std::ostringstream annotationStream;
+					int initialPos = 0;
+					int defValuePos = 0;
+					std::ostringstream::pos_type lastEndl = 0;
+					std::string tmp;
+					for (int curPos = 0; curPos < str.length(); ++curPos) {
+						if (str[curPos] == '$') {
+							//copy from initial position...
+							annotationStream << str.substr(initialPos, curPos - initialPos);
+							initialPos = curPos;
+							if (curPos + 1 < str.length() && str[curPos+1] == '{') {
+								//search for '}'
+								defValuePos = -1;
+								bool isTag = false;
+								for (;curPos < str.length(); ++curPos) {
+									if (str[curPos] == '}') {
+										//key found...
+										if (pAnnotator.IsValid()) {
+											if (isTag) {
+												if (defValuePos > 0) {
+													annotationStream << pAnnotator->GetTagValue(c, str.substr(initialPos + 2, defValuePos - initialPos - 3), str.substr(defValuePos, curPos - defValuePos));
+												} else {
+													annotationStream << pAnnotator->GetTagValue(c, str.substr(initialPos + 2, curPos - initialPos -2));
+												}
+											} else {
+												tmp = pAnnotator->GetAnnotationValue(c, str.substr(initialPos, curPos - initialPos + 1));
+												if (tmp == "\n") {
+													if (annotationStream.tellp() != lastEndl) {
+														annotationStream << tmp;
+														lastEndl = annotationStream.tellp();
+													}
+												} else {
+													annotationStream << tmp;
+												}
+											}											
+										} else {
+											//if no anotator..
+											//copy from initial position...
+											annotationStream << str.substr(initialPos, curPos - initialPos + 1);
+										}
+										break;
+									} else if (str[curPos] == ':') {
+										defValuePos = curPos + 1;
+									} else if (str[curPos] == '|') {
+										isTag = true;
+									}
+								}
+								initialPos = curPos + 1;
+							}
+						}						
+					}
+					if (initialPos < str.length()) {
+						annotationStream << str.substr(initialPos, str.length() - initialPos);
+					}
+
+					std::string ann = annotationStream.str();
+
+					if (m_TextoAnotacion[index] != ann) {
+						m_TextoAnotacion[index] = ann;
 						ModificarTextura(index, true);
 						return true;
 					}
@@ -239,7 +363,7 @@ namespace GNC {
 						m_RecalcularTamOptimo = false;
 						m_TamCajaMaxima = m_TamViewPort;
 						m_TamFuente = TAMFUENTE;
-						for (int i = 0; i < Anotaciones::TP_NumPosiciones; ++i) {
+						for (int i = 0; i < GNC::GCS::AnnotationSettings::TP_NumPos; ++i) {
 							m_TamTexto[i].Asignar(0.0f, 0.0f);
 							if (m_TextoAnotacion[i].size() > 0) {
 								cairo_select_font_face(m_TexturaMetrica.cr, FUENTE_CAIRO, CAIRO_FONT_SLANT_NORMAL, CAIRO_FONT_WEIGHT_NORMAL);
@@ -252,7 +376,7 @@ namespace GNC {
 							m_TamFuente = ((m_TamViewPort * TAMFUENTE) / m_TamCajaMaxima).Redondear().ComponenteMinima(); // Calculo del tamanyo de fuente maxima
 							m_TamFuente = std::max(TAMFUENTE_MIN, m_TamFuente);
 
-							for (int i = 0; i < Anotaciones::TP_NumPosiciones; ++i) {
+							for (int i = 0; i < GNC::GCS::AnnotationSettings::TP_NumPos; ++i) {
 								m_TamTexto[i] *=  (m_TamFuente / TAMFUENTE);
 								m_TamTexto[i].RedondearAlza();
 								m_Texturas[i].Redimensionar(m_TamTexto[i].x, m_TamTexto[i].y);
@@ -260,7 +384,7 @@ namespace GNC {
 							}
 						}
 						else{
-							for (int i = 0; i < Anotaciones::TP_NumPosiciones; ++i) {
+							for (int i = 0; i < GNC::GCS::AnnotationSettings::TP_NumPos; ++i) {
 								m_TamTexto[i].RedondearAlza();
 								m_Texturas[i].Redimensionar(m_TamTexto[i].x, m_TamTexto[i].y);
 								m_TexturaModificada[i] = true;
@@ -273,7 +397,7 @@ namespace GNC {
 				{
 					RecalcularTamOptimo();
 
-					for (int i = 0; i < Anotaciones::TP_NumPosiciones; ++i)
+					for (int i = 0; i < GNC::GCS::AnnotationSettings::TP_NumPos; ++i)
 					{
 						const std::string& texto = m_TextoAnotacion[i];
 
@@ -301,28 +425,27 @@ namespace GNC {
 					GNC::GCS::Vector pos;
 
 					pos = GNC::GCS::Vector(0.0, 0.0).Redondeado();
-					m_Texturas[Anotaciones::TP_TopLeft].Actualizar();
-					m_Texturas[Anotaciones::TP_TopLeft].Render(c, pos, false, false, 0);
+					m_Texturas[GNC::GCS::AnnotationSettings::TP_TopLeft].Actualizar();
+					m_Texturas[GNC::GCS::AnnotationSettings::TP_TopLeft].Render(c, pos, false, false, 0);
 
-					pos = GNC::GCS::Vector(m_RectViewport[1].x - m_TamTexto[Anotaciones::TP_TopRight].x, 0.0).Redondeado();
-					m_Texturas[Anotaciones::TP_TopRight].Actualizar();
-					m_Texturas[Anotaciones::TP_TopRight].Render(c, pos, false, false, 0);
+					pos = GNC::GCS::Vector(m_RectViewport[1].x - m_TamTexto[GNC::GCS::AnnotationSettings::TP_TopRight].x, 0.0).Redondeado();
+					m_Texturas[GNC::GCS::AnnotationSettings::TP_TopRight].Actualizar();
+					m_Texturas[GNC::GCS::AnnotationSettings::TP_TopRight].Render(c, pos, false, false, 0);
 
-					pos = GNC::GCS::Vector(0.0, m_RectViewport[1].y - m_TamTexto[Anotaciones::TP_BottomLeft].y).Redondeado();
-					m_Texturas[Anotaciones::TP_BottomLeft].Actualizar();
-					m_Texturas[Anotaciones::TP_BottomLeft].Render(c, pos, false, false, 0);
+					pos = GNC::GCS::Vector(0.0, m_RectViewport[1].y - m_TamTexto[GNC::GCS::AnnotationSettings::TP_BottomLeft].y).Redondeado();
+					m_Texturas[GNC::GCS::AnnotationSettings::TP_BottomLeft].Actualizar();
+					m_Texturas[GNC::GCS::AnnotationSettings::TP_BottomLeft].Render(c, pos, false, false, 0);
 
-					pos = GNC::GCS::Vector(m_RectViewport[1].x - m_TamTexto[Anotaciones::TP_BottomRight].x, m_RectViewport[1].y - m_TamTexto[Anotaciones::TP_BottomRight].y).Redondeado();
-					m_Texturas[Anotaciones::TP_BottomRight].Actualizar();
-					m_Texturas[Anotaciones::TP_BottomRight].Render(c, pos, false, false, 0);
+					pos = GNC::GCS::Vector(m_RectViewport[1].x - m_TamTexto[GNC::GCS::AnnotationSettings::TP_BottomRight].x, m_RectViewport[1].y - m_TamTexto[GNC::GCS::AnnotationSettings::TP_BottomRight].y).Redondeado();
+					m_Texturas[GNC::GCS::AnnotationSettings::TP_BottomRight].Actualizar();
+					m_Texturas[GNC::GCS::AnnotationSettings::TP_BottomRight].Render(c, pos, false, false, 0);
 
 					Modificar(false);
 				}
 
 				void LiberarRecursos()
 				{
-					GTRACE("Anotaciones::LiberarRecursos()");
-					for (int i = 0; i < Anotaciones::TP_NumPosiciones; i++)
+					for (int i = 0; i < GNC::GCS::AnnotationSettings::TP_NumPos; i++)
 					{
 						m_Texturas[i].Destruir();
 					}
@@ -335,13 +458,13 @@ namespace GNC {
 
 				GNC::GCS::TexturaCairo m_TexturaMetrica; // Contexto usado solamente para medir.
 
-				bool m_TexturaModificada[Anotaciones::TP_NumPosiciones];
+				bool m_TexturaModificada[GNC::GCS::AnnotationSettings::TP_NumPos];
 
-				std::string m_TextoAnotacion[Anotaciones::TP_NumPosiciones];
+				std::string m_TextoAnotacion[GNC::GCS::AnnotationSettings::TP_NumPos];
 
-				GNC::GCS::Vector m_TamTexto[Anotaciones::TP_NumPosiciones];
+				GNC::GCS::Vector m_TamTexto[GNC::GCS::AnnotationSettings::TP_NumPos];
 
-				GNC::GCS::TexturaCairo m_Texturas[Anotaciones::TP_NumPosiciones];
+				GNC::GCS::TexturaCairo m_Texturas[GNC::GCS::AnnotationSettings::TP_NumPos];
 
 				bool m_RecalcularTamOptimo;
 
@@ -350,9 +473,10 @@ namespace GNC {
 				bool m_Correcta;
 				float m_TamFuente;
 
-				GNC::GCS::Widgets::HelperTexto::TAlineamiento m_Alineacion[Anotaciones::TP_NumPosiciones];
+				GNC::GCS::Widgets::HelperTexto::TAlineamiento m_Alineacion[GNC::GCS::AnnotationSettings::TP_NumPos];
 
 				GNC::GCS::IWidgetsRenderer* m_pRenderer;
+				TAnnotationItemDictionary m_annotationDicionary;
 				bool m_Modificada;
 
 			};
@@ -416,87 +540,79 @@ namespace GNC {
 						}
 					}
 				}
-
-				inline void InvalidarTodas()
-				{
-					for( MapaAnotaciones::iterator it = m_Anotaciones.begin(); it != m_Anotaciones.end(); ++it)
-					{
-						(*it).second->m_Correcta = false;
-						(*it).first->Modificar(true);
-					}
-				}
-
-				inline void ModificarTodas()
-				{
-					for( MapaAnotaciones::iterator it = m_Anotaciones.begin(); it != m_Anotaciones.end(); ++it)
-					{
-						(*it).second->Modificar(true);
-					}
-				}
-
+				
 			};
+
+			/**
+			* Gets the orientation index given string. Default is zero.
+			* strPos: The patient position string (HFS, HFP...)
+			* defautlunknown: When orientation index is empty, set the default index to unknown ("?") or empty ("") values
+			**/
+			int GetOrientationIndex(const std::string& strPos, bool defaultunknown) {
+
+				if (strcmp(strPos.c_str(), "HFS") == 0) {
+					return 1;
+				}
+				else if (strcmp(strPos.c_str(), "HFP") == 0) {
+					return 2;
+				}
+				else if (strcmp(strPos.c_str(), "HFDR") == 0) {
+					return 3;
+				}
+				else if (strcmp(strPos.c_str(), "HFDL") == 0) {
+					return 4;
+				}
+				else if (strcmp(strPos.c_str(), "FFDR") == 0) {
+					return 5;
+				}
+				else if (strcmp(strPos.c_str(), "FFDL") == 0) {
+					return 6;
+				}
+				else if (strcmp(strPos.c_str(), "FFS") == 0) {
+					return 7;
+				}
+				else if(strcmp(strPos.c_str(), "FFP") == 0) {
+					return 8;
+				}
+				if (defaultunknown) {
+					return 9;
+				}
+				else {
+					return 0;
+				}
+			}
+
+			/**
+			* Gets the patient orientation char ("R", "L", "S"...) from:
+			* patientPosIndex: The patient position index: get if from GetOrientationIndex() call.
+			* axis: The axis: 0==x, 1==y, 2==z
+			* dir: The direction: -1 == decreasing, +1 == decreasing
+			**/
+			const char* GetOrientationChar(int patientPosIndex, int axis, int dir) {
+				const int offPos = 9 * patientPosIndex;
+				const int offAxis = 3 * axis;
+				const int offDir = 1 + dir;
+
+				return PatientOrientation[offPos + offAxis + offDir];
+			}
 		}
 	}
 }
 
 
-int GetOrientation(const std::string& strPos) {
-	if (strcmp(strPos.c_str(), "") == 0) {
-		return 1;
-	}
-	else if (strcmp(strPos.c_str(), "HFS") == 0) {
-		return 1;
-	}
-	else if (strcmp(strPos.c_str(), "HFP") == 0) {
-		return 2;
-	}
-	else if (strcmp(strPos.c_str(), "HFDR") == 0) {
-		return 3;
-	}
-	else if (strcmp(strPos.c_str(), "HFDL") == 0) {
-		return 4;
-	}
-	else if (strcmp(strPos.c_str(), "FFDR") == 0) {
-		return 5;
-	}
-	else if (strcmp(strPos.c_str(), "FFDL") == 0) {
-		return 6;
-	}
-	else if (strcmp(strPos.c_str(), "FFS") == 0) {
-		return 7;
-	}
-	else if(strcmp(strPos.c_str(), "FFP") == 0) {
-		return 8;
-	}
-	else {
-		return 0;
-	}
-}
-
 //region "Constructor y destructor"
 
-GNC::GCS::Widgets::WAnotador::WAnotador(GNC::GCS::IAnotador* annotator, IWidgetsManager* pManager, long vid, const char* nombre, long gid) : GNC::GCS::Widgets::IWidget(pManager, vid, nombre, gid)
+GNC::GCS::Widgets::WAnotador::WAnotador(IWidgetsManager* pManager, long vid, const char* nombre, long gid) : GNC::GCS::Widgets::IWidget(pManager, vid, nombre, gid)
 {
 	GNC::GCS::ConfigurationController::Instance()->readBoolUser("/GinkgoCore/Tools/CornerAnotations", "IsShown", m_Oculto, true);
 	m_TopLevel = true;
 	m_ReservaRecursos = true;
-	m_pAnnotator = annotator;
 	m_Estado = new EstadoInterno();
 	m_color = GNC::GCS::GLHelper::TColor(ANNOTATOR_TEXT_COLOR);
-
-	GTRACE("AnotadorEsquina creado");
-
-	for (int i = 0; i < TP_NumPosiciones; ++i) {
-		m_volatileProperty[i] = false;
-	}
-
-	GNC::GCS::Events::EventoModificacionImagen evt2(m_pManager->GetVista());
-	GNC::GCS::IEventsController::Instance()->Registrar(this, evt2);
 }
 
 GNC::GCS::Widgets::WAnotador::~WAnotador()
 {
-	GTRACE("AnotadorEsquina destruido");
 	delete m_Estado;
 }
 
@@ -529,9 +645,6 @@ bool GNC::GCS::Widgets::WAnotador::HitTest(GNC::GCS::Vector* , int )
 	return false;
 }
 
-
-
-
 void GNC::GCS::Widgets::WAnotador::Render(GNC::GCS::Contexto3D* c)
 {
 	if(m_Oculto){
@@ -559,53 +672,19 @@ void GNC::GCS::Widgets::WAnotador::Render(GNC::GCS::Contexto3D* c)
 	Anotaciones* pAnotaciones = m_Estado->Get(c->GetRenderer());
 	OrientationMarks* pOrientation = m_Estado->GetOrientation(c->GetRenderer());
 
+
 	pAnotaciones->Redimensionar(viewport);
-
-	bool recalc = false;
-
-	if(!pAnotaciones->m_Correcta) {
-		recalc = true;
-		RecalcularEstaticas(pAnotaciones, c);
-	}
+	
+	pAnotaciones->Recalculate(c, m_pManager->GetAnnotator());
 
 	RecalcularPosicion(pOrientation, c);
 
-	if (!recalc) {
-		for (int i = 0; i < TP_NumPosiciones; ++i) {
-			if (m_volatileProperty[i]) {
-				switch ((WAnotador::TPosicionAnotacion)i) {
-				case TP_TopLeft:
-					pAnotaciones->SetAnotation(Anotaciones::TP_TopLeft, m_pAnnotator->GetTopLeftAnnotation(c));
-					break;
-				case TP_TopRight:
-					pAnotaciones->SetAnotation(Anotaciones::TP_TopRight, m_pAnnotator->GetTopRightAnnotation(c));
-					break;
-				case TP_BottomLeft:
-					pAnotaciones->SetAnotation(Anotaciones::TP_BottomLeft, m_pAnnotator->GetBottomLeftAnnotation(c));
-					break;
-				case TP_BottomRight:
-					pAnotaciones->SetAnotation(Anotaciones::TP_BottomRight, m_pAnnotator->GetBottomRightAnnotation(c));
-					break;
-				case TP_Top:
-					break;
-				case TP_Right:
-					break;
-				case TP_Bottom:
-					break;
-				case TP_Left:
-					break;
-				default:
-					break;
-				}
-				
-			}
-		}
-	}
-
+	
 	pAnotaciones->Actualizar(m_color);
 
 	pAnotaciones->Render(c);
 	pOrientation->Render(c, pAnotaciones->m_RectViewport);
+	
 
 	glPopMatrix();
 
@@ -618,18 +697,6 @@ void GNC::GCS::Widgets::WAnotador::Render(GNC::GCS::Contexto3D* c)
 	glMatrixMode(GL_MODELVIEW);
 
 	glPopAttrib();
-
-}
-
-void GNC::GCS::Widgets::WAnotador::Modificar (bool modificada)
-{
-	if (modificada)
-	{
-		m_Estado->ModificarTodas();
-	}
-	else {
-		; // Caso inconsistente
-	}
 }
 
 void GNC::GCS::Widgets::WAnotador::Seleccionar(bool )
@@ -649,22 +716,7 @@ void GNC::GCS::Widgets::WAnotador::Ocultar(bool oculto)
 	GNC::GCS::ConfigurationController::Instance()->writeBoolUser("/GinkgoCore/Tools/CornerAnotations", "IsShown", m_Oculto);
 }
 
-void GNC::GCS::Widgets::WAnotador::RecalcularEstaticas(Anotaciones* pAnotaciones, GNC::GCS::Contexto3D* c)
-{
 
-	pAnotaciones->SetAnotation(Anotaciones::TP_TopLeft, m_pAnnotator->GetTopLeftAnnotation(c));
-	pAnotaciones->SetAnotation(Anotaciones::TP_TopRight, m_pAnnotator->GetTopRightAnnotation(c));
-	pAnotaciones->SetAnotation(Anotaciones::TP_BottomLeft, m_pAnnotator->GetBottomLeftAnnotation(c));
-	pAnotaciones->SetAnotation(Anotaciones::TP_BottomRight, m_pAnnotator->GetBottomRightAnnotation(c));
-
-	std::string strPos = m_pAnnotator->GetPatientPosition(c);
-	std::stringstream trimmer;
-	trimmer << strPos;
-	m_CachedPatientPosition.clear();
-	trimmer >> m_CachedPatientPosition;
-
-	pAnotaciones->m_Correcta = true;
-}
 
 //endregion
 
@@ -675,7 +727,7 @@ void GNC::GCS::Widgets::WAnotador::RecalcularPosicion(OrientationMarks* pAnotaci
 	GNC::GCS::Vector3D camUp;
 
 	c->GetRenderer()->GetCamVectors(camPos.v, camDir.v, camUp.v);
-	
+
 	for (int i = 0; i < 3; ++i) {
 		if (std::abs(camUp.v[i]) < 0.1) {
 			camUp.v[i] = 0.0;
@@ -684,7 +736,7 @@ void GNC::GCS::Widgets::WAnotador::RecalcularPosicion(OrientationMarks* pAnotaci
 			camDir.v[i] = 0.0;
 		}
 	}
-	
+
 	GNC::GCS::Vector3D camCross = camDir.ProductoVectorial(camUp).Normalizado();
 
 	for (int i = 0; i < 3; ++i) {
@@ -704,8 +756,13 @@ void GNC::GCS::Widgets::WAnotador::RecalcularPosicion(OrientationMarks* pAnotaci
 
 	camOrient[2][0] = camDir.Stabilized().Sign(); // back
 	camOrient[2][1] = -camOrient[2][0];           // front
-	
-	int patientPosIndex = GetOrientation(m_CachedPatientPosition);
+
+	std::string patPosition;
+	if (m_pManager->GetAnnotator().IsValid()) {
+		patPosition = m_pManager->GetAnnotator()->GetTagValue(c, GKDCM_PatientPosition);
+	}
+
+	int patientPosIndex = GetOrientationIndex(patPosition, false);
 
 	std::ostringstream left;
 	std::ostringstream right;
@@ -847,11 +904,6 @@ void GNC::GCS::Widgets::WAnotador::RecalcularPosicion(OrientationMarks* pAnotaci
 	else {
 		bottom << PatientOrientation[offPos + offZ + offSignZero];
 	}
-	/*
-	LOG_DEBUG("View", "==\n " << top.str());
-	LOG_DEBUG("View", left.str() << " " << right.str());
-	LOG_DEBUG("View", " " << bottom.str());
-	*/
 	pAnotaciones->SetAnotation(OrientationMarks::TP_Top, top.str());
 	pAnotaciones->SetAnotation(OrientationMarks::TP_Right, right.str());
 	pAnotaciones->SetAnotation(OrientationMarks::TP_Bottom, bottom.str());
@@ -859,12 +911,7 @@ void GNC::GCS::Widgets::WAnotador::RecalcularPosicion(OrientationMarks* pAnotaci
 }
 //region "Interfaz especifica"
 
-void GNC::GCS::Widgets::WAnotador::SetAnotador(GNC::GCS::IAnotador* anotador)
-{
-	m_pAnnotator = anotador;
-	Modificar(true);
-	m_Estado->InvalidarTodas();
-}
+
 
 void GNC::GCS::Widgets::WAnotador::SetTextColor(const GNC::GCS::GLHelper::TColor& color)
 {
@@ -875,40 +922,6 @@ void GNC::GCS::Widgets::WAnotador::SetTextColor(const GNC::GCS::GLHelper::TColor
 
 //region "Estado interno"
 
-void GNC::GCS::Widgets::WAnotador::setVolatileProperty(TPosicionAnotacion pos, bool enabled)
-{
-	m_volatileProperty[pos] = enabled;
-}
-
-void GNC::GCS::Widgets::WAnotador::InvalidarTodas()
-{
-	m_Estado->InvalidarTodas();
-}
-
-//region Interfaz de eventos ginkgo
-
-void GNC::GCS::Widgets::WAnotador::ProcesarEvento(GNC::GCS::Events::IEvent *evt)
-{
-	if (evt == NULL) {
-		std::cerr << "Error: Evento nulo" << std::endl;
-		return;
-	}
-	switch (evt->GetCodigoEvento()) {
-
-	case ginkgoEVT_Core_ModificacionImagen:
-		{
-			GNC::GCS::Events::EventoModificacionImagen* pEvt = dynamic_cast<GNC::GCS::Events::EventoModificacionImagen*>(evt);
-			if (pEvt != NULL && pEvt->GetTipo() == GNC::GCS::Events::EventoModificacionImagen::AnotacionesEstaticasModificadas) {
-				Modificar(true);
-				m_Estado->InvalidarTodas();
-			}
-		}
-		break;
-
-	}
-}
-
-//endregion
 
 void GNC::GCS::Widgets::WAnotador::OffscreenRender(GNC::GCS::Contexto3D* c)
 {
@@ -921,7 +934,7 @@ void GNC::GCS::Widgets::WAnotador::OffscreenRender(GNC::GCS::Contexto3D* c)
 
 
 
-	const std::string        TextoAnotacion[WAnotador::TP_NumPosiciones] = { m_pAnnotator->GetTopLeftAnnotation(c), m_pAnnotator->GetTopRightAnnotation(c), m_pAnnotator->GetBottomLeftAnnotation(c), m_pAnnotator->GetBottomRightAnnotation(c) };
+	const std::string        TextoAnotacion[WAnotador::TP_NumPosiciones] = {"","","",""};/////////////{ m_pAnnotator->GetTopLeftAnnotation(c), m_pAnnotator->GetTopRightAnnotation(c), m_pAnnotator->GetBottomLeftAnnotation(c), m_pAnnotator->GetBottomRightAnnotation(c) };
 	GNC::GCS::Vector         TamTexto      [WAnotador::TP_NumPosiciones];
 	GNC::GCS::Widgets::HelperTexto::TAlineamiento Alineacion[4] = { GNC::GCS::Widgets::HelperTexto::TA_Izquierda, GNC::GCS::Widgets::HelperTexto::TA_Derecha, GNC::GCS::Widgets::HelperTexto::TA_Izquierda, GNC::GCS::Widgets::HelperTexto::TA_Derecha };
 
@@ -941,23 +954,6 @@ void GNC::GCS::Widgets::WAnotador::OffscreenRender(GNC::GCS::Contexto3D* c)
 			TamCajaMaxima.AsignarMaximos(TamTexto[i]);
 		}
 	}
-	/*
-	if (!TamCajaMaxima.EsNulo()) {
-	TamFuente = ((TamViewPort * TAMFUENTE) / TamCajaMaxima).Redondear().ComponenteMinima(); // Calculo del tamanyo de fuente maxima
-	TamFuente = std::max(TAMFUENTE_MIN, TamFuente);
-	for (int i = 0; i < WAnotador::TP_NumPosiciones; ++i) {
-	TamTexto[i] *=  (TamFuente / TAMFUENTE);
-	TamTexto[i].Redondear();
-	}
-	}
-	else{
-	for (int i = 0; i < WAnotador::TP_NumPosiciones; ++i) {
-	TamTexto[i].Redondear();
-	}
-	}
-	cairo_set_font_size(c->cr, TamFuente);
-	*/
-
 
 	GNC::GCS::Vector pos;
 
