@@ -14,22 +14,21 @@
 //#define _GINKGO_TRACE
 
 #include "wanotacionposicion.h"
-#include <api/ianotador.h>
 
 #include <main/managers/widgetsmanager.h>
 #include <eventos/mensajes.h>
+#include <api/iannotator.h>
 #include <main/entorno.h>
 #include <main/controllers/controladoreventos.h>
 
 
 //region "Constructor y destructor"
 
-GNC::GCS::Widgets::WAnotacionPosicion::WAnotacionPosicion(GNC::GCS::IAnotador* annotator, IWidgetsManager* pManager, long vid, const char* nombre, long gid) : GNC::GCS::Widgets::IWidget(pManager, vid, nombre, gid)
+GNC::GCS::Widgets::WAnotacionPosicion::WAnotacionPosicion(IWidgetsManager* pManager, long vid, const char* nombre, long gid) : GNC::GCS::Widgets::IWidget(pManager, vid, nombre, gid)
 {
 	m_Oculto = false;
 	m_TopLevel = true;
 	m_ReservaRecursos = false;
-	m_pAnnotator = annotator;
 	
 	GTRACE("Anotador posicion creado");
 }
@@ -55,8 +54,10 @@ void GNC::GCS::Widgets::WAnotacionPosicion::OnMouseEvents(GNC::GCS::Events::Even
 	}
 
 	if( evento.Moving() || evento.Dragging()) {
-		std::string posstr = m_pAnnotator->GetAnotacionPosicion(evento.wP, evento.c);
-		GNC::GCS::ControladorEventos::Instance()->ProcesarEvento(new GNC::GCS::Events::EventoMensajes(NULL,posstr));
+		if (m_pManager->GetAnnotator().IsValid()) {
+			std::string posstr = m_pManager->GetAnnotator()->GetPositionAnnotation(evento.c, evento.wP);
+			GNC::GCS::ControladorEventos::Instance()->ProcesarEvento(new GNC::GCS::Events::EventoMensajes(NULL,posstr));
+		}
 	}
 }
 
@@ -94,10 +95,5 @@ void GNC::GCS::Widgets::WAnotacionPosicion::Ocultar(bool oculto)
 	}
 }
 
-//region "Interfaz especifica"
-void GNC::GCS::Widgets::WAnotacionPosicion::SetAnotador(GNC::GCS::IAnotador* anotador)
-{
-	m_pAnnotator = anotador;
-}
-//endregion
+
 
