@@ -31,7 +31,7 @@ namespace GNC {
 			//region "Constructor y destructor"
 
 			public:
-				WAnotacionPosicion(GNC::GCS::IAnotador* annotator, IWidgetsManager* pManager, long vid, const char* nombre, long gid);
+				WAnotacionPosicion(IWidgetsManager* pManager, long vid, const char* nombre, long gid);
 
 				~WAnotacionPosicion();
 
@@ -59,8 +59,6 @@ namespace GNC {
 
 				//region "Interfaz especifica"
 			public:
-				virtual void SetAnotador(GNC::GCS::IAnotador* anotador);
-				GNC::GCS::IAnotador* m_pAnnotator;
 				//endregion
 			};
 		}
