@@ -3,7 +3,7 @@
  *  $Id: wnota.cpp $
  *  Ginkgo CADx Project
  *
- *  Copyright 2008-12 MetaEmotion S.L. All rights reserved.
+ *  Copyright 2008-14 MetaEmotion S.L. All rights reserved.
  *  http://ginkgo-cadx.com
  *
  *  This file is licensed under LGPL v3 license.
@@ -78,6 +78,7 @@ void GNC::GCS::Widgets::WNotaBuilder::OnMouseEvents(GNC::GCS::Events::EventoRato
 		m_Posicion= evento.iP;
 		m_pManager->InsertarWidget(m_pTempWidget);
 		m_pManager->LanzarEventoCreacion(m_pTempWidget);
+		m_pTempWidget->DoEditText(evento.c->pWindow);
 		m_pTempWidget = NULL;
 		evento.Skip(false);
 		m_pManager->Modificado();
@@ -134,7 +135,7 @@ GNC::GCS::Widgets::TipoCursor GNC::GCS::Widgets::WNotaBuilder::GetCursor()
 //====================================================================================================
 //= Widget de notas
 //====================================================================================================
-GNC::GCS::Widgets::WCajaTexto::WCajaTexto(IWidgetsManager* pManager, long vid, GNC::GCS::Vector posicion, const char* nombre, std::string texto) : IWidget(pManager, vid, nombre), GNC::GCS::Widgets::IWidgetSerializable()
+GNC::GCS::Widgets::WCajaTexto::WCajaTexto(IWidgetsManager* pManager, long vid, GNC::GCS::Vector posicion, const char* nombre, std::string texto) : IWidget(pManager, vid, nombre,0,TID_USER_ANNOTATION_WIDGET), GNC::GCS::Widgets::IWidgetSerializable()
 {
 	m_AnchoMaximo = 150.0f;
 	m_Texto = texto;
@@ -210,6 +211,17 @@ wxXmlNode* GNC::GCS::Widgets::WCajaTexto::Serializar(const std::string& nombreMe
 }
 //endregion
 
+void GNC::GCS::Widgets::WCajaTexto::DoEditText(wxWindow* pWindow) 
+{
+	if (m_pWidgetSeleccion != NULL) {
+		m_pWidgetSeleccion->Destroy();
+		m_pWidgetSeleccion = NULL;
+	}
+	m_pWidgetSeleccion = new GNC::GCS::Widgets::Dialogos::SeleccionTexto(pWindow, this, m_pManager);
+	m_pWidgetSeleccion->Center();
+	m_pWidgetSeleccion->ShowModal();
+}
+
 GNC::GCS::Widgets::WCajaTexto::TexturaNota* GNC::GCS::Widgets::WCajaTexto::GetTextura(void* renderer)
 {
 	if(m_mapaRecursos.find(renderer) == m_mapaRecursos.end()) {
@@ -346,13 +358,7 @@ void GNC::GCS::Widgets::WCajaTexto::OnMouseEvents(GNC::GCS::Events::EventoRaton&
 	else if (evento.ButtonDClick(GNC::GCS::Events::EventoRaton::EB_IZQUIERDO)) {
 		if (!EventoConsumido()) {
 			if (evento.iP.DentroDePoligono2(m_Quad,4)) {
-				if (m_pWidgetSeleccion != NULL) {
-					m_pWidgetSeleccion->Destroy();
-					m_pWidgetSeleccion = NULL;
-				}
-				m_pWidgetSeleccion = new GNC::GCS::Widgets::Dialogos::SeleccionTexto(evento.c->pWindow, this, m_pManager);
-				m_pWidgetSeleccion->Center();
-				m_pWidgetSeleccion->ShowModal();
+				DoEditText(evento.c->pWindow);
 				ConsumirEvento();
 			}
 		}
@@ -508,7 +514,7 @@ void GNC::GCS::Widgets::WCajaTexto::Recalcular(void* renderer)
 
 	std::string texto = m_Texto;
 	if (texto.empty()) {
-		texto = _Std("Double click to edit");
+		texto = _Std("Default text");
 	}
 
 	m_Texto = texto;
