@@ -188,6 +188,36 @@ protected:
 	int m_sizeBorder;
 };
 
+class EXTAPI UnTitledPanel: public wxPanel {
+public:
+	UnTitledPanel(wxWindow *parent,
+            wxWindowID winid = wxID_ANY,
+            const wxPoint& pos = wxDefaultPosition,
+            const wxSize& size = wxDefaultSize,
+            long style = wxTAB_TRAVERSAL | wxNO_BORDER);
+	~UnTitledPanel();
+
+	virtual void OnEraseBackground( wxEraseEvent& event );
+	virtual void OnPaint(wxPaintEvent &event);
+	virtual void OnSize(wxSizeEvent &event);
+
+	virtual void SetColorBorde(const wxColour& colorBorde);
+	virtual wxColour GetColorBorde();
+
+	virtual int GetSizeBorde();
+	virtual void SetSizeBorde(int size);
+
+	virtual int GetBorderInterior();
+	virtual void SetBorderInterior(int size);
+
+protected:
+	wxColour m_colorFondo;
+	wxColour m_colorBorde;
+	wxColour m_colorSombraBorde;
+	int m_sizeBorder;
+	int m_borderInterior;
+};
+
 
 class EXTAPI TitledPanel: public wxPanel {
 public:
