@@ -48,7 +48,7 @@
 #include "wx/dcbuffer.h"
 #include <resources/ginkgoresourcesmanager.h>
 #include <api/globals.h>
-#include <main/controllers/controladorcomandos.h>
+#include <main/controllers/commandcontroller.h>
 
 #include "tick.xpm"
 
