@@ -280,7 +280,7 @@ public:
 // Accessing items
 
     /// Get the number of items in the control
-    virtual int GetCount() const { return m_items.GetCount(); }
+    virtual int GetCount() const { return (int) m_items.GetCount(); }
 
     /// Is the control empty?
     bool IsEmpty() const { return GetCount() == 0; }
