@@ -3,7 +3,7 @@
  *  $Id: vista2d.cpp $
  *  Ginkgo CADx Project
  *
- *  Copyright 2008-12 MetaEmotion S.L. All rights reserved.
+ *  Copyright 2008-14 MetaEmotion S.L. All rights reserved.
  *  http://ginkgo-cadx.com
  *
  *  This file is licensed under LGPL v3 license.
@@ -85,7 +85,7 @@ void GNKVisualizator::Vista2D::OnCargaIniciada()
 }
 
 // Paso 1: Cargar los ficheros en memoria. Metodo NO sincrono con la interfaz.
-void GNKVisualizator::Vista2D::CargarEstudio(GNC::GCS::IComando* pCmdInvocador)
+void GNKVisualizator::Vista2D::CargarEstudio(GNC::GCS::IComando* /*pCmdInvocador*/)
 {
 	
 }
@@ -129,7 +129,7 @@ void GNKVisualizator::Vista2D::DetenerPipeline()
 
 
 //region Interfaz IVista
-bool GNKVisualizator::Vista2D::SoportaHerramienta(GNC::GCS::ITool* h)
+bool GNKVisualizator::Vista2D::SoportaHerramienta(GNC::GCS::ITool* /*h*/)
 {
 	return GVista->GetManipulacionEnabled();
 }
@@ -208,7 +208,7 @@ void GNKVisualizator::Vista2D::ComienzaDestruccion()
 	m_IgnorarModificaciones=true;
 }
 
-void ActivarRuta(const std::string & path)
+void ActivarRuta(const std::string & /*path*/)
 {
 }
 
