@@ -27,6 +27,7 @@
 #include <resources/visualizatorresourcesmanager.h>
 #include <api/dicom/idicommanager.h>
 #include <api/dicom/dcmdictionary.h>
+#include <api/iannotator.h>
 
 #include <api/autoptr.h>
 #include <export/contracts/ipixelsbluringcontract.h>
@@ -438,6 +439,54 @@ class GVistaComplejaPixelsBluringDelegate: public GNC::GCS::IPixelsBluringContra
 		GVistaCompleja* GView;
 };
 
+class GVistaComplejaAnnotatorDelegate: public GNC::GCS::IAnnotator
+{
+public:
+	GVistaComplejaAnnotatorDelegate(GVistaCompleja* gView, GNKVisualizator::Vista2D* pView) : GNC::GCS::IAnnotator(pView), 
+		GView(gView)
+	{
+	}
+	~GVistaComplejaAnnotatorDelegate()
+	{
+	}
+
+
+	virtual std::string GetAnnotationValue(GNC::GCS::Contexto3D* c, const std::string& key)
+	{
+		if (key == "${SLICE.IDX}") {
+			if (c->GetRenderer() != NULL && c->GetRenderer()->m_pImageViewer != NULL) {
+				std::ostringstream ostr;
+				ostr << c->GetRenderer()->m_pImageViewer->GetTindex() + 1;
+				return ostr.str();
+			}
+		} else if (key == "${SLICE.IDX.FULLTEXT}") {
+			if (c->GetRenderer() != NULL && c->GetRenderer()->m_pImageViewer != NULL && m_pView != NULL && m_pView->GetEstudio().IsValid()) {
+				int dims[3] = {0, 0, 0};
+				c->GetRenderer()->m_pImageViewer->GetDimensions(dims);
+				std::ostringstream ostr;
+				if (c->offscreenCreado) {
+					ostr << _Std("Slice: ") <<  c->OVID + 1;
+					if (dims[2] > 1) {
+						ostr << " T: 0";
+					}
+		
+				}
+				else {
+					ostr << _Std("Slice: ") <<  c->GetRenderer()->GetVID() + 1;
+					if (dims[2] > 1) {
+						ostr << " T: " << c->GetRenderer()->m_pImageViewer->GetTindex();
+					}
+				}
+				return ostr.str();
+			}
+		}
+		return GNC::GCS::IAnnotator::GetAnnotationValue(c, key);
+	}
+
+protected:
+	GVistaCompleja* GView;
+};
+
 //contracts dellegate
 
 /////////////////////////////////////DRAG&DROP/////////////////////////////////////////
@@ -503,7 +552,8 @@ GVistaCompleja::GVistaCompleja(GNKVisualizator::Vista2D* pIVista) : VistaComplej
 	m_pManager (GNC::GCS::IEntorno::Instance()->NewWidgetsManager(IVista)),
 	ExportDelegate(new GNKVisualizator::SimpleViewExportContractDelegate(this)),
 	m_pPanelPreview(new GNKVisualizator::GUI::PreviewPanelVisualizator(pIVista, this)),
-	PixelsBluringDelegate(new GVistaComplejaPixelsBluringDelegate(this))
+	PixelsBluringDelegate(new GVistaComplejaPixelsBluringDelegate(this)),
+	AnnotatorDelegate(new GVistaComplejaAnnotatorDelegate(this, pIVista))
 {
 	IVista->GetVisualizatorStudy()->Window = this;
 	m_hasBeenRendered = false;
@@ -624,6 +674,7 @@ GVistaCompleja::GVistaCompleja(GNKVisualizator::Vista2D* pIVista) : VistaComplej
 
 	//m_pManager->InsertarWidget(new GNC::GCS::Widgets::WProgreso(m_VistasSimples.front()->ViewInteractor2D, m_pManager, -1, "progreso", 666));
 	m_pManager->EnableAnimation();
+	m_pManager->SetAnnotator(AnnotatorDelegate);
 
 	this->Layout();
 }
@@ -726,7 +777,7 @@ void GVistaCompleja::LoadSeries(long seriesPk)
 
 void GVistaCompleja::IniciarPipeline(const GNC::GCS::Ptr<GNC::GCS::Layout>& layout)
 {
-	m_pManager->EliminarTodosLosWidgets(false);
+	m_pManager->RemoveUserAnnotationWidgets(false);
 	m_pPanelManipulacion->Enable(true);
 
 
@@ -784,8 +835,6 @@ void GVistaCompleja::IniciarPipeline(const GNC::GCS::Ptr<GNC::GCS::Layout>& layo
 	} else {
 		GoToSlice(0,false,false);
 	}
-	
-	m_pManager->CrearWidgetAnotador(this);
 }
 
 
@@ -1106,94 +1155,6 @@ void GVistaCompleja::OnTimer()
 	}
 }
 
-//region "Realizacion de la interfaz IAnnotator"
-std::string GVistaCompleja::GetTopLeftAnnotation(GNC::GCS::Contexto3D* c)
-{
-	GNC::GCS::IWidgetsRenderer* r = ( c == NULL? NULL : c->GetRenderer());
-	if (r == NULL) {
-		return m_VistasSimples[0]->GetTopLeftAnnotation(c);
-	} else {
-		for (TListaGVistasSimples::iterator it = m_VistasSimples.begin(); it != m_VistasSimples.end(); ++it) {
-			if ( (*it)->ViewInteractor2D == r) {
-				return (*it)->GetTopLeftAnnotation(c);
-			}
-		}
-	}
-	return "";
-}
-
-std::string GVistaCompleja::GetTopRightAnnotation(GNC::GCS::Contexto3D* c)
-{
-	GNC::GCS::IWidgetsRenderer* r = ( c == NULL? NULL : c->GetRenderer());
-	if (r == NULL) {
-		return m_VistasSimples[0]->GetTopRightAnnotation(c);
-	} else {
-		for (TListaGVistasSimples::iterator it = m_VistasSimples.begin(); it != m_VistasSimples.end(); ++it) {
-			if ( (*it)->ViewInteractor2D == r) {
-				return (*it)->GetTopRightAnnotation(c);
-			}
-		}
-	}
-	return "";
-}
-
-std::string GVistaCompleja::GetBottomLeftAnnotation(GNC::GCS::Contexto3D* c)
-{
-	GNC::GCS::IWidgetsRenderer* r = ( c == NULL? NULL : c->GetRenderer());
-	if (r == NULL) {
-		return m_VistasSimples[0]->GetBottomLeftAnnotation(c);
-	} else {
-		for (TListaGVistasSimples::iterator it = m_VistasSimples.begin(); it != m_VistasSimples.end(); ++it) {
-			if ( (*it)->ViewInteractor2D == r) {
-				return (*it)->GetBottomLeftAnnotation(c);
-			}
-		}
-	}
-	return "";
-}
-
-std::string GVistaCompleja::GetBottomRightAnnotation(GNC::GCS::Contexto3D* c)
-{
-	GNC::GCS::IWidgetsRenderer* r = ( c == NULL? NULL : c->GetRenderer());
-	if (r == NULL) {
-		return m_VistasSimples[0]->GetBottomRightAnnotation(c);
-	} else {
-		for (TListaGVistasSimples::iterator it = m_VistasSimples.begin(); it != m_VistasSimples.end(); ++it) {
-			if ( (*it)->ViewInteractor2D == r) {
-				return (*it)->GetBottomRightAnnotation(c);
-			}
-		}
-	}
-	return "";
-}
-
-
-std::string GVistaCompleja::GetPatientPosition(GNC::GCS::Contexto3D* c) {
-	GNC::GCS::IWidgetsRenderer* r = ( c == NULL? NULL : c->GetRenderer());
-	if (r == NULL) {
-		return m_VistasSimples[0]->GetPatientPosition(c);
-	} else {
-		for (TListaGVistasSimples::iterator it = m_VistasSimples.begin(); it != m_VistasSimples.end(); ++it) {
-			if ( (*it)->ViewInteractor2D == r) {
-				return (*it)->GetPatientPosition(c);
-			}
-		}
-	}
-	return "";
-}
-
-std::string GVistaCompleja::GetAnotacionPosicion(const GNC::GCS::Vector3D& wP, GNC::GCS::Contexto3D* c)
-{
-	GNC::GCS::IWidgetsRenderer* r = m_pManager->GetRendererActivo();
-	for (TListaGVistasSimples::iterator it = m_VistasSimples.begin(); it != m_VistasSimples.end(); ++it) {
-		if ( (*it)->ViewInteractor2D == r) {
-			return (*it)->GetAnotacionPosicion(wP, c);
-		}
-	}
-	return "";
-}
-//endregion
-
 void GVistaCompleja::ActualizarImagen()
 {
 	//m_pImagenOriginal->Modified();
