@@ -24,7 +24,6 @@
 #include <export/contracts/iwindowlayoutcontract.h>
 #include <export/contracts/iimageexportcontract.h>
 #include "../estudios/overlay.h"
-#include <api/ianotador.h>
 
 #include <wx/sizer.h>
 #include <wx/dc.h>
@@ -55,6 +54,7 @@ class GVistaComplejaDelegate;
 class GVistaComplejaOverlaysDelegate;
 class GVistaComplejaWindowLayoutDelegate;
 class GVistaComplejaPixelsBluringDelegate;
+class GVistaComplejaAnnotatorDelegate;
 
 namespace GNKVisualizator
 {	
@@ -66,7 +66,7 @@ namespace GNKVisualizator
 	}	
 }
 
-class GVistaCompleja: public VistaComplejaBase, public GNC::GCS::IAnotador, public GNC::GCS::IEventsObserver {
+class GVistaCompleja: public VistaComplejaBase, public GNC::GCS::IEventsObserver {
 	friend class GVistaComplejaDelegate;
 	friend class GVistaComplejaOverlaysDelegate;
 	friend class GVistaComplejaWindowLayoutDelegate;
@@ -74,6 +74,7 @@ class GVistaCompleja: public VistaComplejaBase, public GNC::GCS::IAnotador, publ
 	friend class GNKVisualizator::SimpleViewExportDelegate;
 	friend class GNKVisualizator::GUI::wxDropTargetPreviewPanelVisualizator;
 	friend class GVistaComplejaPixelsBluringDelegate;
+	friend class GVistaComplejaAnnotatorDelegate;
 public:
 
    /* Constructor */
@@ -148,17 +149,7 @@ public:
 
 	//endregion
 
-
-	//region "Realizacion de la interfaz IAnnotator"
-	virtual std::string GetTopLeftAnnotation(GNC::GCS::Contexto3D* c);
-	virtual std::string GetTopRightAnnotation(GNC::GCS::Contexto3D* c);
-	virtual std::string GetBottomLeftAnnotation(GNC::GCS::Contexto3D* c);
-	virtual std::string GetBottomRightAnnotation(GNC::GCS::Contexto3D* c);
-	virtual std::string GetPatientPosition(GNC::GCS::Contexto3D* c);
-
-	virtual std::string GetAnotacionPosicion(const GNC::GCS::Vector3D& wP, GNC::GCS::Contexto3D* c);
-	//endregion
-
+	
 	// Asigna los valores de los apuntadores a la la imagen y el slice actual
 	void AsignarConexionesDeFiltrado(vtkImageData** pImagen, int* slice, vtkImageData** pChroma);
 	void ActualizarImagen();
@@ -195,6 +186,7 @@ protected:
 	GNC::GCS::Ptr<GVistaComplejaWindowLayoutDelegate> WindowLayoutDelegate;
 	GNC::GCS::Ptr<GVistaComplejaPixelsBluringDelegate> PixelsBluringDelegate;
 	GNC::GCS::Ptr<GNKVisualizator::SimpleViewExportContractDelegate> ExportDelegate;
+	GNC::GCS::Ptr<GVistaComplejaAnnotatorDelegate> AnnotatorDelegate;
 	GNKVisualizator::GUI::PreviewPanelVisualizator*   m_pPanelPreview;
 
 	friend class GNKVisualizator::Vista2D;
