@@ -360,283 +360,6 @@ void GVistaSimple::ActualizarTSlider()
 	m_pSliderTimeInstant->SetValue(0);
 }
 
-
-//region "Realizacion de la interfaz IAnnotator"
-
-std::string GVistaSimple::GetTopLeftAnnotation(GNC::GCS::Contexto3D*)
-{
-	if (!this->ViewImage2D->IsInstalledAndInitialized() || IVista == NULL)
-		return "";
-
-	std::ostringstream os;
-	std::string tag;
-
-	tag = "0010|0010"; // Patient's Name
-
-	os << _Std("Patient: ") << IVista->GetDICOMTagOriginal(tag).c_str() << std::endl;
-
-	tag = "0010|0020"; // Patient's ID
-
-	os << _Std("Patient Id: ") << IVista->GetDICOMTagOriginal(tag).c_str();
-
-	return os.str();
-}
-
-std::string GVistaSimple::GetTopRightAnnotation(GNC::GCS::Contexto3D*) {
-	if (!this->ViewImage2D->IsInstalledAndInitialized() || IVista == NULL)
-		return "";
-
-	GTRACE("GVistaSimple::GetTopRightAnnotation()");
-
-	std::ostringstream os;
-	std::string tag;
-	std::string str;
-
-	tag = "0010|0040"; // Patient's Sex
-
-	os << _Std("Sexo") << ": ";
-	os << IVista->GetDICOMTagOriginal(tag).c_str() << " ";
-
-	tag = "0010|0030"; // Patient's BirthDate
-	str = IVista->GetDICOMTagOriginal(tag);
-	if (str.size() == 8) {
-		os << str.substr(6, 2).c_str() << "/";
-		os << str.substr(4, 2).c_str() << "/";
-		os << str.substr(0, 4).c_str() << " ";
-	}
-
-	tag = "0010|1010"; // Patient's Age
-	str = IVista->GetDICOMTagOriginal(tag);
-	os << str << std::endl;
-
-	tag = "0008|0060"; // Modalidad
-	os << _Std("Modality: ") << IVista->GetDICOMTagOriginal(tag).c_str() << std::endl;
-
-	tag = "0008|0021"; // Series Date
-	str = IVista->GetDICOMTagOriginal(tag);
-	if (str.size() == 8) {
-		os << str.substr(6, 2).c_str() << "/";
-		os << str.substr(4, 2).c_str() << "/";
-		os << str.substr(0, 4).c_str() << std::endl;
-	}
-	
-
-	tag = "0008|103e"; // Series Description
-	str = IVista->GetDICOMTagOriginal(tag);
-	if (!str.empty()) {
-		if(str.size()<18){
-			os << str.c_str();
-		}else {
-			os << str.substr(0,18).c_str()<<"...";
-		}
-	}
-
-	return os.str();
-}
-
-std::string GVistaSimple::GetBottomLeftAnnotation(GNC::GCS::Contexto3D* c) {
-	if (!this->ViewImage2D->IsInstalledAndInitialized() || IVista == NULL) {
-		return "";
-	}
-
-	std::ostringstream os;
-	std::string tmp = IVista->GetDICOMTagOriginal("0020|4000");// Image description
-	if (!tmp.empty()) {
-		os << std::endl << _Std("Comment:") << tmp;
-	}
-	int dims[3] = {0, 0, 0};
-	this->ViewImage2D->GetDimensions(dims);
-	int nc = this->ViewImage2D->GetNumberOfComponents();
-	os << std::endl << _Std("Image:") << dims[0] << " x " << dims[1];
-	if (dims[2] > 1) {
-		os << " x " << dims[2];
-	}
-	if(nc == 1){
-		os << std::endl << "W/L: "  << ViewImage2D->GetWindow() << "/" << ViewImage2D->GetLevel();
-	}
-	
-	//esto es una secuencia no sta mu bien
-	tmp = IVista->GetDICOMTagOriginal(std::string("0020|0062"));
-	if(tmp != "") {
-		os << " ";
-		if(tmp=="R"){
-			os << _Std("Right") << ";" ;
-		}else if(tmp=="L"){
-			os << _Std("Left") << ";";
-		}
-	}
-
-	if (c->offscreenCreado) {
-		os << std::endl << _Std("Slice: ") <<  c->OVID + 1;
-		if (dims[2] > 1) {
-			os << " T: 0";
-		}
-		
-	}
-	else {
-		os << std::endl << _Std("Slice: ") <<  c->GetRenderer()->GetVID() + 1;
-		if (dims[2] > 1) {
-			os << " T: " << ViewImage2D->GetTindex();
-		}
-	}
-
-	double spacing[3] = {0.0, 0.0, 0.0};
-	bool hasSpacing = EstudioReferido->GetSpacingActive(spacing[0], spacing[1], spacing[2]);
-	if (hasSpacing) {
-		os << std::endl << _Std("Voxel:") << spacing[0] << "x" << spacing[1] << " mm.";
-	}
-	else {
-		os << std::endl << _Std("Image without metric information");
-	}
-
-	std::string ststr = IVista->GetDICOMTagOriginal("0018|0050");
-	if (!ststr.empty()) {
-		double thickness = 0.0;
-		std::istringstream is(ststr);
-		is >> thickness;
-		if (thickness > 0.0) {
-			os << std::endl << _Std("Slice thickness:") << " " <<  thickness << " mm.";
-		}
-	}
-	return os.str();
-}
-
-std::string GVistaSimple::GetBottomRightAnnotation(GNC::GCS::Contexto3D* /*c*/) {
-	if (!this->ViewImage2D->IsInstalledAndInitialized() || IVista == NULL)
-		return "";
-
-	std::ostringstream os;
-	std::string tag;
-	std::string str;
-
-	tag = "0008|0020"; // study Date
-	str = IVista->GetDICOMTagOriginal(tag);
-	if (str.size() == 8) {
-		os << str.substr(6, 2).c_str() << "/";
-		os << str.substr(4, 2).c_str() << "/";
-		os << str.substr(0, 4).c_str() << " ";
-	}
-	os<<std::endl;
-
-	tag = "0008|1030"; // Study Description
-	str = IVista->GetDICOMTagOriginal(tag);
-	if (!str.empty()) {
-		if(str.size()<18){
-			os << str.c_str()<<std::endl;
-		}else {
-			os << str.substr(0,18).c_str()<<"..."<<std::endl;
-		}
-	}
-
-	tag = "0008|0080"; // Nombre del centro, si viene el centro en el estudio se pone si no el d los tags estaticos
-	str = IVista->GetDICOMTagOriginal(tag);
-	if (str.size() == 6) {
-		os << str.substr(0, 2).c_str() << ":";
-	} else {
-		//institucion
-		std::string tag;
-		GNC::GCS::ConfigurationController::Instance()->readStringGeneral("/GinkgoCore/Estacion", "CentroNombre", tag);
-
-		if (!tag.empty()) {
-			os << tag.c_str() << std::endl;
-		}
-	}
-
-	wxString appName ( wxString::FromUTF8(GNC::GCS::IEntorno::Instance()->GetApplicationName().c_str()));
-	wxString madewith( wxString::Format(_("Made with %s"), appName.c_str()));
-	os << madewith.ToUTF8();
-	return os.str();
-}
-
-std::string GVistaSimple::GetPatientPosition(GNC::GCS::Contexto3D* /*c*/)
-{
-	return IVista->GetDICOMTagOriginal("0018|5100");
-}
-
-std::string GVistaSimple::GetAnotacionPosicion(const GNC::GCS::Vector3D& wP, GNC::GCS::Contexto3D* c)
-{
-	if (!this->ViewImage2D->IsInstalledAndInitialized() || IVista == NULL)
-		return "";
-
-	std::ostringstream os;
-	os.setf(ios::floatfield, ios::fixed );
-	os.precision(2);
-	os.fill('0');
-
-	double ip[3] = {0,0,0};
-	c->pRenderer->m_pImageViewer->Proyect2D(wP.v, ip);
-	int pp[3] = {0, 0, 0};
-	int dims[3];
-
-	ViewImage2D->GetDimensions(dims);
-
-
-	os << _Std("Position:") << " W:(" << wP.x << ", " << wP.y << "," << wP.z << "); I:(" << ip[0] << ", " << ip[1] << ")";
-
-	//corregir de convención DICOM a convención vtk
-
-	ViewImage2D->CoordenadasImagenACoordenadasPixel(ip, pp);
-	if (pp[0]>=0 && pp[0] < dims[0] && pp[1]>=0 && pp[1] < dims[1]) {
-		const vtkSmartPointer<vtkImageData>& pImg = ViewImage2D->GetDataObject();
-		if (pImg == NULL || pImg->GetNumberOfPoints() == 0)
-		{
-			return "";
-		}
-		void *scalar = pImg->GetScalarPointer((int)pp[0],(int)pp[1],ViewImage2D->GetTindex());
-		
-
-		if( scalar ) {
-			bool primero = true;
-			for(int i = 0; i<ViewImage2D->GetNumberOfComponents(); i++) {
-				
-				double value = 0.0f;
-
-				switch (ViewImage2D->GetInput()->GetScalarType()) {
-					case VTK_DOUBLE:
-						value = (((double*)scalar)[i]);
-						break;
-					case VTK_FLOAT:
-						value = (double) (((float*)scalar)[i]);
-						break;
-					case VTK_UNSIGNED_LONG:
-						value = (double) (((unsigned long*)scalar)[i]);
-						break;
-					case VTK_LONG:
-						value = (double) (((long*)scalar)[i]);
-						break;
-					case VTK_UNSIGNED_INT:
-						value = (double) (((unsigned int*)scalar)[i]);
-						break;
-					case VTK_INT:
-						value = (double) (((int*)scalar)[i]);
-						break;
-					case VTK_UNSIGNED_SHORT:
-						value = (double) (((unsigned short*)scalar)[i]);
-						break;
-					case VTK_SHORT:
-						value = (double) (((short*)scalar)[i]);
-						break;
-					case VTK_UNSIGNED_CHAR:
-						value = (double) (((unsigned char*)scalar)[i]);
-						break;
-					case VTK_CHAR:
-						value = (double) (((char*)scalar)[i]);
-						break;
-				}
-
-				if(primero) {
-					os << " " << _Std("Value:") << value;
-				} else {
-					os << "," << value;
-				}
-				primero = false;
-			}
-		}
-	}
-
-	return os.str();
-}
-
 //endregion
 
 inline bool my_isnan(double x)
@@ -1179,6 +902,7 @@ void GVistaSimple::ProcesarEvento(GNC::GCS::Events::IEvent *evt)
 						break;
 					case GNC::GCS::Events::EventoModificacionImagen::SliceCambiado:
 						{
+							ActualizarTSlider();
 						}
 						break;
 					case GNC::GCS::Events::EventoModificacionImagen::ImagenDescargada:
