@@ -16,7 +16,6 @@
 #include "visualizatorviews.h"
 #include <api/controllers/ieventscontroller.h>
 #include <api/iwidgets.h>
-#include <api/ianotador.h>
 #include <api/icontexto.h>
 #include <api/observers/ieventsobserver.h>
 #include "../estudios/overlay.h"
@@ -38,7 +37,7 @@ class IconoImagenCtrl;
 class vtkAlgorithmOutput;
 class vtkImageData;
 
-class GVistaSimple: public VistaSimpleBase, public GNC::GCS::IAnotador, public GNC::GCS::IImpresorOverlay, public GNC::GCS::IEventsObserver {
+class GVistaSimple: public VistaSimpleBase, public GNC::GCS::IImpresorOverlay, public GNC::GCS::IEventsObserver {
 public:
    /* Constructor */
 	GVistaSimple( GNKVisualizator::Vista2D* pIVista, wxWindow* pParent);
@@ -102,16 +101,6 @@ public:
 
    //endregion
 
-
-	//region "Realizacion de la interfaz IAnnotator"
-	virtual std::string GetTopLeftAnnotation(GNC::GCS::Contexto3D* c);
-	virtual std::string GetTopRightAnnotation(GNC::GCS::Contexto3D* c);
-	virtual std::string GetBottomLeftAnnotation(GNC::GCS::Contexto3D* c);
-	virtual std::string GetBottomRightAnnotation(GNC::GCS::Contexto3D* c);
-	virtual std::string GetPatientPosition(GNC::GCS::Contexto3D* c);
-	virtual std::string GetAnotacionPosicion(const GNC::GCS::Vector3D& wP, GNC::GCS::Contexto3D* c);
-	//endregion
-
 	//region "Interfaz de impresion de overlays de widgets"
 	virtual void ImprimirOverlay(GNC::GCS::Widgets::IWidget* w, GNC::GCS::Contexto3D* c, GNC::GCS::Vector& boundingBox);
 	virtual void ImprimirOverlay(GNC::GCS::Widgets::IWidgetBuilder* wb, GNC::GCS::Contexto3D* c, GNC::GCS::Vector& boundingBox);
