@@ -19,6 +19,7 @@
 #include <eventos/render.h>
 #include <wx/pen.h>
 #include <wx/aui/auibar.h>
+#include <api/iannotator.h>
 #include <wx/ginkgostyle/ginkgostyle.h>
 
 #include <visualizator/vistas/waveformview.h>
@@ -74,6 +75,37 @@ namespace GNKVisualizator
 			{
 				return false;
 			}
+		protected:
+			GWaveformView* GView;
+		};
+		////////////////////GWaveform annotator delegate
+		class GWaveformAnnotatorDelegate: public GNC::GCS::IAnnotator
+		{
+		public:
+			GWaveformAnnotatorDelegate(GWaveformView* gView, GNKVisualizator::WaveFormView* pView):GNC::GCS::IAnnotator(pView),
+				GView(gView)
+			{
+			}
+			~GWaveformAnnotatorDelegate()
+			{
+			}
+
+			virtual std::string GetAnnotationValue(GNC::GCS::Contexto3D* c, const std::string& key)
+			{
+				if (key == "${SLICE.WL.FULLTEXT}") {
+					return "";
+				} else if (key == "${SLICE.IDX.FULLTEXT}") {
+					return "";
+				} else if (key == "${VIEW.COORDLABELS}") {
+					std::ostringstream os;
+					os << "25 mm/s, 10 mm/mV";
+					return os.str();
+				}
+				return GNC::GCS::IAnnotator::GetAnnotationValue(c, key);
+			}
+
+
+
 		protected:
 			GWaveformView* GView;
 		};
@@ -97,7 +129,8 @@ namespace GNKVisualizator
 		
 		/* Constructor */
 		GWaveformView::GWaveformView(GNKVisualizator::WaveFormView* pView) : GWaveformViewBase(pView->GetEstudio()->ParentWindow),
-				Delegate(new GWaveformViewDelegate(this))
+				Delegate(new GWaveformViewDelegate(this)),
+				AnnotatorDelegate(new GWaveformAnnotatorDelegate(this, pView))
 		{
 			Freeze();
 			View = pView;
@@ -112,12 +145,11 @@ namespace GNKVisualizator
 
 			// Setup del manejador de widgets */
 			m_pManager = GNC::GCS::IEntorno::Instance()->NewWidgetsManager(View);
+			m_pManager->SetAnnotator(AnnotatorDelegate);
 			ViewInteractor2D->SetManager(m_pManager);
 			ViewInteractor2D->SetVID(0,false);
 			m_pManager->SetRendererActivo(ViewInteractor2D);
-
-			m_pManager->CrearWidgetAnotador(this);
-
+			
 			WidgetRepresentation* pWidgetsRepresentation = WidgetRepresentation::New();
 			pWidgetsRepresentation->SetRenderer(ViewInteractor2D->FindPokedRenderer(0,0));
 			ViewInteractor2D->FindPokedRenderer(0,0)->AddViewProp(pWidgetsRepresentation);
@@ -328,160 +360,10 @@ namespace GNKVisualizator
 
 		void GWaveformView::OnShowHideCornerAnnotations(wxCommandEvent &)
 		{
-			m_pManager->MostrarOcultarAnotador();			
+			m_pManager->ShowAnnotations(!m_pManager->IsShownAnnotations());			
 			GNC::GCS::IEntorno::Instance()->GetControladorEventos()->ProcesarEvento(new GNC::GCS::Events::EventoRender(View));
 		}
 
-		//IAnotador
-		std::string GWaveformView::GetDICOMTag(std::string tagId)
-		{
-			std::string str("");
-			View->GetEstudio()->GetTagActiveImage(tagId,str);
-
-			return str;
-		}
-
-		std::string GWaveformView::GetTopLeftAnnotation(GNC::GCS::Contexto3D*)
-		{
-			if (!this->ViewImage2D->IsInstalledAndInitialized() || View == NULL)
-				return "";
-
-			std::ostringstream os;
-			std::string tag;
-
-			tag = "0010|0010"; // Patient's Name
-
-			os << _Std("Patient: ") << GetDICOMTag(tag).c_str() << std::endl;
-
-			tag = "0010|0020"; // Patient's ID
-
-			os << _Std("Patient Id: ") << GetDICOMTag(tag).c_str();
-
-			return os.str();
-		}
-
-		std::string GWaveformView::GetTopRightAnnotation(GNC::GCS::Contexto3D*)
-		{
-			if (!this->ViewImage2D->IsInstalledAndInitialized() || View == NULL)
-				return "";
-
-			std::ostringstream os;
-			std::string tag;
-			std::string str;
-
-			tag = "0010|0040"; // Patient's Sex
-
-			os << GetDICOMTag(tag).c_str() << " ";
-
-			tag = "0010|0030"; // Patient's BirthDate
-			str = GetDICOMTag(tag);
-			if (str.size() == 8) {
-				os << str.substr(6, 2).c_str() << "-";
-				os << str.substr(4, 2).c_str() << "-";
-				os << str.substr(0, 4).c_str() << " ";
-			}
-
-			tag = "0010|1010"; // Patient's Age
-			str = GetDICOMTag(tag);
-			if(str.size() > 0) {
-				os << str.c_str() << "Y" << std::endl;
-			}
-
-			tag = "0008|0060"; // Modalidad
-			os << _Std("Modality: ") << GetDICOMTag(tag).c_str() << std::endl;
-
-			tag = "0008|0021"; // Series Date
-			str = GetDICOMTag(tag);
-			if (str.size() == 8) {
-				os << str.substr(6, 2).c_str() << "-";
-				os << str.substr(4, 2).c_str() << "-";
-				os << str.substr(0, 4).c_str() << " ";
-			}
-			os<<std::endl;
-
-			tag = "0008|103e"; // Series Description
-			str = GetDICOMTag(tag);
-			if (!str.empty()) {
-				if(str.size()<18){
-					os << str.c_str();
-				}else {
-					os << str.substr(0,18).c_str()<<"...";
-				}
-			}
-
-			return os.str();
-		}
-
-		std::string GWaveformView::GetBottomLeftAnnotation(GNC::GCS::Contexto3D*)
-		{
-			
-			if (!this->ViewImage2D->IsInstalledAndInitialized() || View == NULL)
-				return "";
-
-			std::ostringstream os;
-			std::string tag;
-			std::string str;
-
-			tag = "0008|0020"; // study Date
-			str = GetDICOMTag(tag);
-			if (str.size() == 8) {
-				os << str.substr(6, 2).c_str() << "-";
-				os << str.substr(4, 2).c_str() << "-";
-				os << str.substr(0, 4).c_str() << " ";
-			}
-			os<<std::endl;
-
-			tag = "0008|1030"; // Study Description
-			str = GetDICOMTag(tag);
-			if (!str.empty()) {
-				if(str.size()<18){
-					os << str.c_str()<<std::endl;
-				}else {
-					os << str.substr(0,18).c_str()<<"..."<<std::endl;
-				}
-			}
-
-			tag = "0008|0080"; // Nombre del centro, si viene el centro en el estudio se pone si no el d los tags estaticos
-			str = GetDICOMTag(tag);
-			if (str.size() == 6) {
-				os << str.substr(0, 2).c_str() << ":";
-			} else {
-				std::string tag;
-				GNC::GCS::ConfigurationController::Instance()->readStringGeneral("/GinkgoCore/Estacion", "CentroNombre", tag);
-
-				if (!tag.empty()) {
-					os << tag.c_str() << std::endl;
-				}
-			}
-			
-			
-			wxString appName ( wxString::FromUTF8(GNC::GCS::IEntorno::Instance()->GetApplicationName().c_str()));
-			wxString madewith( wxString::Format(_("Made with %s"), appName.c_str()));
-			
-			os << std::string(madewith.ToUTF8());
-			return os.str();
-		}
-
-		std::string GWaveformView::GetBottomRightAnnotation(GNC::GCS::Contexto3D*)
-		{
-			if (!this->ViewImage2D->IsInstalledAndInitialized() || View == NULL)
-				return "";
-			std::ostringstream os;
-			os << "25 mm/s, 10 mm/mV";
-			return os.str();
-		}
-
-		std::string GWaveformView::GetPatientPosition(GNC::GCS::Contexto3D*)
-		{
-			return "";
-		}
-
-		std::string GWaveformView::GetAnotacionPosicion(const GNC::GCS::Vector3D& /*wP*/, GNC::GCS::Contexto3D*)
-		{
-			return "";
-		}
-
-		//end ianotador
 
 		void GWaveformView::OnFocus(wxChildFocusEvent &)
 		{
