@@ -58,7 +58,7 @@ namespace GNKVisualizator {
 		GetImage(ptrImage, m_pView->IVista->GetEstudio()->ActiveFileIndex, mapasValoracion, conWidgets, size);
 	}
 
-	void SimpleViewExportDelegate::GetImage(ImageType::Pointer& ptrImage, int index, TValorationMaps& mapasValoracion, bool conWidgets, const GNC::GCS::Vector& size)
+	void SimpleViewExportDelegate::GetImage(ImageType::Pointer& ptrImage, int index, TValorationMaps& /*mapasValoracion*/, bool conWidgets, const GNC::GCS::Vector& size)
 	{
 		vtkSmartPointer<vtkGinkgoImageViewer>& Viewer = m_pView->IVista->GetEstudio()->Viewer;
 		if (!Viewer->IsInstalledAndInitialized())
